@@ -23,6 +23,8 @@ import (
 	dto "github.com/prometheus/client_model/go"
 	"go.uber.org/zap"
 
+	"github.com/apache/yunikorn-core/pkg/common/resources"
+	"github.com/apache/yunikorn-core/pkg/locking"
 	"github.com/apache/yunikorn-core/pkg/log"
 )
 
@@ -42,10 +44,11 @@ const (
 	ContainerAllocated = "allocated"
 	ContainerRejected  = "rejected"
 
-	QueueGuaranteed = "guaranteed"
-	QueueMax        = "max"
-	QueuePending    = "pending"
-	QueuePreempting = "preempting"
+	QueueGuaranteed     = "guaranteed"
+	QueueMax            = "max"
+	QueuePending        = "pending"
+	QueuePreempting     = "preempting"
+	QueueMaxRunningApps = "maxRunningApps"
 )
 
 // QueueMetrics to declare queue metrics
@@ -57,6 +60,9 @@ type QueueMetrics struct {
 	resourceMetricsLabel *prometheus.GaugeVec
 	// Deprecated - To be removed in 1.7.0. Replaced with queue label Metrics
 	resourceMetricsSubsystem *prometheus.GaugeVec
+	// Track known resource types
+	knownResourceTypes map[string]struct{}
+	lock               locking.Mutex
 }
 
 // InitQueueMetrics to initialize queue metrics
@@ -94,7 +100,7 @@ func InitQueueMetrics(name string) *QueueMetrics {
 			Namespace:   Namespace,
 			Name:        "queue_resource",
 			ConstLabels: prometheus.Labels{"queue": name},
-			Help:        "Queue resource metrics. State of the resource includes `guaranteed`, `max`, `allocated`, `pending`, `preempting`.",
+			Help:        "Queue resource metrics. State of the resource includes `guaranteed`, `max`, `allocated`, `pending`, `preempting`, `maxRunningApps`.",
 		}, []string{"state", "resource"})
 
 	q.resourceMetricsSubsystem = prometheus.NewGaugeVec(
@@ -102,7 +108,7 @@ func InitQueueMetrics(name string) *QueueMetrics {
 			Namespace: Namespace,
 			Subsystem: replaceStr,
 			Name:      "queue_resource",
-			Help:      "Queue resource metrics. State of the resource includes `guaranteed`, `max`, `allocated`, `pending`, `preempting`.",
+			Help:      "Queue resource metrics. State of the resource includes `guaranteed`, `max`, `allocated`, `pending`, `preempting`, `maxRunningApps`.",
 		}, []string{"state", "resource"})
 
 	var queueMetricsList = []prometheus.Collector{
@@ -123,9 +129,25 @@ func InitQueueMetrics(name string) *QueueMetrics {
 		}
 	}
 
+	q.knownResourceTypes = make(map[string]struct{})
 	return q
 }
 
+func (m *QueueMetrics) UnregisterMetrics() {
+	var queueMetricsList = []prometheus.Collector{
+		m.appMetricsLabel,
+		m.appMetricsSubsystem,
+		m.containerMetrics,
+		m.resourceMetricsLabel,
+		m.resourceMetricsSubsystem,
+	}
+
+	// Unregister the metrics
+	for _, metric := range queueMetricsList {
+		prometheus.Unregister(metric)
+	}
+}
+
 func (m *QueueMetrics) incQueueApplications(state string) {
 	m.appMetricsLabel.WithLabelValues(state).Inc()
 	m.appMetricsSubsystem.WithLabelValues(state).Inc()
@@ -142,10 +164,13 @@ func (m *QueueMetrics) setQueueResource(state string, resourceName string, value
 }
 
 func (m *QueueMetrics) Reset() {
+	m.lock.Lock()
+	defer m.lock.Unlock()
 	m.appMetricsLabel.Reset()
 	m.appMetricsSubsystem.Reset()
 	m.resourceMetricsLabel.Reset()
 	m.resourceMetricsSubsystem.Reset()
+	m.knownResourceTypes = make(map[string]struct{})
 }
 
 func (m *QueueMetrics) IncQueueApplicationsRunning() {
@@ -301,12 +326,22 @@ func (m *QueueMetrics) AddReleasedContainers(value int) {
 	m.containerMetrics.WithLabelValues(ContainerReleased).Add(float64(value))
 }
 
-func (m *QueueMetrics) SetQueueGuaranteedResourceMetrics(resourceName string, value float64) {
-	m.setQueueResource(QueueGuaranteed, resourceName, value)
-}
+func (m *QueueMetrics) UpdateQueueResourceMetrics(state string, newResources map[string]resources.Quantity) {
+	m.lock.Lock()
+	defer m.lock.Unlock()
+	// Iterate over new resource types and set their values
+	for resourceName, value := range newResources {
+		m.setQueueResource(state, resourceName, float64(value))
+		// Add new resources to the known list
+		m.knownResourceTypes[resourceName] = struct{}{}
+	}
 
-func (m *QueueMetrics) SetQueueMaxResourceMetrics(resourceName string, value float64) {
-	m.setQueueResource(QueueMax, resourceName, value)
+	// Emit old resource types that are missing in the new collection with zero
+	for resourceName := range m.knownResourceTypes {
+		if _, exists := newResources[resourceName]; !exists {
+			m.setQueueResource(state, resourceName, float64(0))
+		}
+	}
 }
 
 func (m *QueueMetrics) SetQueueAllocatedResourceMetrics(resourceName string, value float64) {
@@ -320,3 +355,7 @@ func (m *QueueMetrics) SetQueuePendingResourceMetrics(resourceName string, value
 func (m *QueueMetrics) SetQueuePreemptingResourceMetrics(resourceName string, value float64) {
 	m.setQueueResource(QueuePreempting, resourceName, value)
 }
+
+func (m *QueueMetrics) SetQueueMaxRunningAppsMetrics(value uint64) {
+	m.setQueueResource(QueueMaxRunningApps, "apps", float64(value))
+}
