@@ -19,8 +19,7 @@
 package mock
 
 import (
-	"sync"
-
+	"github.com/apache/yunikorn-core/pkg/locking"
 	"github.com/apache/yunikorn-scheduler-interface/lib/go/si"
 )
 
@@ -28,7 +27,7 @@ type EventPlugin struct {
 	ResourceManagerCallback
 	records chan *si.EventRecord
 
-	sync.Mutex
+	locking.Mutex
 }
 
 func (m *EventPlugin) SendEvent(events []*si.EventRecord) {
