@@ -120,6 +120,7 @@ func (cc *ClusterContext) setEventHandler(rmHandler handler.EventHandler) {
 func (cc *ClusterContext) schedule() bool {
 	// schedule each partition defined in the cluster
 	activity := false
+	scheduleCycleStart := time.Now()
 	for _, psc := range cc.GetPartitionMapClone() {
 		// if there are no resources in the partition just skip
 		if psc.root.GetMaxResource() == nil {
@@ -140,8 +141,8 @@ func (cc *ClusterContext) schedule() bool {
 				result = psc.tryAllocate()
 			}
 		}
+		metrics.GetSchedulerMetrics().ObserveSchedulingLatency(schedulingStart)
 		if result != nil {
-			metrics.GetSchedulerMetrics().ObserveSchedulingLatency(schedulingStart)
 			if result.ResultType == objects.Replaced {
 				// communicate the removal to the RM
 				cc.notifyRMAllocationReleased(psc.RmID, psc.Name, []*objects.Allocation{result.Request.GetRelease()}, si.TerminationType_PLACEHOLDER_REPLACED, "replacing allocationKey: "+result.Request.GetAllocationKey())
@@ -151,6 +152,7 @@ func (cc *ClusterContext) schedule() bool {
 			activity = true
 		}
 	}
+	metrics.GetSchedulerMetrics().ObserveSchedulingCycle(scheduleCycleStart)
 	return activity
 }
 
@@ -365,7 +367,7 @@ func (cc *ClusterContext) updateSchedulerConfig(conf *configs.SchedulerConfig, r
 		part, ok := cc.partitions[p.Name]
 		if ok {
 			// make sure the new info passes all checks
-			_, err = newPartitionContext(p, rmID, nil)
+			_, err = newPartitionContext(p, rmID, nil, true)
 			if err != nil {
 				return err
 			}
@@ -379,7 +381,7 @@ func (cc *ClusterContext) updateSchedulerConfig(conf *configs.SchedulerConfig, r
 			// not found: new partition, no checks needed
 			log.Log(log.SchedContext).Info("added partitions", zap.String("partitionName", partitionName))
 
-			part, err = newPartitionContext(p, rmID, cc)
+			part, err = newPartitionContext(p, rmID, cc, false)
 			if err != nil {
 				return err
 			}
@@ -661,9 +663,6 @@ func (cc *ClusterContext) updateNode(nodeInfo *si.NodeInfo) {
 		if sr := nodeInfo.SchedulableResource; sr != nil {
 			partition.updatePartitionResource(node.SetCapacity(resources.NewResourceFromProto(sr)))
 		}
-		if or := nodeInfo.OccupiedResource; or != nil {
-			node.SetOccupiedResource(resources.NewResourceFromProto(or))
-		}
 	case si.NodeInfo_DRAIN_NODE:
 		if node.IsSchedulable() {
 			// set the state to not schedulable
@@ -759,7 +758,7 @@ func (cc *ClusterContext) processAllocations(request *si.AllocationRequest) {
 			continue
 		}
 		// at some point, we may need to handle new requests as well
-		if newAlloc {
+		if newAlloc && !alloc.IsForeign() {
 			cc.notifyRMNewAllocation(request.RmID, alloc)
 		}
 	}
