@@ -37,9 +37,10 @@ import (
 const pName = "default"
 
 type mockEventHandler struct {
-	eventHandled  bool
-	rejectedNodes []*si.RejectedNode
-	acceptedNodes []*si.AcceptedNode
+	eventHandled    bool
+	rejectedNodes   []*si.RejectedNode
+	acceptedNodes   []*si.AcceptedNode
+	newAllocHandler func(*rmevent.RMNewAllocationsEvent)
 }
 
 func newMockEventHandler() *mockEventHandler {
@@ -56,6 +57,10 @@ func (m *mockEventHandler) HandleEvent(ev interface{}) {
 		m.rejectedNodes = append(m.rejectedNodes, nodeEvent.RejectedNodes...)
 		m.acceptedNodes = append(m.acceptedNodes, nodeEvent.AcceptedNodes...)
 	}
+
+	if allocEvent, ok := ev.(*rmevent.RMNewAllocationsEvent); ok && m.newAllocHandler != nil {
+		m.newAllocHandler(allocEvent)
+	}
 }
 
 func createTestContext(t *testing.T, partitionName string) *ClusterContext {
@@ -71,11 +76,17 @@ func createTestContext(t *testing.T, partitionName string) *ClusterContext {
 				Name:      "root",
 				Parent:    true,
 				SubmitACL: "*",
-				Queues:    nil,
+				Queues: []configs.QueueConfig{
+					{
+						Name:      "default",
+						Parent:    false,
+						SubmitACL: "*",
+					},
+				},
 			},
 		},
 	}
-	partition, err := newPartitionContext(conf, "test", context)
+	partition, err := newPartitionContext(conf, "test", context, false)
 	assert.NilError(t, err, "partition create should not have failed with error")
 	context.partitions[partition.Name] = partition
 	return context
@@ -89,7 +100,6 @@ func TestContext_UpdateNode(t *testing.T) {
 		SchedulableResource: &si.Resource{Resources: map[string]*si.Quantity{"first": {Value: 10}}},
 	}
 	full := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10})
-	half := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5})
 	partition := context.GetPartition(pName)
 	if partition == nil {
 		t.Fatalf("partition should have been found")
@@ -110,15 +120,9 @@ func TestContext_UpdateNode(t *testing.T) {
 	assert.Assert(t, resources.Equals(full, partition.GetTotalPartitionResource()), "partition resource should be updated")
 	// try to update: fail due to unknown action
 	n.SchedulableResource = &si.Resource{Resources: map[string]*si.Quantity{"first": {Value: 5}}}
-	n.OccupiedResource = &si.Resource{Resources: map[string]*si.Quantity{"first": {Value: 5}}}
 	context.updateNode(n)
 	node := partition.GetNode("test-1")
 	assert.Assert(t, resources.Equals(full, node.GetAvailableResource()), "node available resource should not be updated")
-	n.Action = si.NodeInfo_UPDATE
-	context.updateNode(n)
-	assert.Assert(t, resources.Equals(half, partition.GetTotalPartitionResource()), "partition resource should be updated")
-	assert.Assert(t, resources.IsZero(node.GetAvailableResource()), "node available should have been updated to zero")
-	assert.Assert(t, resources.Equals(half, node.GetOccupiedResource()), "node occupied should have been updated")
 
 	// other actions
 	n = &si.NodeInfo{
@@ -296,6 +300,87 @@ func TestContextDrainingNodeBackToSchedulableMetrics(t *testing.T) {
 	verifyMetrics(t, 0, "draining")
 }
 
+func TestContext_OnAllocationNotification(t *testing.T) {
+	context := createTestContext(t, pName)
+	eventHandler := context.rmEventHandler.(*mockEventHandler) //nolint:errcheck
+	var lastAllocEvent *rmevent.RMNewAllocationsEvent
+	eventHandler.newAllocHandler = func(event *rmevent.RMNewAllocationsEvent) {
+		lastAllocEvent = event
+		go func() {
+			event.Channel <- &rmevent.Result{Succeeded: true}
+		}()
+	}
+
+	n := getNodeInfoForAddingNode()
+	err := context.addNode(n, true)
+	assert.NilError(t, err, "unexpected error returned from addNode")
+	partition := context.GetPartition(pName)
+	assert.Assert(t, partition != nil)
+	assert.Equal(t, 1, len(partition.GetNodes()), "expected node not found on partition")
+
+	// register application
+	appReq := &si.ApplicationRequest{
+		New: []*si.AddApplicationRequest{
+			{
+				QueueName:     defQueue,
+				PartitionName: pName,
+				Ugi: &si.UserGroupInformation{
+					User:   "testuser",
+					Groups: []string{"testgroup"},
+				},
+				ApplicationID: appID1,
+			},
+		},
+		RmID: "rm:123",
+	}
+	context.handleRMUpdateApplicationEvent(&rmevent.RMUpdateApplicationEvent{Request: appReq})
+
+	// add a Yunikorn allocation
+	allocReq := &si.AllocationRequest{
+		Allocations: []*si.Allocation{
+			{
+				AllocationKey: allocKey,
+				ResourcePerAlloc: &si.Resource{
+					Resources: map[string]*si.Quantity{
+						"first": {Value: 1},
+					},
+				},
+				ApplicationID: appID1,
+				NodeID:        "test-1",
+				PartitionName: pName,
+			},
+		},
+		RmID: "rm:123",
+	}
+	context.handleRMUpdateAllocationEvent(&rmevent.RMUpdateAllocationEvent{Request: allocReq})
+	assert.Assert(t, lastAllocEvent != nil)
+	assert.Equal(t, lastAllocEvent.Allocations[0].AllocationKey, allocKey)
+
+	// add a non-Yunikorn allocation
+	lastAllocEvent = nil
+	nonYkAllocReq := &si.AllocationRequest{
+		Allocations: []*si.Allocation{
+			{
+				AllocationKey: "foreign-alloc-1",
+				ResourcePerAlloc: &si.Resource{
+					Resources: map[string]*si.Quantity{
+						"first": {Value: 1},
+					},
+				},
+				AllocationTags: map[string]string{
+					siCommon.Foreign: siCommon.AllocTypeDefault,
+				},
+				NodeID:        "test-1",
+				PartitionName: pName,
+			},
+		},
+		RmID: "rm:123",
+	}
+
+	context.handleRMUpdateAllocationEvent(&rmevent.RMUpdateAllocationEvent{Request: nonYkAllocReq})
+	assert.Assert(t, lastAllocEvent == nil, "unexpected allocation event")
+}
+
 func getNodeInfoForAddingNode() *si.NodeInfo {
 	n := &si.NodeInfo{
 		NodeID:              "test-1",
