@@ -52,7 +52,6 @@ var (
 	terminatedTimeout         = 3 * 24 * time.Hour
 	defaultPlaceholderTimeout = 15 * time.Minute
 )
-
 var initAppLogOnce sync.Once
 var rateLimitedAppLog *log.RateLimitedLogger
 
@@ -78,10 +77,9 @@ type StateLogEntry struct {
 }
 
 type Application struct {
-	ApplicationID  string            // application ID
-	Partition      string            // partition Name
-	SubmissionTime time.Time         // time application was submitted
-	tags           map[string]string // application tags used in scheduling
+	ApplicationID string            // application ID
+	Partition     string            // partition Name
+	tags          map[string]string // application tags used in scheduling
 
 	// Private mutable fields need protection
 	queuePath         string
@@ -92,6 +90,7 @@ type Application struct {
 	sortedRequests    sortedRequests          // list of requests pre-sorted
 	user              security.UserGroup      // owner of the application
 	allocatedResource *resources.Resource     // total allocated resources
+	submissionTime    time.Time               // time application was submitted (based on the first ask)
 
 	usedResource        *resources.TrackedResource // keep track of resource usage of the application
 	preemptedResource   *resources.TrackedResource // keep track of preempted resource usage of the application
@@ -125,34 +124,11 @@ type Application struct {
 	locking.RWMutex
 }
 
-func (sa *Application) GetApplicationSummary(rmID string) *ApplicationSummary {
-	sa.RLock()
-	defer sa.RUnlock()
-	state := sa.stateMachine.Current()
-	resourceUsage := sa.usedResource.Clone()
-	preemptedUsage := sa.preemptedResource.Clone()
-	placeHolderUsage := sa.placeholderResource.Clone()
-	appSummary := &ApplicationSummary{
-		ApplicationID:       sa.ApplicationID,
-		SubmissionTime:      sa.SubmissionTime,
-		StartTime:           sa.startTime,
-		FinishTime:          sa.finishedTime,
-		User:                sa.user.User,
-		Queue:               sa.queuePath,
-		State:               state,
-		RmID:                rmID,
-		ResourceUsage:       resourceUsage,
-		PreemptedResource:   preemptedUsage,
-		PlaceholderResource: placeHolderUsage,
-	}
-	return appSummary
-}
-
 func NewApplication(siApp *si.AddApplicationRequest, ugi security.UserGroup, eventHandler handler.EventHandler, rmID string) *Application {
 	app := &Application{
 		ApplicationID:         siApp.ApplicationID,
 		Partition:             siApp.PartitionName,
-		SubmissionTime:        time.Now(),
+		submissionTime:        time.Now(),
 		queuePath:             siApp.QueueName,
 		tags:                  siApp.Tags,
 		pending:               resources.NewResource(),
@@ -191,21 +167,15 @@ func NewApplication(siApp *si.AddApplicationRequest, ugi security.UserGroup, eve
 	app.rmID = rmID
 	app.appEvents = schedEvt.NewApplicationEvents(events.GetEventSystem())
 	app.appEvents.SendNewApplicationEvent(app.ApplicationID)
-	app.setNewMetrics()
 	return app
 }
 
-func (sa *Application) setNewMetrics() {
-	metrics.GetSchedulerMetrics().IncTotalApplicationsNew()
-	metrics.GetQueueMetrics(sa.GetQueuePath()).IncQueueApplicationsNew()
-}
-
 func (sa *Application) String() string {
 	if sa == nil {
 		return "application is nil"
 	}
 	return fmt.Sprintf("applicationID: %s, Partition: %s, SubmissionTime: %x, State: %s",
-		sa.ApplicationID, sa.Partition, sa.SubmissionTime, sa.stateMachine.Current())
+		sa.ApplicationID, sa.Partition, sa.GetSubmissionTime(), sa.stateMachine.Current())
 }
 
 func (sa *Application) SetState(state string) {
@@ -627,6 +597,9 @@ func (sa *Application) AddAllocationAsk(ask *Allocation) error {
 	if ask.IsAllocated() || resources.IsZero(ask.GetAllocatedResource()) {
 		return fmt.Errorf("invalid ask added to app %s: %v", sa.ApplicationID, ask)
 	}
+	if ask.createTime.Before(sa.submissionTime) {
+		sa.submissionTime = ask.createTime
+	}
 	delta := ask.GetAllocatedResource().Clone()
 
 	var oldAskResource *resources.Resource = nil
@@ -1473,6 +1446,7 @@ func (sa *Application) tryNodes(ask *Allocation, iterator NodeIterator) *Allocat
 	reserved := sa.reservations[allocKey]
 	var allocResult *AllocationResult
 	var predicateErrors map[string]int
+	tryNodeCycleStart := time.Now()
 	iterator.ForEachNode(func(node *Node) bool {
 		// skip the node if the node is not schedulable
 		if !node.IsSchedulable() {
@@ -1537,6 +1511,7 @@ func (sa *Application) tryNodes(ask *Allocation, iterator NodeIterator) *Allocat
 		}
 		return true
 	})
+	metrics.GetSchedulerMetrics().ObserveTryNodeEvaluation(tryNodeCycleStart)
 
 	if allocResult != nil {
 		return allocResult
@@ -1628,6 +1603,9 @@ func (sa *Application) SetQueue(queue *Queue) {
 	defer sa.Unlock()
 	sa.queuePath = queue.QueuePath
 	sa.queue = queue
+	// here we can make sure the queue is not empty
+	metrics.GetQueueMetrics(queue.QueuePath).IncQueueApplicationsNew()
+	metrics.GetSchedulerMetrics().IncTotalApplicationsNew()
 }
 
 // remove the leaf queue the application runs in, used when completing the app
@@ -1747,6 +1725,9 @@ func (sa *Application) addAllocationInternal(allocType AllocationResultType, all
 		sa.allocatedResource = resources.Add(sa.allocatedResource, alloc.GetAllocatedResource())
 		sa.maxAllocatedResource = resources.ComponentWiseMax(sa.allocatedResource, sa.maxAllocatedResource)
 	}
+	if alloc.createTime.Before(sa.submissionTime) {
+		sa.submissionTime = alloc.createTime
+	}
 	sa.appEvents.SendNewAllocationEvent(sa.ApplicationID, alloc.allocationKey, alloc.GetAllocatedResource())
 	sa.allocations[alloc.GetAllocationKey()] = alloc
 }
@@ -2115,21 +2096,58 @@ func (sa *Application) cleanupTrackedResource() {
 	sa.preemptedResource = nil
 }
 
-func (sa *Application) CleanupTrackedResource() {
+// GetApplicationSummary locked version to get the application summary
+// Exposed for test only
+func (sa *Application) GetApplicationSummary(rmID string) *ApplicationSummary {
+	sa.RLock()
+	defer sa.RUnlock()
+	return sa.getApplicationSummary(rmID)
+}
+
+func (sa *Application) getApplicationSummary(rmID string) *ApplicationSummary {
+	return &ApplicationSummary{
+		ApplicationID:       sa.ApplicationID,
+		SubmissionTime:      sa.submissionTime,
+		StartTime:           sa.startTime,
+		FinishTime:          sa.finishedTime,
+		User:                sa.user.User,
+		Queue:               sa.queuePath,
+		State:               sa.stateMachine.Current(),
+		RmID:                rmID,
+		ResourceUsage:       sa.usedResource.Clone(),
+		PreemptedResource:   sa.preemptedResource.Clone(),
+		PlaceholderResource: sa.placeholderResource.Clone(),
+	}
+}
+
+// LogAppSummary log the summary details for the application if it has run at any point in time.
+// The application summary only contains correct data when the application is in the Completed state.
+// Logging the data in any other state will show incomplete or inconsistent data.
+// After the data is logged the objects are cleaned up to lower overhead of Completed application tracking.
+func (sa *Application) LogAppSummary(rmID string) {
 	sa.Lock()
 	defer sa.Unlock()
+	if !sa.startTime.IsZero() {
+		appSummary := sa.getApplicationSummary(rmID)
+		appSummary.DoLogging()
+	}
 	sa.cleanupTrackedResource()
 }
 
-func (sa *Application) LogAppSummary(rmID string) {
-	if sa.startTime.IsZero() {
-		return
+// GetTrackedDAOMap returns the tracked resources type specified in which as a DAO similar to the normal resources.
+func (sa *Application) GetTrackedDAOMap(which string) map[string]map[string]int64 {
+	sa.RLock()
+	defer sa.RUnlock()
+	switch which {
+	case "usedResource":
+		return sa.usedResource.DAOMap()
+	case "preemptedResource":
+		return sa.preemptedResource.DAOMap()
+	case "placeholderResource":
+		return sa.placeholderResource.DAOMap()
+	default:
+		return map[string]map[string]int64{}
 	}
-	appSummary := sa.GetApplicationSummary(rmID)
-	appSummary.DoLogging()
-	appSummary.ResourceUsage = nil
-	appSummary.PreemptedResource = nil
-	appSummary.PlaceholderResource = nil
 }
 
 func (sa *Application) HasPlaceholderAllocation() bool {
@@ -2252,3 +2270,9 @@ func (sa *Application) getResourceFromTags(tag string) *resources.Resource {
 
 	return resource
 }
+
+func (sa *Application) GetSubmissionTime() time.Time {
+	sa.RLock()
+	defer sa.RUnlock()
+	return sa.submissionTime
+}
