@@ -41,14 +41,14 @@ func TestNewNode(t *testing.T) {
 	if node != nil {
 		t.Error("node not returned correctly: node is nul or incorrect name")
 	}
-	proto := newProto(testNode, nil, nil, nil)
+	proto := newProto(testNode, nil, nil)
 	node = NewNode(proto)
 	if node == nil || node.NodeID != testNode {
 		t.Error("node not returned correctly: node is nul or incorrect name")
 	}
 
 	totalRes := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 100, "second": 100})
-	proto = newProto(testNode, totalRes, nil, map[string]string{})
+	proto = newProto(testNode, totalRes, map[string]string{})
 	node = NewNode(proto)
 	if node == nil || node.NodeID != testNode {
 		t.Fatal("node not returned correctly: node is nul or incorrect name")
@@ -74,25 +74,20 @@ func TestNewNode(t *testing.T) {
 	assert.Equal(t, "rack1", node.Rackname)
 	assert.Equal(t, "partition1", node.Partition)
 
-	// test capacity/available/occupied resources
+	// test capacity/available resources
 	totalResources := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 100, "second": 100})
-	occupiedResources := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 30, "second": 20})
 	availableResources := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 70, "second": 80})
-	proto = newProto(testNode, totalResources, occupiedResources, map[string]string{})
+	proto = newProto(testNode, totalResources, map[string]string{})
 	node = NewNode(proto)
 	assert.Equal(t, node.NodeID, testNode, "node not returned correctly: node is nul or incorrect name")
 	if !resources.Equals(node.GetCapacity(), totalResources) {
 		t.Errorf("node total resources not set correctly: %v expected got %v",
 			totalResources, node.GetCapacity())
 	}
-	if !resources.Equals(node.GetAvailableResource(), availableResources) {
+	if !resources.Equals(node.GetAvailableResource(), totalResources) {
 		t.Errorf("node available resources not set correctly: %v expected got %v",
 			availableResources, node.GetAvailableResource())
 	}
-	if !resources.Equals(node.GetOccupiedResource(), occupiedResources) {
-		t.Errorf("node occupied resources not set correctly: %v expected got %v",
-			occupiedResources, node.GetOccupiedResource())
-	}
 }
 
 func TestCheckConditions(t *testing.T) {
@@ -350,7 +345,7 @@ func TestAttributes(t *testing.T) {
 		testname := fmt.Sprintf("Attributes in the node %d", index)
 		t.Run(testname, func(t *testing.T) {
 			nodename := fmt.Sprintf("%s-%d", testNode, index)
-			node := NewNode(newProto(nodename, nil, nil, tt.inputs))
+			node := NewNode(newProto(nodename, nil, tt.inputs))
 			if node == nil || node.NodeID != nodename {
 				t.Error("node not returned correctly: node is nul or incorrect name")
 			}
@@ -385,7 +380,7 @@ func TestAttributes(t *testing.T) {
 }
 
 func TestGetInstanceType(t *testing.T) {
-	proto := newProto(testNode, nil, nil, map[string]string{
+	proto := newProto(testNode, nil, map[string]string{
 		common.NodePartition: "partition1",
 		"label1":             "key1",
 		"label2":             "key2",
@@ -436,23 +431,54 @@ func TestAddAllocation(t *testing.T) {
 	assert.Assert(t, resources.IsZero(node.GetAllocatedResource()), "removal of half allocation should return to zero %v, got %v", node, node.GetAllocatedResource())
 }
 
-func TestTryAddAllocation(t *testing.T) {
+func TestAddForeignAllocation(t *testing.T) {
 	node := newNode("node-123", map[string]resources.Quantity{"first": 100, "second": 200})
 	if !resources.IsZero(node.GetAllocatedResource()) {
 		t.Fatal("Failed to initialize resource")
 	}
 
+	// check foreign alloc that is over quota
+	large := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 200})
+	falloc1 := newForeignAllocation("foreign-1", "node-123", large)
+	node.AddAllocation(falloc1)
+	assert.Assert(t, resources.Equals(large, node.GetOccupiedResource()), "invalid occupied resource - expected %v got %v",
+		large, node.GetOccupiedResource())
+	assert.Assert(t, resources.Equals(resources.Zero, node.GetAllocatedResource()), "allocated resource is not zero: %v", node.GetAllocatedResource())
+	assert.Assert(t, resources.Equals(resources.Zero, node.GetUtilizedResource()), "utilized resource is not zero: %v", node.GetUtilizedResource())
+	node.RemoveAllocation("foreign-1")
+
+	// check foreign alloc that is below quota
+	half := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 50, "second": 100})
+	falloc2 := newForeignAllocation("foreign-2", "node-123", half)
+	node.AddAllocation(falloc2)
+	assert.Assert(t, resources.Equals(half, node.GetOccupiedResource()), "invalid occupied resource - expected %v got %v",
+		large, node.GetOccupiedResource())
+	assert.Assert(t, resources.Equals(resources.Zero, node.GetAllocatedResource()), "allocated resource is not zero: %v", node.GetAllocatedResource())
+	assert.Assert(t, resources.Equals(resources.Zero, node.GetUtilizedResource()), "utilized resource is not zero: %v", node.GetUtilizedResource())
+}
+
+func TestTryAddAllocation(t *testing.T) {
+	node := newNode("node-123", map[string]resources.Quantity{"first": 100, "second": 200})
+	if !resources.IsZero(node.GetAllocatedResource()) {
+		t.Fatal("Failed to initialize resource")
+	}
+	listener := &testListener{}
+	node.AddListener(listener)
+
 	// check nil alloc
 	assert.Assert(t, !node.TryAddAllocation(nil), "nil allocation should not have been added: %v", node)
+	assert.Equal(t, 0, listener.updateCount, "unexpected listener update")
 	// check alloc that does not match
 	unknown := resources.NewResourceFromMap(map[string]resources.Quantity{"unknown": 1})
 	alloc := newAllocation(appID1, nodeID1, unknown)
 	assert.Assert(t, !node.TryAddAllocation(alloc), "unmatched resource type in allocation should not have been added: %v", node)
+	assert.Equal(t, 0, listener.updateCount, "unexpected listener update")
 
 	// allocate half of the resources available and check the calculation
 	half := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 50, "second": 100})
 	alloc = newAllocation(appID1, nodeID1, half)
 	assert.Assert(t, node.TryAddAllocation(alloc), "add allocation 1 should not have failed")
+	assert.Equal(t, 1, listener.updateCount, "listener update expected")
 	if node.GetAllocation(alloc.GetAllocationKey()) == nil {
 		t.Fatal("failed to add allocations: allocation not returned")
 	}
@@ -470,6 +496,7 @@ func TestTryAddAllocation(t *testing.T) {
 	piece := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 25, "second": 50})
 	alloc = newAllocation(appID1, nodeID1, piece)
 	assert.Assert(t, node.TryAddAllocation(alloc), "add allocation 2 should not have failed")
+	assert.Equal(t, 2, listener.updateCount, "listener update expected")
 	if node.GetAllocation(alloc.GetAllocationKey()) == nil {
 		t.Fatal("failed to add allocations: allocation not returned")
 	}
@@ -487,16 +514,59 @@ func TestTryAddAllocation(t *testing.T) {
 	}
 }
 
+func TestTryAddForeignAllocation(t *testing.T) {
+	node := newNode("node-123", map[string]resources.Quantity{"first": 100, "second": 200})
+	if !resources.IsZero(node.GetAllocatedResource()) {
+		t.Fatal("Failed to initialize resource")
+	}
+	listener := &testListener{}
+	node.AddListener(listener)
+
+	// first allocation - doesn't fit
+	fRes := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 200, "second": 200})
+	fAlloc1 := newForeignAllocation("foreign-1", "node-123", fRes)
+	assert.Assert(t, !node.TryAddAllocation(fAlloc1), "add allocation should have failed")
+	assert.Equal(t, 0, listener.updateCount, "unexpected listener update")
+	assert.Assert(t, resources.Equals(node.GetOccupiedResource(), resources.Zero), "occupied resource is not zero: %v", node.GetOccupiedResource())
+	assert.Assert(t, resources.Equals(node.GetAllocatedResource(), resources.Zero), "allocated resource is not zero: %v", node.GetAllocatedResource())
+	assert.Assert(t, resources.Equals(node.GetUtilizedResource(), resources.Zero), "utilized resource is not zero: %v", node.GetUtilizedResource())
+
+	// second allocation - fits
+	fRes = resources.NewResourceFromMap(map[string]resources.Quantity{"first": 20, "second": 20})
+	fAlloc2 := newForeignAllocation("foreign-2", "node-123", fRes)
+	assert.Assert(t, node.TryAddAllocation(fAlloc2), "add allocation should have succeeded")
+	assert.Equal(t, 0, listener.updateCount, "unexpected listener update")
+	assert.Assert(t, node.GetAllocation("foreign-2") != nil, "failed to add allocations: allocation foreign-2 not returned")
+	assert.Assert(t, resources.Equals(node.GetOccupiedResource(), fRes), "occupied resource is not zero: %v", node.GetOccupiedResource())
+	assert.Assert(t, resources.Equals(node.GetAllocatedResource(), resources.Zero), "allocated resource is not zero: %v", node.GetAllocatedResource())
+	assert.Assert(t, resources.Equals(node.GetUtilizedResource(), resources.Zero), "utilized resource is not zero: %v", node.GetUtilizedResource())
+
+	// third allocation - fits
+	fRes = resources.NewResourceFromMap(map[string]resources.Quantity{"first": 25, "second": 35})
+	fAlloc3 := newForeignAllocation("foreign-3", "node-123", fRes)
+	assert.Assert(t, node.TryAddAllocation(fAlloc3), "add allocation should have succeeded")
+	assert.Equal(t, 0, listener.updateCount, "unexpected listener update")
+	assert.Assert(t, node.GetAllocation("foreign-3") != nil, "failed to add allocations: allocation foreign-2 not returned")
+	expectedOccupied := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 45, "second": 55})
+	assert.Assert(t, resources.Equals(node.GetOccupiedResource(), expectedOccupied), "occupied resource calculation is invalid - expected %v got %v",
+		expectedOccupied, node.GetOccupiedResource())
+	assert.Assert(t, resources.Equals(node.GetAllocatedResource(), resources.Zero), "allocated resource is not zero: %v", node.GetAllocatedResource())
+	assert.Assert(t, resources.Equals(node.GetUtilizedResource(), resources.Zero), "utilized resource is not zero: %v", node.GetUtilizedResource())
+}
+
 func TestRemoveAllocation(t *testing.T) {
 	node := newNode("node-123", map[string]resources.Quantity{"first": 100, "second": 200})
 	if !resources.IsZero(node.GetAllocatedResource()) {
 		t.Fatal("Failed to initialize resource")
 	}
+	listener := &testListener{}
+	node.AddListener(listener)
 
 	// allocate half of the resources available and check the calculation
 	half := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 50, "second": 100})
 	alloc1 := newAllocation(appID1, nodeID1, half)
 	node.AddAllocation(alloc1)
+	assert.Equal(t, 1, listener.updateCount, "listener update expected")
 	if node.GetAllocation(alloc1.GetAllocationKey()) == nil {
 		t.Fatal("failed to add allocations: allocation not returned")
 	}
@@ -510,6 +580,8 @@ func TestRemoveAllocation(t *testing.T) {
 	if !resources.Equals(node.GetAllocatedResource(), half) {
 		t.Errorf("allocated resource not set correctly %v got %v", half, node.GetAllocatedResource())
 	}
+	assert.Equal(t, 1, listener.updateCount, "unexpected listener update for removal")
+	listener.updateCount = 0
 
 	// add second alloc and remove first check calculation
 	piece := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 25, "second": 50})
@@ -519,6 +591,8 @@ func TestRemoveAllocation(t *testing.T) {
 		t.Fatal("failed to add allocations: allocation not returned")
 	}
 	alloc := node.RemoveAllocation(alloc1.GetAllocationKey())
+	assert.Equal(t, 2, listener.updateCount, "update expected for add+removal")
+	listener.updateCount = 0
 	if alloc == nil {
 		t.Error("allocation should have been removed but was not")
 	}
@@ -533,6 +607,36 @@ func TestRemoveAllocation(t *testing.T) {
 	if !resources.Equals(node.GetUtilizedResource(), expectedUtilizedResource) {
 		t.Errorf("failed to get utilized resources expected %v, got %v", expectedUtilizedResource, node.GetUtilizedResource())
 	}
+	_ = node.RemoveAllocation(alloc2.GetAllocationKey())
+	assert.Equal(t, 1, listener.updateCount, "update expected for removal")
+	listener.updateCount = 0
+}
+
+func TestRemoveForeignAllocation(t *testing.T) {
+	node := newNode("node-123", map[string]resources.Quantity{"first": 100, "second": 200})
+	if !resources.IsZero(node.GetAllocatedResource()) {
+		t.Fatal("Failed to initialize resource")
+	}
+	listener := &testListener{}
+	node.AddListener(listener)
+
+	fRes := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 11, "second": 11})
+	fAlloc1 := newForeignAllocation("foreign-1", "node-123", fRes)
+	node.AddAllocation(fAlloc1)
+	assert.Assert(t, node.GetAllocation("foreign-1") != nil, "failed to add allocations: allocation foreign-1 not returned")
+	fAlloc2 := newForeignAllocation("foreign-2", "node-123", fRes)
+	node.AddAllocation(fAlloc2)
+	assert.Assert(t, node.GetAllocation("foreign-2") != nil, "failed to add allocations: allocation foreign-2 not returned")
+	node.RemoveAllocation("foreign-1")
+	assert.Equal(t, 0, listener.updateCount, "no update expected for foreign allocation add+removal")
+	expectedOccupied := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 11, "second": 11})
+	assert.Assert(t, resources.Equals(node.GetOccupiedResource(), expectedOccupied), "occupied resource calculation is invalid - expected %v got %v",
+		expectedOccupied, node.GetOccupiedResource())
+	expectedAvailable := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 89, "second": 189})
+	assert.Assert(t, resources.Equals(node.GetAvailableResource(), expectedAvailable), "available resource calculation is invalid - expected %v got %v",
+		expectedAvailable, node.GetAvailableResource())
+	assert.Assert(t, resources.Equals(node.GetAllocatedResource(), resources.Zero), "allocated resource calculation is invalid - expected zero got %v",
+		node.GetAllocatedResource())
 }
 
 func TestNodeReplaceAllocation(t *testing.T) {
@@ -601,29 +705,6 @@ func TestGetAllocation(t *testing.T) {
 	}
 }
 
-func TestGetAllocations(t *testing.T) {
-	node := newNode("node-123", map[string]resources.Quantity{"first": 100, "second": 200})
-	if !resources.IsZero(node.GetAllocatedResource()) {
-		t.Fatal("Failed to initialize resource")
-	}
-
-	// nothing allocated get an empty list
-	allocs := node.GetAllAllocations()
-	if allocs == nil || len(allocs) != 0 {
-		t.Fatalf("allocation length should be 0 on new node")
-	}
-	alloc1 := newAllocation(appID1, nodeID1, nil)
-	alloc2 := newAllocation(appID1, nodeID1, nil)
-
-	// allocate
-	node.AddAllocation(alloc1)
-	node.AddAllocation(alloc2)
-	assert.Equal(t, 2, len(node.GetAllAllocations()), "allocation length mismatch")
-	// This should not happen in real code just making sure the code does do what is expected
-	node.AddAllocation(alloc2)
-	assert.Equal(t, 2, len(node.GetAllAllocations()), "allocation length mismatch")
-}
-
 func TestSchedulingState(t *testing.T) {
 	node := newNode("node-123", nil)
 	if !node.IsSchedulable() {
@@ -725,8 +806,7 @@ func TestAddRemoveListener(t *testing.T) {
 func TestNodeEvents(t *testing.T) {
 	mockEvents := evtMock.NewEventSystem()
 	total := resources.NewResourceFromMap(map[string]resources.Quantity{"cpu": 100, "memory": 100})
-	occupied := resources.NewResourceFromMap(map[string]resources.Quantity{"cpu": 10, "memory": 10})
-	proto := newProto(testNode, total, occupied, map[string]string{
+	proto := newProto(testNode, total, map[string]string{
 		"ready": "true",
 	})
 	node := NewNode(proto)
@@ -840,8 +920,7 @@ func TestPreconditions(t *testing.T) {
 
 	plugins.RegisterSchedulerPlugin(mock.NewPredicatePlugin(true, map[string]int{}))
 	total := resources.NewResourceFromMap(map[string]resources.Quantity{"cpu": 100, "memory": 100})
-	occupied := resources.NewResourceFromMap(map[string]resources.Quantity{"cpu": 10, "memory": 10})
-	proto := newProto(testNode, total, occupied, map[string]string{
+	proto := newProto(testNode, total, map[string]string{
 		"ready": "true",
 	})
 	res := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 1})
@@ -860,3 +939,65 @@ func TestPreconditions(t *testing.T) {
 	assert.NilError(t, err)
 	assert.Equal(t, 1, len(ask.allocLog))
 }
+
+func TestGetAllocations(t *testing.T) {
+	node := newNode(nodeID1, map[string]resources.Quantity{"first": 100, "second": 200})
+	allocRes := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10, "second": 20})
+
+	// no allocations
+	assert.Equal(t, 0, len(node.GetForeignAllocations()))
+	assert.Equal(t, 0, len(node.GetYunikornAllocations()))
+
+	alloc1 := newAllocationWithKey(aKey, appID1, nodeID1, nil)
+	alloc2 := newAllocationWithKey(aKey2, appID1, nodeID1, nil)
+	alloc3 := newForeignAllocation(foreignAlloc1, nodeID1, allocRes)
+	alloc4 := newForeignAllocation(foreignAlloc2, nodeID1, allocRes)
+	node.AddAllocation(alloc1)
+	node.AddAllocation(alloc2)
+	node.AddAllocation(alloc3)
+	node.AddAllocation(alloc4)
+
+	t.Run("GetYunikornAllocations", func(t *testing.T) {
+		allocs := node.GetYunikornAllocations()
+		assert.Equal(t, 2, len(allocs))
+		m := map[string]bool{}
+		m[allocs[0].allocationKey] = true
+		m[allocs[1].allocationKey] = true
+		assert.Assert(t, m[aKey])
+		assert.Assert(t, m[aKey2])
+	})
+
+	t.Run("GetForeignAllocations", func(t *testing.T) {
+		allocs := node.GetForeignAllocations()
+		assert.Equal(t, 2, len(allocs))
+		m := map[string]bool{}
+		m[allocs[0].allocationKey] = true
+		m[allocs[1].allocationKey] = true
+		assert.Assert(t, m[foreignAlloc1])
+		assert.Assert(t, m[foreignAlloc2])
+	})
+}
+
+func TestUpdateForeignAllocation(t *testing.T) {
+	node := newNode(nodeID1, map[string]resources.Quantity{"first": 100, "second": 200})
+	allocRes := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10, "second": 20})
+	alloc := newForeignAllocation(foreignAlloc1, nodeID1, allocRes)
+	node.AddAllocation(alloc)
+
+	// update existing allocation
+	updatedRes := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 15, "second": 0})
+	allocUpd := newForeignAllocation(foreignAlloc1, nodeID1, updatedRes)
+	prev := node.UpdateForeignAllocation(allocUpd)
+	expectedOccupied := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 15})
+	expectedAvailable := resources.NewResourceFromMap(map[string]resources.Quantity{"first": 85, "second": 200})
+	assert.Assert(t, prev == alloc, "returned previous allocation is different")
+	assert.Assert(t, resources.Equals(node.GetOccupiedResource(), expectedOccupied), "occupied resource has been updated incorrectly")
+	assert.Assert(t, resources.Equals(node.GetAllocatedResource(), resources.Zero), "allocated resource has changed")
+	assert.Assert(t, resources.Equals(node.GetAvailableResource(), expectedAvailable), "avaiable resource has been updated incorrectly")
+
+	// update non-existing allocation
+	alloc2 := newForeignAllocation(foreignAlloc2, nodeID1, allocRes)
+	prev = node.UpdateForeignAllocation(alloc2)
+	assert.Assert(t, prev == nil, "unexpected previous allocation returned")
+	assert.Assert(t, node.GetAllocation(foreignAlloc2) == alloc2, "foreign allocation not found")
+}
