@@ -28,71 +28,108 @@ import (
 	"github.com/apache/yunikorn-scheduler-interface/lib/go/si"
 )
 
-func createAllocationAsk(allocationKey string, app string, allowPreemption bool, isOriginator bool, priority int32, res *resources.Resource) *AllocationAsk {
+func createAllocationAsk(allocationKey string, app string, allowPreemption bool, isOriginator bool, priority int32, res *resources.Resource) *Allocation {
 	tags := map[string]string{}
-	siAsk := &si.AllocationAsk{
+	siAsk := &si.Allocation{
 		AllocationKey:    allocationKey,
 		ApplicationID:    app,
 		PartitionName:    "default",
 		Priority:         priority,
-		ResourceAsk:      res.ToProto(),
+		ResourcePerAlloc: res.ToProto(),
 		Originator:       isOriginator,
 		PreemptionPolicy: &si.PreemptionPolicy{AllowPreemptSelf: allowPreemption, AllowPreemptOther: true},
-		Tags:             tags,
+		AllocationTags:   tags,
 	}
-	ask := NewAllocationAskFromSI(siAsk)
+	ask := NewAllocationFromSI(siAsk)
 	return ask
 }
 
-func prepareAllocationAsks(node *Node) {
+func createAllocation(allocationKey string, app string, nodeID string, allowPreemption bool, isOriginator bool, priority int32, res *resources.Resource) *Allocation {
+	tags := map[string]string{}
+	siAsk := &si.Allocation{
+		AllocationKey:    allocationKey,
+		ApplicationID:    app,
+		PartitionName:    "default",
+		Priority:         priority,
+		ResourcePerAlloc: res.ToProto(),
+		Originator:       isOriginator,
+		PreemptionPolicy: &si.PreemptionPolicy{AllowPreemptSelf: allowPreemption, AllowPreemptOther: true},
+		AllocationTags:   tags,
+		NodeID:           nodeID,
+	}
+	ask := NewAllocationFromSI(siAsk)
+	return ask
+}
+
+func prepareAllocationAsks(t *testing.T, node *Node) []*Allocation {
 	createTime := time.Now()
 
+	result := make([]*Allocation, 0)
+
 	// regular pods
-	ask1 := createAllocationAsk("ask1", "app1", true, false, 10,
+	alloc1 := createAllocation("ask1", "app1", node.NodeID, true, false, 10,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10}))
-	node.AddAllocation(NewAllocation(node.NodeID, ask1))
+	assert.Assert(t, node.TryAddAllocation(alloc1))
+	result = append(result, alloc1)
 
-	ask2 := createAllocationAsk("ask2", "app1", true, false, 10,
+	alloc2 := createAllocation("ask2", "app1", node.NodeID, true, false, 10,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 8}))
-	ask2.createTime = createTime
-	node.AddAllocation(NewAllocation(node.NodeID, ask2))
+	alloc2.createTime = createTime
+	assert.Assert(t, node.TryAddAllocation(alloc2))
+	result = append(result, alloc2)
 
-	ask3 := createAllocationAsk("ask3", "app1", true, false, 15,
+	alloc3 := createAllocation("ask3", "app1", node.NodeID, true, false, 15,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10}))
-	node.AddAllocation(NewAllocation(node.NodeID, ask3))
+	assert.Assert(t, node.TryAddAllocation(alloc3))
+	result = append(result, alloc3)
 
-	ask4 := createAllocationAsk("ask4", "app1", true, false, 10,
+	alloc4 := createAllocation("ask4", "app1", node.NodeID, true, false, 10,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
-	ask4.createTime = createTime
-	node.AddAllocation(NewAllocation(node.NodeID, ask4))
+	alloc4.createTime = createTime
+	assert.Assert(t, node.TryAddAllocation(alloc4))
+	result = append(result, alloc4)
 
-	ask5 := createAllocationAsk("ask5", "app1", true, false, 5,
+	alloc5 := createAllocation("ask5", "app1", node.NodeID, true, false, 5,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
-	node.AddAllocation(NewAllocation(node.NodeID, ask5))
+	assert.Assert(t, node.TryAddAllocation(alloc5))
+	result = append(result, alloc5)
 
 	// opted out pods
-	ask6 := createAllocationAsk("ask6", "app1", false, false, 10,
+	alloc6 := createAllocation("ask6", "app1", node.NodeID, false, false, 10,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10}))
-	node.AddAllocation(NewAllocation(node.NodeID, ask6))
+	assert.Assert(t, node.TryAddAllocation(alloc6))
+	result = append(result, alloc6)
 
-	ask7 := createAllocationAsk("ask7", "app1", false, false, 10,
+	alloc7 := createAllocation("ask7", "app1", node.NodeID, false, false, 10,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 8}))
-	ask7.createTime = createTime
-	node.AddAllocation(NewAllocation(node.NodeID, ask7))
+	alloc7.createTime = createTime
+	assert.Assert(t, node.TryAddAllocation(alloc7))
+	result = append(result, alloc7)
 
-	ask8 := createAllocationAsk("ask8", "app1", false, false, 15,
+	alloc8 := createAllocation("ask8", "app1", node.NodeID, false, false, 15,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 10}))
-	node.AddAllocation(NewAllocation(node.NodeID, ask8))
+	assert.Assert(t, node.TryAddAllocation(alloc8))
+	result = append(result, alloc8)
 
 	// driver/owner pods
-	ask9 := createAllocationAsk("ask9", "app1", false, true, 10,
+	alloc9 := createAllocation("ask9", "app1", node.NodeID, false, true, 10,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
-	ask9.createTime = createTime
-	node.AddAllocation(NewAllocation(node.NodeID, ask9))
+	alloc9.createTime = createTime
+	assert.Assert(t, node.TryAddAllocation(alloc9))
+	result = append(result, alloc9)
 
-	ask10 := createAllocationAsk("ask10", "app1", true, true, 5,
+	alloc10 := createAllocation("ask10", "app1", node.NodeID, true, true, 5,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
-	node.AddAllocation(NewAllocation(node.NodeID, ask10))
+	assert.Assert(t, node.TryAddAllocation(alloc10))
+	result = append(result, alloc10)
+
+	return result
+}
+
+func removeAllocationAsks(node *Node, asks []*Allocation) {
+	for _, ask := range asks {
+		node.RemoveAllocation(ask.GetAllocationKey())
+	}
 }
 
 // regular pods
@@ -124,10 +161,9 @@ func TestSortAllocations(t *testing.T) {
 
 	requiredAsk := createAllocationAsk("ask", "app1", true, true, 20,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
-	requiredAsk.pendingAskRepeat = 5
 
 	p := NewRequiredNodePreemptor(node, requiredAsk)
-	prepareAllocationAsks(node)
+	asks := prepareAllocationAsks(t, node)
 	p.filterAllocations()
 	p.sortAllocations()
 	sortedAsks := p.getAllocations()
@@ -147,6 +183,8 @@ func TestSortAllocations(t *testing.T) {
 	// assert driver/owner pods
 	assert.Equal(t, sortedAsks[8].GetAllocationKey(), "ask10")
 	assert.Equal(t, sortedAsks[9].GetAllocationKey(), "ask9")
+
+	removeAllocationAsks(node, asks)
 }
 
 func TestFilterAllocations(t *testing.T) {
@@ -162,38 +200,41 @@ func TestFilterAllocations(t *testing.T) {
 	requiredAsk := createAllocationAsk("ask12", "app1", true, true, 20,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"second": 5}))
 	p := NewRequiredNodePreemptor(node, requiredAsk)
-	prepareAllocationAsks(node)
+	asks := prepareAllocationAsks(t, node)
 	p.filterAllocations()
 	filteredAllocations := p.getAllocations()
 
 	// allocations are not even considered as there is no match. of course, no victims
 	assert.Equal(t, len(filteredAllocations), 0)
+	removeAllocationAsks(node, asks)
 
 	// case 2: allocations are available but priority is higher than ds request priority, hence no allocations considered
 	requiredAsk1 := createAllocationAsk("ask12", "app1", true, true, 1,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
 	p1 := NewRequiredNodePreemptor(node, requiredAsk1)
-	prepareAllocationAsks(node)
+	asks = prepareAllocationAsks(t, node)
 	p1.filterAllocations()
 	filteredAllocations = p.getAllocations()
 
 	// allocations are not even considered as there is no match. of course, no victims
 	assert.Equal(t, len(filteredAllocations), 0)
+	removeAllocationAsks(node, asks)
 
 	// case 3: victims are available as there are allocations with lower priority and resource match
 	requiredAsk2 := createAllocationAsk("ask12", "app1", true, true, 20,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
 	p2 := NewRequiredNodePreemptor(node, requiredAsk2)
-	prepareAllocationAsks(node)
+	asks = prepareAllocationAsks(t, node)
 	p2.filterAllocations()
 	filteredAllocations = p2.getAllocations()
 	assert.Equal(t, len(filteredAllocations), 10)
+	removeAllocationAsks(node, asks)
 
 	// case 4: allocation has preempted
 	requiredAsk3 := createAllocationAsk("ask12", "app1", true, true, 20,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
 	p3 := NewRequiredNodePreemptor(node, requiredAsk3)
-	prepareAllocationAsks(node)
+	asks = prepareAllocationAsks(t, node)
 	p3.filterAllocations()
 	p3.sortAllocations()
 
@@ -204,6 +245,7 @@ func TestFilterAllocations(t *testing.T) {
 	p3.filterAllocations()
 	filteredAllocations = p3.getAllocations()
 	assert.Equal(t, len(filteredAllocations), 19)
+	removeAllocationAsks(node, asks)
 }
 
 func TestGetVictims(t *testing.T) {
@@ -220,7 +262,7 @@ func TestGetVictims(t *testing.T) {
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 25}))
 
 	p := NewRequiredNodePreemptor(node, requiredAsk)
-	prepareAllocationAsks(node)
+	asks := prepareAllocationAsks(t, node)
 	p.filterAllocations()
 	p.sortAllocations()
 	victims := p.GetVictims()
@@ -233,22 +275,24 @@ func TestGetVictims(t *testing.T) {
 	assert.Equal(t, resources.Equals(victims[2].GetAllocatedResource(), resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5})), true)
 	assert.Equal(t, victims[3].GetAllocationKey(), "ask2")
 	assert.Equal(t, resources.Equals(victims[3].GetAllocatedResource(), resources.NewResourceFromMap(map[string]resources.Quantity{"first": 8})), true)
+	removeAllocationAsks(node, asks)
 
 	// case 2: victims are available and its resources are matching with ds request ask (but with different quantity)
 	requiredAsk2 := createAllocationAsk("ask13", "app1", true, true, 20,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5}))
 	p2 := NewRequiredNodePreemptor(node, requiredAsk2)
-	prepareAllocationAsks(node)
+	asks = prepareAllocationAsks(t, node)
 	p2.filterAllocations()
 	p2.sortAllocations()
 	victims2 := p2.GetVictims()
 	assert.Equal(t, len(victims2), 1)
+	removeAllocationAsks(node, asks)
 
 	// case 3: allocations are available and its resources are matching partially with ds request ask (because of different resource types), hence no victims
 	requiredAsk3 := createAllocationAsk("ask13", "app1", true, true, 20,
 		resources.NewResourceFromMap(map[string]resources.Quantity{"first": 5, "second": 5}))
 	p3 := NewRequiredNodePreemptor(node, requiredAsk3)
-	prepareAllocationAsks(node)
+	asks = prepareAllocationAsks(t, node)
 	p3.filterAllocations()
 	filteredAllocations := p3.getAllocations()
 
@@ -259,4 +303,5 @@ func TestGetVictims(t *testing.T) {
 	// allocations are available but no exact match for choosing victims
 	victims3 := p3.GetVictims()
 	assert.Equal(t, len(victims3), 0)
+	removeAllocationAsks(node, asks)
 }
