@@ -100,17 +100,15 @@ func sortQueuesByFairnessAndPriority(queues []*Queue, fairMaxResources []*resour
 
 func sortApplications(apps map[string]*Application, sortType policies.SortPolicy, considerPriority bool, globalResource *resources.Resource) []*Application {
 	sortingStart := time.Now()
-	var sortedApps []*Application
+	sortedApps := filterOnPendingResources(apps)
 	switch sortType {
 	case policies.FairSortPolicy:
-		sortedApps = filterOnPendingResources(apps)
 		if considerPriority {
 			sortApplicationsByPriorityAndFairness(sortedApps, globalResource)
 		} else {
 			sortApplicationsByFairnessAndPriority(sortedApps, globalResource)
 		}
 	case policies.FifoSortPolicy:
-		sortedApps = filterOnPendingResources(apps)
 		if considerPriority {
 			sortApplicationsByPriorityAndSubmissionTime(sortedApps)
 		} else {
@@ -152,10 +150,12 @@ func sortApplicationsBySubmissionTimeAndPriority(sortedApps []*Application) {
 	sort.SliceStable(sortedApps, func(i, j int) bool {
 		l := sortedApps[i]
 		r := sortedApps[j]
-		if l.SubmissionTime.Before(r.SubmissionTime) {
+		lSubTime := l.GetSubmissionTime()
+		rSubTime := r.GetSubmissionTime()
+		if lSubTime.Before(rSubTime) {
 			return true
 		}
-		if r.SubmissionTime.Before(l.SubmissionTime) {
+		if rSubTime.Before(lSubTime) {
 			return false
 		}
 		return l.GetAskMaxPriority() > r.GetAskMaxPriority()
@@ -174,7 +174,7 @@ func sortApplicationsByPriorityAndSubmissionTime(sortedApps []*Application) {
 		if leftPriority < rightPriority {
 			return false
 		}
-		return l.SubmissionTime.Before(r.SubmissionTime)
+		return l.GetSubmissionTime().Before(r.GetSubmissionTime())
 	})
 }
 
