@@ -65,6 +65,7 @@ type PartitionContext struct {
 	reservations           int                             // number of reservations
 	placeholderAllocations int                             // number of placeholder allocations
 	preemptionEnabled      bool                            // whether preemption is enabled or not
+	foreignAllocs          map[string]*objects.Allocation  // foreign (non-Yunikorn) allocations
 
 	// The partition write lock must not be held while manipulating an application.
 	// Scheduling is running continuously as a lock free background task. Scheduling an application
@@ -78,7 +79,7 @@ type PartitionContext struct {
 	locking.RWMutex
 }
 
-func newPartitionContext(conf configs.PartitionConfig, rmID string, cc *ClusterContext) (*PartitionContext, error) {
+func newPartitionContext(conf configs.PartitionConfig, rmID string, cc *ClusterContext, silence bool) (*PartitionContext, error) {
 	if conf.Name == "" || rmID == "" {
 		log.Log(log.SchedPartition).Info("partition cannot be created",
 			zap.String("partition name", conf.Name),
@@ -94,17 +95,19 @@ func newPartitionContext(conf configs.PartitionConfig, rmID string, cc *ClusterC
 		applications:          make(map[string]*objects.Application),
 		completedApplications: make(map[string]*objects.Application),
 		nodes:                 objects.NewNodeCollection(conf.Name),
+		foreignAllocs:         make(map[string]*objects.Allocation),
 	}
 	pc.partitionManager = newPartitionManager(pc, cc)
-	if err := pc.initialPartitionFromConfig(conf); err != nil {
+	if err := pc.initialPartitionFromConfig(conf, silence); err != nil {
 		return nil, err
 	}
 
 	return pc, nil
 }
 
-// Initialise the partition
-func (pc *PartitionContext) initialPartitionFromConfig(conf configs.PartitionConfig) error {
+// Initialise the partition.
+// If the silence flag is set to true, the function will not log queue creation or node sorting policy, update limit settings, or send a queue event.
+func (pc *PartitionContext) initialPartitionFromConfig(conf configs.PartitionConfig, silence bool) error {
 	if len(conf.Queues) == 0 || conf.Queues[0].Name != configs.RootQueue {
 		return fmt.Errorf("partition cannot be created without root queue")
 	}
@@ -113,38 +116,45 @@ func (pc *PartitionContext) initialPartitionFromConfig(conf configs.PartitionCon
 	// Add the rest of the queue structure recursively
 	queueConf := conf.Queues[0]
 	var err error
-	if pc.root, err = objects.NewConfiguredQueue(queueConf, nil); err != nil {
+	if pc.root, err = objects.NewConfiguredQueue(queueConf, nil, silence); err != nil {
 		return err
 	}
 	// recursively add the queues to the root
-	if err = pc.addQueue(queueConf.Queues, pc.root); err != nil {
+	if err = pc.addQueue(queueConf.Queues, pc.root, silence); err != nil {
 		return err
 	}
-	log.Log(log.SchedPartition).Info("root queue added",
-		zap.String("partitionName", pc.Name),
-		zap.String("rmID", pc.RmID))
+
+	if !silence {
+		log.Log(log.SchedPartition).Info("root queue added",
+			zap.String("partitionName", pc.Name),
+			zap.String("rmID", pc.RmID))
+	}
 
 	// We need to pass in the locked version of the GetQueue function.
 	// Placing an application will not have a lock on the partition context.
-	pc.placementManager = placement.NewPlacementManager(conf.PlacementRules, pc.GetQueue)
+	pc.placementManager = placement.NewPlacementManager(conf.PlacementRules, pc.GetQueue, silence)
 	// get the user group cache for the partition
 	pc.userGroupCache = security.GetUserGroupCache("")
-	pc.updateNodeSortingPolicy(conf)
+	pc.updateNodeSortingPolicy(conf, silence)
 	pc.updatePreemption(conf)
 
 	// update limit settings: start at the root
-	return ugm.GetUserManager().UpdateConfig(queueConf, conf.Queues[0].Name)
+	if !silence {
+		return ugm.GetUserManager().UpdateConfig(queueConf, conf.Queues[0].Name)
+	}
+	return nil
 }
 
 // NOTE: this is a lock free call. It should only be called holding the PartitionContext lock.
-func (pc *PartitionContext) updateNodeSortingPolicy(conf configs.PartitionConfig) {
+// If the silence flag is set to true, the function will not log when setting the node sorting policy.
+func (pc *PartitionContext) updateNodeSortingPolicy(conf configs.PartitionConfig, silence bool) {
 	var configuredPolicy policies.SortingPolicy
 	configuredPolicy, err := policies.SortingPolicyFromString(conf.NodeSortPolicy.Type)
 	if err != nil {
 		log.Log(log.SchedPartition).Debug("NodeSorting policy incorrectly set or unknown",
 			zap.Error(err))
 		log.Log(log.SchedPartition).Info(fmt.Sprintf("NodeSorting policy not set using '%s' as default", configuredPolicy))
-	} else {
+	} else if !silence {
 		log.Log(log.SchedPartition).Info("NodeSorting policy set from config",
 			zap.Stringer("policyName", configuredPolicy))
 	}
@@ -168,7 +178,7 @@ func (pc *PartitionContext) updatePartitionDetails(conf configs.PartitionConfig)
 		log.Log(log.SchedPartition).Info("New placement rules not activated, config reload failed", zap.Error(err))
 		return err
 	}
-	pc.updateNodeSortingPolicy(conf)
+	pc.updateNodeSortingPolicy(conf, false)
 
 	pc.Lock()
 	defer pc.Unlock()
@@ -189,17 +199,18 @@ func (pc *PartitionContext) updatePartitionDetails(conf configs.PartitionConfig)
 	return ugm.GetUserManager().UpdateConfig(queueConf, conf.Queues[0].Name)
 }
 
-// Process the config structure and create a queue info tree for this partition
-func (pc *PartitionContext) addQueue(conf []configs.QueueConfig, parent *objects.Queue) error {
+// Process the config structure and create a queue info tree for this partition.
+// If the silence flag is set to true, the function will neither log the queue creation nor send a queue event.
+func (pc *PartitionContext) addQueue(conf []configs.QueueConfig, parent *objects.Queue, silence bool) error {
 	// create the queue at this level
 	for _, queueConf := range conf {
-		thisQueue, err := objects.NewConfiguredQueue(queueConf, parent)
+		thisQueue, err := objects.NewConfiguredQueue(queueConf, parent, silence)
 		if err != nil {
 			return err
 		}
 		// recursive create the queues below
 		if len(queueConf.Queues) > 0 {
-			err = pc.addQueue(queueConf.Queues, thisQueue)
+			err = pc.addQueue(queueConf.Queues, thisQueue, silence)
 			if err != nil {
 				return err
 			}
@@ -222,7 +233,7 @@ func (pc *PartitionContext) updateQueues(config []configs.QueueConfig, parent *o
 		queue := pc.getQueueInternal(pathName)
 		var err error
 		if queue == nil {
-			queue, err = objects.NewConfiguredQueue(queueConfig, parent)
+			queue, err = objects.NewConfiguredQueue(queueConfig, parent, false)
 		} else {
 			err = queue.ApplyConf(queueConfig)
 		}
@@ -345,10 +356,7 @@ func (pc *PartitionContext) AddApplication(app *objects.Application) error {
 	maxApps := app.GetMaxApps()
 	if !isRecoveryQueue && (guaranteedRes != nil || maxRes != nil || maxApps != 0) {
 		// set resources based on tags, but only if the queue is dynamic (unmanaged)
-		if queue.IsManaged() {
-			log.Log(log.SchedQueue).Warn("Trying to set resources on a queue that is not an unmanaged leaf",
-				zap.String("queueName", queue.QueuePath))
-		} else {
+		if !queue.IsManaged() {
 			if maxApps != 0 {
 				queue.SetMaxRunningApps(maxApps)
 			}
@@ -670,7 +678,7 @@ func (pc *PartitionContext) removeNodeAllocations(node *objects.Node) ([]*object
 	released := make([]*objects.Allocation, 0)
 	confirmed := make([]*objects.Allocation, 0)
 	// walk over all allocations still registered for this node
-	for _, alloc := range node.GetAllAllocations() {
+	for _, alloc := range node.GetYunikornAllocations() {
 		allocationKey := alloc.GetAllocationKey()
 		// since we are not locking the node and or application we could have had an update while processing
 		// note that we do not return the allocation if the app or allocation is not found and assume that it
@@ -805,7 +813,7 @@ func (pc *PartitionContext) tryAllocate() *objects.AllocationResult {
 		return nil
 	}
 	// try allocating from the root down
-	result := pc.root.TryAllocate(pc.GetNodeIterator, pc.GetFullNodeIterator, pc.GetNode, pc.isPreemptionEnabled())
+	result := pc.root.TryAllocate(pc.GetNodeIterator, pc.GetFullNodeIterator, pc.GetNode, pc.IsPreemptionEnabled())
 	if result != nil {
 		return pc.allocate(result)
 	}
@@ -1150,12 +1158,17 @@ func (pc *PartitionContext) UpdateAllocation(alloc *objects.Allocation) (request
 	allocationKey := alloc.GetAllocationKey()
 	applicationID := alloc.GetApplicationID()
 	nodeID := alloc.GetNodeID()
+	node := pc.GetNode(alloc.GetNodeID())
 
 	log.Log(log.SchedPartition).Info("processing allocation",
 		zap.String("partitionName", pc.Name),
 		zap.String("appID", applicationID),
 		zap.String("allocationKey", allocationKey))
 
+	if alloc.IsForeign() {
+		return pc.handleForeignAllocation(allocationKey, applicationID, nodeID, node, alloc)
+	}
+
 	// find application
 	app := pc.getApplication(alloc.GetApplicationID())
 	if app == nil {
@@ -1165,10 +1178,8 @@ func (pc *PartitionContext) UpdateAllocation(alloc *objects.Allocation) (request
 	queue := app.GetQueue()
 
 	// find node if one is specified
-	var node *objects.Node = nil
 	allocated := alloc.IsAllocated()
 	if allocated {
-		node = pc.GetNode(alloc.GetNodeID())
 		if node == nil {
 			metrics.GetSchedulerMetrics().IncSchedulingError()
 			return false, false, fmt.Errorf("failed to find node %s", nodeID)
@@ -1305,12 +1316,60 @@ func (pc *PartitionContext) UpdateAllocation(alloc *objects.Allocation) (request
 	return false, false, nil
 }
 
+func (pc *PartitionContext) handleForeignAllocation(allocationKey, applicationID, nodeID string, node *objects.Node, alloc *objects.Allocation) (requestCreated bool, allocCreated bool, err error) {
+	allocated := alloc.IsAllocated()
+	if !allocated {
+		return false, false, fmt.Errorf("trying to add a foreign request (non-allocation) %s", allocationKey)
+	}
+	if alloc.GetNodeID() == "" {
+		return false, false, fmt.Errorf("node ID is empty for allocation %s", allocationKey)
+	}
+	if node == nil {
+		return false, false, fmt.Errorf("failed to find node %s for allocation %s", nodeID, allocationKey)
+	}
+
+	exists := pc.getOrStoreForeignAlloc(alloc)
+	if !exists {
+		log.Log(log.SchedPartition).Info("handling new foreign allocation",
+			zap.String("partitionName", pc.Name),
+			zap.String("nodeID", nodeID),
+			zap.String("allocationKey", allocationKey))
+		node.AddAllocation(alloc)
+		return false, true, nil
+	}
+
+	log.Log(log.SchedPartition).Info("handling foreign allocation update",
+		zap.String("partitionName", pc.Name),
+		zap.String("appID", applicationID),
+		zap.String("allocationKey", allocationKey))
+	prev := node.UpdateForeignAllocation(alloc)
+	if prev == nil {
+		log.Log(log.SchedPartition).Warn("BUG: previous allocation not found during update",
+			zap.String("allocationKey", allocationKey))
+	}
+
+	return false, false, nil
+}
+
 func (pc *PartitionContext) convertUGI(ugi *si.UserGroupInformation, forced bool) (security.UserGroup, error) {
 	pc.RLock()
 	defer pc.RUnlock()
 	return pc.userGroupCache.ConvertUGI(ugi, forced)
 }
 
+// getOrStoreForeignAlloc returns whether the allocation already exists or stores it if it's new
+func (pc *PartitionContext) getOrStoreForeignAlloc(alloc *objects.Allocation) bool {
+	pc.Lock()
+	defer pc.Unlock()
+	allocKey := alloc.GetAllocationKey()
+	existing := pc.foreignAllocs[allocKey]
+	if existing == nil {
+		pc.foreignAllocs[allocKey] = alloc
+		return false
+	}
+	return true
+}
+
 // calculate overall nodes resource usage and returns a map as the result,
 // where the key is the resource name, e.g memory, and the value is a []int,
 // which is a slice with 10 elements,
@@ -1394,6 +1453,10 @@ func (pc *PartitionContext) removeAllocation(release *si.AllocationRelease) ([]*
 	}
 	appID := release.ApplicationID
 	allocationKey := release.GetAllocationKey()
+	if appID == "" {
+		pc.removeForeignAllocation(allocationKey)
+		return nil, nil
+	}
 	app := pc.getApplication(appID)
 	// no app nothing to do everything should already be clean
 	if app == nil {
@@ -1521,6 +1584,31 @@ func (pc *PartitionContext) updatePhAllocationCount(released []*objects.Allocati
 	}
 }
 
+func (pc *PartitionContext) removeForeignAllocation(allocID string) {
+	pc.Lock()
+	defer pc.Unlock()
+	alloc := pc.foreignAllocs[allocID]
+	delete(pc.foreignAllocs, allocID)
+	if alloc == nil {
+		log.Log(log.SchedPartition).Debug("Tried to remove a non-existing foreign allocation",
+			zap.String("allocationID", allocID))
+		return
+	}
+
+	nodeID := alloc.GetNodeID()
+	node := pc.GetNode(nodeID)
+	if node == nil {
+		log.Log(log.SchedPartition).Debug("Node not found for foreign allocation",
+			zap.String("allocationID", allocID),
+			zap.String("nodeID", nodeID))
+		return
+	}
+	log.Log(log.SchedPartition).Info("Removing foreign allocation",
+		zap.String("allocationID", allocID),
+		zap.String("nodeID", nodeID))
+	node.RemoveAllocation(allocID)
+}
+
 func (pc *PartitionContext) GetCurrentState() string {
 	return pc.stateMachine.Current()
 }
@@ -1541,7 +1629,7 @@ func (pc *PartitionContext) GetNodeSortingResourceWeights() map[string]float64 {
 	return policy.ResourceWeights()
 }
 
-func (pc *PartitionContext) isPreemptionEnabled() bool {
+func (pc *PartitionContext) IsPreemptionEnabled() bool {
 	pc.RLock()
 	defer pc.RUnlock()
 	return pc.preemptionEnabled
@@ -1562,7 +1650,6 @@ func (pc *PartitionContext) moveTerminatedApp(appID string) {
 		zap.String("appID", appID),
 		zap.String("app status", app.CurrentState()))
 	app.LogAppSummary(pc.RmID)
-	app.CleanupTrackedResource()
 	pc.Lock()
 	defer pc.Unlock()
 	delete(pc.applications, appID)
