@@ -19,6 +19,7 @@
 package tests
 
 import (
+	"fmt"
 	"strconv"
 	"testing"
 	"time"
@@ -32,19 +33,22 @@ import (
 	"github.com/apache/yunikorn-scheduler-interface/lib/go/si"
 )
 
-const configDataSmokeTest = `
+const (
+	configDataSmokeTest = `
 partitions:
   - name: default
     queues:
       - name: root
         submitacl: "*"
         queues:
-          - name: singleleaf
+          - name: leaf
             resources:
               max:
                 memory: 150M
                 vcore: 20
 `
+	leafName = "root.leaf"
+)
 
 // Test scheduler reconfiguration
 func TestConfigScheduler(t *testing.T) {
@@ -117,7 +121,7 @@ partitions:
 	assert.NilError(t, err, "configuration reload failed")
 
 	// wait until configuration is reloaded
-	if err = common.WaitFor(time.Second, 5*time.Second, func() bool {
+	if err = common.WaitForCondition(time.Second, 5*time.Second, func() bool {
 		return configs.ConfigContext.Get("policygroup").Checksum != configChecksum
 	}); err != nil {
 		t.Errorf("timeout waiting for configuration to be reloaded: %v", err)
@@ -156,6 +160,8 @@ partitions:
 }
 
 // Test basic interactions from rm proxy to cache and to scheduler.
+//
+//nolint:funlen
 func TestBasicScheduler(t *testing.T) {
 	// Register RM
 	// Start all tests
@@ -165,7 +171,6 @@ func TestBasicScheduler(t *testing.T) {
 	err := ms.Init(configDataSmokeTest, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
-	leafName := "root.singleleaf"
 	// Check queues of cache and scheduler.
 	part := ms.scheduler.GetClusterContext().GetPartition(partition)
 	assert.Assert(t, part.GetTotalPartitionResource() == nil, "partition info max resource nil")
@@ -230,17 +235,26 @@ func TestBasicScheduler(t *testing.T) {
 	assert.Equal(t, app01.CurrentState(), objects.New.String())
 
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
+		Allocations: []*si.Allocation{
 			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
+				AllocationKey: "alloc-1a",
+				ResourcePerAlloc: &si.Resource{
 					Resources: map[string]*si.Quantity{
 						"memory": {Value: 10000000},
 						"vcore":  {Value: 1000},
 					},
 				},
-				MaxAllocations: 2,
-				ApplicationID:  appID1,
+				ApplicationID: appID1,
+			},
+			{
+				AllocationKey: "alloc-1b",
+				ResourcePerAlloc: &si.Resource{
+					Resources: map[string]*si.Quantity{
+						"memory": {Value: 10000000},
+						"vcore":  {Value: 1000},
+					},
+				},
+				ApplicationID: appID1,
 			},
 		},
 		RmID: "rm:123",
@@ -274,30 +288,48 @@ func TestBasicScheduler(t *testing.T) {
 	// Check allocated resources of nodes
 	waitForAllocatedNodeResource(t, ms.scheduler.GetClusterContext(), ms.partitionName, []string{"node-1:1234", "node-2:1234"}, 20000000, 1000)
 
-	// ask for two more resources
+	// ask for 4 more tasks
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
+		Allocations: []*si.Allocation{
 			{
-				AllocationKey: "alloc-2",
-				ResourceAsk: &si.Resource{
+				AllocationKey: "alloc-2a",
+				ResourcePerAlloc: &si.Resource{
 					Resources: map[string]*si.Quantity{
 						"memory": {Value: 50000000},
 						"vcore":  {Value: 5000},
 					},
 				},
-				MaxAllocations: 2,
-				ApplicationID:  appID1,
+				ApplicationID: appID1,
 			},
 			{
-				AllocationKey: "alloc-3",
-				ResourceAsk: &si.Resource{
+				AllocationKey: "alloc-2b",
+				ResourcePerAlloc: &si.Resource{
+					Resources: map[string]*si.Quantity{
+						"memory": {Value: 50000000},
+						"vcore":  {Value: 5000},
+					},
+				},
+				ApplicationID: appID1,
+			},
+			{
+				AllocationKey: "alloc-3a",
+				ResourcePerAlloc: &si.Resource{
 					Resources: map[string]*si.Quantity{
 						"memory": {Value: 100000000},
 						"vcore":  {Value: 5000},
 					},
 				},
-				MaxAllocations: 2,
-				ApplicationID:  appID1,
+				ApplicationID: appID1,
+			},
+			{
+				AllocationKey: "alloc-3b",
+				ResourcePerAlloc: &si.Resource{
+					Resources: map[string]*si.Quantity{
+						"memory": {Value: 100000000},
+						"vcore":  {Value: 5000},
+					},
+				},
+				ApplicationID: appID1,
 			},
 		},
 		RmID: "rm:123",
@@ -338,7 +370,7 @@ func TestBasicScheduler(t *testing.T) {
 	// Release all allocations
 	for _, v := range ms.mockRM.getAllocations() {
 		updateRequest.Releases.AllocationsToRelease = append(updateRequest.Releases.AllocationsToRelease, &si.AllocationRelease{
-			AllocationID:  v.AllocationID,
+			AllocationKey: v.AllocationKey,
 			ApplicationID: v.ApplicationID,
 			PartitionName: v.PartitionName,
 		})
@@ -363,7 +395,7 @@ func TestBasicScheduler(t *testing.T) {
 	// Release asks
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
 		Releases: &si.AllocationReleasesRequest{
-			AllocationAsksToRelease: []*si.AllocationAskRelease{
+			AllocationsToRelease: []*si.AllocationRelease{
 				{
 					ApplicationID: appID1,
 					PartitionName: "default",
@@ -387,7 +419,6 @@ func TestBasicSchedulerAutoAllocation(t *testing.T) {
 	err := ms.Init(configDataSmokeTest, true, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
-	leafName := "root.singleleaf"
 	appID := appID1
 
 	// Register a node, and add apps
@@ -432,21 +463,22 @@ func TestBasicSchedulerAutoAllocation(t *testing.T) {
 	ms.mockRM.waitForAcceptedNode(t, "node-1:1234", 1000)
 	ms.mockRM.waitForAcceptedNode(t, "node-2:1234", 1000)
 
-	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
-			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
+	asks := make([]*si.Allocation, 20)
+	for i := 0; i < 20; i++ {
+		asks[i] = &si.Allocation{
+			AllocationKey: fmt.Sprintf("alloc-%d", i),
+			ResourcePerAlloc: &si.Resource{
+				Resources: map[string]*si.Quantity{
+					"memory": {Value: 10000000},
+					"vcore":  {Value: 1000},
 				},
-				MaxAllocations: 20,
-				ApplicationID:  appID,
 			},
-		},
-		RmID: "rm:123",
+			ApplicationID: appID,
+		}
+	}
+	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
+		Allocations: asks,
+		RmID:        "rm:123",
 	})
 
 	assert.NilError(t, err, "AllocationRequest 2 failed")
@@ -542,32 +574,23 @@ partitions:
 	ms.mockRM.waitForAcceptedNode(t, "node-1:1234", 1000)
 	ms.mockRM.waitForAcceptedNode(t, "node-2:1234", 1000)
 
+	asks := make([]*si.Allocation, 40)
+	appIDs := []string{app1ID, app2ID}
+	for i := 0; i < 40; i++ {
+		asks[i] = &si.Allocation{
+			AllocationKey: fmt.Sprintf("alloc-%d", i),
+			ResourcePerAlloc: &si.Resource{
+				Resources: map[string]*si.Quantity{
+					"memory": {Value: 10000000},
+					"vcore":  {Value: 1000},
+				},
+			},
+			ApplicationID: appIDs[(i / 20)],
+		}
+	}
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
-			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
-				},
-				MaxAllocations: 20,
-				ApplicationID:  app1ID,
-			},
-			{
-				AllocationKey: "alloc-2",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
-				},
-				MaxAllocations: 20,
-				ApplicationID:  app2ID,
-			},
-		},
-		RmID: "rm:123",
+		Allocations: asks,
+		RmID:        "rm:123",
 	})
 
 	assert.NilError(t, err, "AllocationRequest 2 failed")
@@ -617,7 +640,6 @@ partitions:
 	err := ms.Init(configData, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
-	leafName := "root.leaf"
 	app1ID := appID1
 	app2ID := appID2
 
@@ -664,32 +686,23 @@ partitions:
 	ms.mockRM.waitForAcceptedNode(t, "node-1:1234", 1000)
 	ms.mockRM.waitForAcceptedNode(t, "node-2:1234", 1000)
 
+	asks := make([]*si.Allocation, 40)
+	appIDs := []string{app1ID, app2ID}
+	for i := 0; i < 40; i++ {
+		asks[i] = &si.Allocation{
+			AllocationKey: fmt.Sprintf("alloc-%d", i),
+			ResourcePerAlloc: &si.Resource{
+				Resources: map[string]*si.Quantity{
+					"memory": {Value: 10000000},
+					"vcore":  {Value: 1000},
+				},
+			},
+			ApplicationID: appIDs[i/20],
+		}
+	}
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
-			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
-				},
-				MaxAllocations: 20,
-				ApplicationID:  app1ID,
-			},
-			{
-				AllocationKey: "alloc-2",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
-				},
-				MaxAllocations: 20,
-				ApplicationID:  app2ID,
-			},
-		},
-		RmID: "rm:123",
+		Allocations: asks,
+		RmID:        "rm:123",
 	})
 
 	assert.NilError(t, err, "AllocationRequest 2 failed")
@@ -783,6 +796,7 @@ partitions:
 	ms.mockRM.waitForAcceptedApplication(t, "app-added-2", 1000)
 }
 
+//nolint:funlen
 func TestSchedulingOverMaxCapacity(t *testing.T) {
 	var parameters = []struct {
 		name       string
@@ -862,21 +876,22 @@ partitions:
 
 			ms.mockRM.waitForAcceptedNode(t, "node-1:1234", 1000)
 
-			err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-				Asks: []*si.AllocationAsk{
-					{
-						AllocationKey: "alloc-1",
-						ResourceAsk: &si.Resource{
-							Resources: map[string]*si.Quantity{
-								"memory": {Value: param.askMemory},
-								"vcore":  {Value: param.askCPU},
-							},
+			asks := make([]*si.Allocation, param.numOfAsk)
+			for i := int32(0); i < param.numOfAsk; i++ {
+				asks[i] = &si.Allocation{
+					AllocationKey: fmt.Sprintf("alloc-%d", i),
+					ResourcePerAlloc: &si.Resource{
+						Resources: map[string]*si.Quantity{
+							"memory": {Value: param.askMemory},
+							"vcore":  {Value: param.askCPU},
 						},
-						MaxAllocations: param.numOfAsk,
-						ApplicationID:  appID1,
 					},
-				},
-				RmID: "rm:123",
+					ApplicationID: appID1,
+				}
+			}
+			err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
+				Allocations: asks,
+				RmID:        "rm:123",
 			})
 
 			assert.NilError(t, err, "AllocationRequest 2 failed in run %s", param.name)
@@ -905,7 +920,7 @@ partitions:
 				allocReleases = append(allocReleases, &si.AllocationRelease{
 					PartitionName: "default",
 					ApplicationID: appID1,
-					AllocationID:  alloc.AllocationID,
+					AllocationKey: alloc.AllocationKey,
 					Message:       "",
 				})
 			}
@@ -1003,7 +1018,7 @@ partitions:
 
 	assert.NilError(t, err, "NodeRequest 2 failed")
 
-	err = common.WaitFor(10*time.Millisecond, 10*time.Second, func() bool {
+	err = common.WaitForCondition(10*time.Millisecond, 10*time.Second, func() bool {
 		return !ms.scheduler.GetClusterContext().GetPartition(partition).GetNode(node1ID).IsSchedulable() &&
 			ms.scheduler.GetClusterContext().GetPartition(partition).GetNode(node2ID).IsSchedulable()
 	})
@@ -1023,7 +1038,7 @@ partitions:
 
 	assert.NilError(t, err, "NodeRequest 3 failed")
 
-	err = common.WaitFor(10*time.Millisecond, 10*time.Second, func() bool {
+	err = common.WaitForCondition(10*time.Millisecond, 10*time.Second, func() bool {
 		return ms.scheduler.GetClusterContext().GetPartition(partition).GetNode(node1ID).IsSchedulable() &&
 			ms.scheduler.GetClusterContext().GetPartition(partition).GetNode(node2ID).IsSchedulable()
 	})
@@ -1112,32 +1127,23 @@ partitions:
 	ms.mockRM.waitForAcceptedNode(t, "node-1:1234", 1000)
 	ms.mockRM.waitForAcceptedNode(t, "node-2:1234", 1000)
 
+	asks := make([]*si.Allocation, 40)
+	appIDs := []string{app1ID, app2ID}
+	for i := 0; i < 40; i++ {
+		asks[i] = &si.Allocation{
+			AllocationKey: fmt.Sprintf("alloc-%d", i),
+			ResourcePerAlloc: &si.Resource{
+				Resources: map[string]*si.Quantity{
+					"memory": {Value: 10000000},
+					"vcore":  {Value: 1000},
+				},
+			},
+			ApplicationID: appIDs[i/20],
+		}
+	}
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
-			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
-				},
-				MaxAllocations: 20,
-				ApplicationID:  app1ID,
-			},
-			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
-				},
-				MaxAllocations: 20,
-				ApplicationID:  app2ID,
-			},
-		},
-		RmID: "rm:123",
+		Allocations: asks,
+		RmID:        "rm:123",
 	})
 
 	assert.NilError(t, err, "UpdateRequest 2 failed")
@@ -1230,22 +1236,23 @@ partitions:
 		waitForNewNode(t, context, node.NodeID, partition, 1000)
 	}
 
-	// Request ask with 20 allocations
-	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
-			{
-				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
-					Resources: map[string]*si.Quantity{
-						"memory": {Value: 10000000},
-						"vcore":  {Value: 1000},
-					},
+	// Request 20 allocations
+	asks := make([]*si.Allocation, 20)
+	for i := 0; i < 20; i++ {
+		asks[i] = &si.Allocation{
+			AllocationKey: fmt.Sprintf("alloc-%d", i),
+			ResourcePerAlloc: &si.Resource{
+				Resources: map[string]*si.Quantity{
+					"memory": {Value: 10000000},
+					"vcore":  {Value: 1000},
 				},
-				MaxAllocations: 20,
-				ApplicationID:  appID,
 			},
-		},
-		RmID: "rm:123",
+			ApplicationID: appID,
+		}
+	}
+	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
+		Allocations: asks,
+		RmID:        "rm:123",
 	})
 
 	assert.NilError(t, err, "AllocationRequest failed")
@@ -1286,7 +1293,6 @@ func TestDupReleasesInGangScheduling(t *testing.T) {
 	err := ms.Init(configDataSmokeTest, false, false)
 	assert.NilError(t, err, "RegisterResourceManager failed")
 
-	leafName := "root.singleleaf"
 	part := ms.scheduler.GetClusterContext().GetPartition(partition)
 	root := part.GetQueue("root")
 	leaf := part.GetQueue(leafName)
@@ -1342,19 +1348,18 @@ func TestDupReleasesInGangScheduling(t *testing.T) {
 
 	// shim side creates a placeholder, and send the UpdateRequest
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
+		Allocations: []*si.Allocation{
 			{
 				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
+				ResourcePerAlloc: &si.Resource{
 					Resources: map[string]*si.Quantity{
 						"memory": {Value: 10000000},
 						"vcore":  {Value: 1000},
 					},
 				},
-				TaskGroupName:  "tg",
-				Placeholder:    true,
-				MaxAllocations: 1,
-				ApplicationID:  appID1,
+				TaskGroupName: "tg",
+				Placeholder:   true,
+				ApplicationID: appID1,
 			},
 		},
 		RmID: "rm:123",
@@ -1377,19 +1382,18 @@ func TestDupReleasesInGangScheduling(t *testing.T) {
 
 	// shim submits the actual pod for scheduling
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
+		Allocations: []*si.Allocation{
 			{
 				AllocationKey: "alloc-2",
-				ResourceAsk: &si.Resource{
+				ResourcePerAlloc: &si.Resource{
 					Resources: map[string]*si.Quantity{
 						"memory": {Value: 10000000},
 						"vcore":  {Value: 1000},
 					},
 				},
-				MaxAllocations: 1,
-				ApplicationID:  appID1,
-				Placeholder:    false,
-				TaskGroupName:  "tg",
+				ApplicationID: appID1,
+				Placeholder:   false,
+				TaskGroupName: "tg",
 			},
 		},
 		RmID: "rm:123",
@@ -1409,7 +1413,7 @@ func TestDupReleasesInGangScheduling(t *testing.T) {
 				{
 					PartitionName:   "default",
 					ApplicationID:   appID1,
-					AllocationID:    placeholderAlloc.GetAllocationID(),
+					AllocationKey:   placeholderAlloc.GetAllocationKey(),
 					TerminationType: si.TerminationType_PLACEHOLDER_REPLACED,
 				},
 			},
@@ -1438,7 +1442,7 @@ func TestDupReleasesInGangScheduling(t *testing.T) {
 				{
 					PartitionName:   "default",
 					ApplicationID:   appID1,
-					AllocationID:    placeholderAlloc.GetAllocationID(),
+					AllocationKey:   placeholderAlloc.GetAllocationKey(),
 					TerminationType: si.TerminationType_PLACEHOLDER_REPLACED,
 				},
 			},
@@ -1540,17 +1544,26 @@ partitions:
 	assert.Equal(t, app01.CurrentState(), objects.New.String())
 
 	err = ms.proxy.UpdateAllocation(&si.AllocationRequest{
-		Asks: []*si.AllocationAsk{
+		Allocations: []*si.Allocation{
 			{
 				AllocationKey: "alloc-1",
-				ResourceAsk: &si.Resource{
+				ResourcePerAlloc: &si.Resource{
 					Resources: map[string]*si.Quantity{
 						"memory": {Value: 10000000},
 						"vcore":  {Value: 1000},
 					},
 				},
-				MaxAllocations: 2,
-				ApplicationID:  appID1,
+				ApplicationID: appID1,
+			},
+			{
+				AllocationKey: "alloc-2",
+				ResourcePerAlloc: &si.Resource{
+					Resources: map[string]*si.Quantity{
+						"memory": {Value: 10000000},
+						"vcore":  {Value: 1000},
+					},
+				},
+				ApplicationID: appID1,
 			},
 		},
 		RmID: "rm:123",
@@ -1594,7 +1607,7 @@ partitions:
 	// Release all allocations
 	for _, v := range ms.mockRM.getAllocations() {
 		updateRequest.Releases.AllocationsToRelease = append(updateRequest.Releases.AllocationsToRelease, &si.AllocationRelease{
-			AllocationID:  v.AllocationID,
+			AllocationKey: v.AllocationKey,
 			ApplicationID: v.ApplicationID,
 			PartitionName: v.PartitionName,
 		})
@@ -1618,10 +1631,10 @@ partitions:
 	// Check app to Completing status
 	assert.Equal(t, app01.CurrentState(), objects.Completing.String())
 	// the app changes from completing state to completed state
-	err = common.WaitFor(1*time.Millisecond, time.Millisecond*200, app.IsCompleted)
+	err = common.WaitForCondition(1*time.Millisecond, time.Millisecond*200, app.IsCompleted)
 	assert.NilError(t, err, "App should be in Completed state")
 	// partition manager should be able to clean up the dynamically created queue.
-	if err = common.WaitFor(1*time.Millisecond, time.Second*11, func() bool {
+	if err = common.WaitForCondition(1*time.Millisecond, time.Second*11, func() bool {
 		return part.GetQueue(leafName) == nil
 	}); err != nil {
 		t.Errorf("timeout waiting for queue is cleared %v", err)
