@@ -30,7 +30,7 @@ import (
 	"github.com/apache/yunikorn-core/pkg/rmproxy"
 	"github.com/apache/yunikorn-core/pkg/scheduler/objects"
 	"github.com/apache/yunikorn-core/pkg/scheduler/ugm"
-	"github.com/apache/yunikorn-core/pkg/webservice/dao"
+	siCommon "github.com/apache/yunikorn-scheduler-interface/lib/go/common"
 	"github.com/apache/yunikorn-scheduler-interface/lib/go/si"
 )
 
@@ -52,6 +52,8 @@ const (
 	allocKey3       = "alloc-3"
 	maxresources    = "maxresources"
 	maxapplications = "maxapplications"
+	foreignAlloc1   = "foreign-alloc-1"
+	foreignAlloc2   = "foreign-alloc-2"
 )
 
 func newBasePartitionNoRootDefault() (*PartitionContext, error) {
@@ -108,7 +110,7 @@ func newBasePartitionNoRootDefault() (*PartitionContext, error) {
 		NodeSortPolicy: configs.NodeSortingPolicy{},
 	}
 
-	return newPartitionContext(conf, rmID, nil)
+	return newPartitionContext(conf, rmID, nil, false)
 }
 
 func newBasePartition() (*PartitionContext, error) {
@@ -165,7 +167,7 @@ func newBasePartition() (*PartitionContext, error) {
 		NodeSortPolicy: configs.NodeSortingPolicy{},
 	}
 
-	return newPartitionContext(conf, rmID, nil)
+	return newPartitionContext(conf, rmID, nil, false)
 }
 
 func newConfiguredPartition() (*PartitionContext, error) {
@@ -263,7 +265,7 @@ func newConfiguredPartition() (*PartitionContext, error) {
 		Limits:         nil,
 		NodeSortPolicy: configs.NodeSortingPolicy{},
 	}
-	return newPartitionContext(conf, rmID, nil)
+	return newPartitionContext(conf, rmID, nil, false)
 }
 
 func newPreemptionConfiguredPartition(parentLimit map[string]string, leafGuarantees map[string]string) (*PartitionContext, error) {
@@ -372,7 +374,7 @@ func newPreemptionConfiguredPartition(parentLimit map[string]string, leafGuarant
 		PlacementRules: nil,
 		NodeSortPolicy: configs.NodeSortingPolicy{},
 	}
-	return newPartitionContext(conf, rmID, nil)
+	return newPartitionContext(conf, rmID, nil, false)
 }
 
 func newLimitedPartition(resLimit map[string]string) (*PartitionContext, error) {
@@ -433,7 +435,7 @@ func newLimitedPartition(resLimit map[string]string) (*PartitionContext, error)
 		NodeSortPolicy: configs.NodeSortingPolicy{},
 	}
 
-	return newPartitionContext(conf, rmID, nil)
+	return newPartitionContext(conf, rmID, nil, false)
 }
 
 func newPlacementPartition() (*PartitionContext, error) {
@@ -475,7 +477,7 @@ func newPlacementPartition() (*PartitionContext, error) {
 		NodeSortPolicy: configs.NodeSortingPolicy{},
 	}
 
-	return newPartitionContext(conf, rmID, nil)
+	return newPartitionContext(conf, rmID, nil, false)
 }
 
 func newApplication(appID, partition, queueName string) *objects.Application {
@@ -555,18 +557,18 @@ func newApplicationTGTagsWithPhTimeout(appID, partition, queueName string, task
 }
 
 func newAllocationAskTG(allocKey, appID, taskGroup string, res *resources.Resource, placeHolder bool) *objects.Allocation {
-	return newAllocationAskAll(allocKey, appID, taskGroup, res, 1, placeHolder)
+	return newAllocationAskAll(allocKey, appID, taskGroup, res, 1, placeHolder, nil)
 }
 
 func newAllocationAsk(allocKey, appID string, res *resources.Resource) *objects.Allocation {
-	return newAllocationAskAll(allocKey, appID, "", res, 1, false)
+	return newAllocationAskAll(allocKey, appID, "", res, 1, false, nil)
 }
 
 func newAllocationAskPriority(allocKey, appID string, res *resources.Resource, prio int32) *objects.Allocation {
-	return newAllocationAskAll(allocKey, appID, "", res, prio, false)
+	return newAllocationAskAll(allocKey, appID, "", res, prio, false, nil)
 }
 
-func newAllocationAskAll(allocKey, appID, taskGroup string, res *resources.Resource, prio int32, placeHolder bool) *objects.Allocation {
+func newAllocationAskAll(allocKey, appID, taskGroup string, res *resources.Resource, prio int32, placeHolder bool, tags map[string]string) *objects.Allocation {
 	return objects.NewAllocationFromSI(&si.Allocation{
 		AllocationKey:    allocKey,
 		ApplicationID:    appID,
@@ -575,6 +577,7 @@ func newAllocationAskAll(allocKey, appID, taskGroup string, res *resources.Resou
 		Priority:         prio,
 		TaskGroupName:    taskGroup,
 		Placeholder:      placeHolder,
+		AllocationTags:   tags,
 	})
 }
 
@@ -587,6 +590,10 @@ func newAllocation(allocKey, appID, nodeID string, res *resources.Resource) *obj
 }
 
 func newAllocationAll(allocKey, appID, nodeID, taskGroup string, res *resources.Resource, prio int32, placeHolder bool) *objects.Allocation {
+	return newAllocationAllTags(allocKey, appID, nodeID, taskGroup, res, prio, placeHolder, nil)
+}
+
+func newAllocationAllTags(allocKey, appID, nodeID, taskGroup string, res *resources.Resource, prio int32, placeHolder bool, tags map[string]string) *objects.Allocation {
 	return objects.NewAllocationFromSI(&si.Allocation{
 		AllocationKey:    allocKey,
 		ApplicationID:    appID,
@@ -596,9 +603,41 @@ func newAllocationAll(allocKey, appID, nodeID, taskGroup string, res *resources.
 		Priority:         prio,
 		TaskGroupName:    taskGroup,
 		Placeholder:      placeHolder,
+		AllocationTags:   tags,
 	})
 }
 
+func newForeignRequest(allocKey string) *objects.Allocation {
+	return objects.NewAllocationFromSI(&si.Allocation{
+		AllocationKey: allocKey,
+		AllocationTags: map[string]string{
+			siCommon.Foreign: siCommon.AllocTypeDefault,
+		},
+	})
+}
+
+func newForeignAllocation(allocKey, nodeID string, allocated *resources.Resource) *objects.Allocation {
+	var alloc *objects.Allocation
+	defer func() {
+		if nodeID == "" {
+			alloc.SetNodeID("")
+		}
+	}()
+	id := nodeID
+	if nodeID == "" {
+		id = "tmp" // set a temporary value to force allocated = true
+	}
+	alloc = objects.NewAllocationFromSI(&si.Allocation{
+		AllocationKey: allocKey,
+		AllocationTags: map[string]string{
+			siCommon.Foreign: siCommon.AllocTypeDefault,
+		},
+		NodeID:           id,
+		ResourcePerAlloc: allocated.ToProto(),
+	})
+	return alloc
+}
+
 func newAllocationAskPreempt(allocKey, appID string, prio int32, res *resources.Resource) *objects.Allocation {
 	return objects.NewAllocationFromSI(&si.Allocation{
 		AllocationKey:    allocKey,
@@ -614,20 +653,16 @@ func newAllocationAskPreempt(allocKey, appID string, prio int32, res *resources.
 		},
 	})
 }
-func newNodeWithResources(nodeID string, max, occupied *resources.Resource) *objects.Node {
+
+func newNodeMaxResource(nodeID string, max *resources.Resource) *objects.Node {
 	proto := &si.NodeInfo{
 		NodeID:              nodeID,
 		Attributes:          map[string]string{},
 		SchedulableResource: max.ToProto(),
-		OccupiedResource:    occupied.ToProto(),
 	}
 	return objects.NewNode(proto)
 }
 
-func newNodeMaxResource(nodeID string, max *resources.Resource) *objects.Node {
-	return newNodeWithResources(nodeID, max, nil)
-}
-
 // partition with an expected basic queue hierarchy
 // root -> parent -> leaf1
 //
@@ -684,13 +719,18 @@ func assertLimits(t *testing.T, userGroup security.UserGroup, expected *resource
 
 func assertUserGroupResourceMaxLimits(t *testing.T, userGroup security.UserGroup, expected *resources.Resource, expectedQueuesMaxLimits map[string]map[string]interface{}) {
 	manager := ugm.GetUserManager()
-	userResource := manager.GetUserResources(userGroup)
+	userResource := manager.GetUserResources(userGroup.User)
 	groupResource := manager.GetGroupResources(userGroup.Groups[0])
+	if expected == nil {
+		assert.Assert(t, userResource.IsEmpty(), "expected empty resource in user tracker")
+		assert.Assert(t, groupResource.IsEmpty(), "expected empty resource in group tracker")
+	} else {
+		assert.Assert(t, resources.Equals(userResource, expected), "user value '%s' not equal to expected '%s'", userResource.String(), expected.String())
+		assert.Assert(t, resources.Equals(groupResource, expected), "group value '%s' not equal to expected '%s'", groupResource.String(), expected.String())
+	}
 	ut := manager.GetUserTracker(userGroup.User)
 	if ut != nil {
-		maxResources := make(map[string]*resources.Resource)
-		usage := ut.GetUserResourceUsageDAOInfo()
-		getMaxResource(usage.Queues, maxResources)
+		maxResources := ut.GetMaxResources()
 		for q, qMaxLimits := range expectedQueuesMaxLimits {
 			if qRes, ok := maxResources[q]; ok {
 				maxRes, ok := qMaxLimits[maxresources].(*resources.Resource)
@@ -698,8 +738,7 @@ func assertUserGroupResourceMaxLimits(t *testing.T, userGroup security.UserGroup
 				assert.Equal(t, resources.Equals(qRes, maxRes), true)
 			}
 		}
-		maxApplications := make(map[string]uint64)
-		getMaxApplications(usage.Queues, maxApplications)
+		maxApplications := ut.GetMaxApplications()
 		for q, qMaxLimits := range expectedQueuesMaxLimits {
 			if qApps, ok := maxApplications[q]; ok {
 				maxApps, ok := qMaxLimits[maxapplications].(uint64)
@@ -709,11 +748,9 @@ func assertUserGroupResourceMaxLimits(t *testing.T, userGroup security.UserGroup
 		}
 	}
 
-	gt := manager.GetUserTracker(userGroup.User)
+	gt := manager.GetGroupTracker(userGroup.Groups[0])
 	if gt != nil {
-		gMaxResources := make(map[string]*resources.Resource)
-		gUsage := gt.GetUserResourceUsageDAOInfo()
-		getMaxResource(gUsage.Queues, gMaxResources)
+		gMaxResources := gt.GetMaxResources()
 		for q, qMaxLimits := range expectedQueuesMaxLimits {
 			if qRes, ok := gMaxResources[q]; ok {
 				maxRes, ok := qMaxLimits[maxresources].(*resources.Resource)
@@ -721,8 +758,7 @@ func assertUserGroupResourceMaxLimits(t *testing.T, userGroup security.UserGroup
 				assert.Equal(t, resources.Equals(qRes, maxRes), true)
 			}
 		}
-		gMaxApps := make(map[string]uint64)
-		getMaxApplications(gUsage.Queues, gMaxApps)
+		gMaxApps := gt.GetMaxApplications()
 		for q, qMaxLimits := range expectedQueuesMaxLimits {
 			if qApps, ok := gMaxApps[q]; ok {
 				maxApps, ok := qMaxLimits[maxapplications].(uint64)
@@ -731,26 +767,4 @@ func assertUserGroupResourceMaxLimits(t *testing.T, userGroup security.UserGroup
 			}
 		}
 	}
-	assert.Equal(t, resources.Equals(userResource, expected), true)
-	assert.Equal(t, resources.Equals(groupResource, expected), true)
-}
-
-func getMaxResource(usage *dao.ResourceUsageDAOInfo, maxResources map[string]*resources.Resource) map[string]*resources.Resource {
-	maxResources[usage.QueuePath] = usage.MaxResources
-	if len(usage.Children) > 0 {
-		for _, resourceUsage := range usage.Children {
-			getMaxResource(resourceUsage, maxResources)
-		}
-	}
-	return maxResources
-}
-
-func getMaxApplications(usage *dao.ResourceUsageDAOInfo, maxApplications map[string]uint64) map[string]uint64 {
-	maxApplications[usage.QueuePath] = usage.MaxApplications
-	if len(usage.Children) > 0 {
-		for _, resourceUsage := range usage.Children {
-			getMaxApplications(resourceUsage, maxApplications)
-		}
-	}
-	return maxApplications
 }
