@@ -18,6 +18,12 @@
 
 package dao
 
+type PartitionNodesUtilDAOInfo struct {
+	ClusterID     string              `json:"clusterId"` // no omitempty, cluster id should not be empty
+	Partition     string              `json:"partition"` // no omitempty, partition should not be empty
+	NodesUtilList []*NodesUtilDAOInfo `json:"utilizations,omitempty"`
+}
+
 type NodesUtilDAOInfo struct {
 	ResourceType string             `json:"type,omitempty"`
 	NodesUtil    []*NodeUtilDAOInfo `json:"utilization,omitempty"`
