@@ -66,6 +66,9 @@ const (
 	AppStateActive    = "active"
 	AppStateRejected  = "rejected"
 	AppStateCompleted = "completed"
+
+	WSBase    = "/ws/v1"
+	DebugBase = "/debug"
 )
 
 var allowedActiveStatusMsg string
@@ -108,8 +111,23 @@ func init() {
 	maxRESTResponseSize.Store(configs.DefaultRESTResponseSize)
 }
 
+// redirectDebug redirect calls that used to be part of "/ws/v1" to "/debug"
+// Moving the URl permanently for requests that should not have been part of the standard list
+func redirectDebug(w http.ResponseWriter, r *http.Request) {
+	code := http.StatusMovedPermanently
+	// replace the path: we know we have the right URL as the router would not have called this
+	r.URL.Path = strings.Replace(r.URL.Path, WSBase, DebugBase, 1)
+	redirect := r.URL.String()
+	w.Header().Set("Content-Type", "text/html; charset=utf-8")
+	w.Header().Set("Location", redirect)
+	w.WriteHeader(code)
+	// do as recommended in the RFC 7321, 6.4.2
+	body := "<a href=\"" + redirect + "\">" + http.StatusText(code) + "</a>.\n"
+	_, _ = fmt.Fprintln(w, body)
+}
+
 func getStackInfo(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	var stack = func() []byte {
 		buf := make([]byte, 1024)
 		for {
@@ -127,7 +145,7 @@ func getStackInfo(w http.ResponseWriter, r *http.Request) {
 }
 
 func getClusterInfo(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 
 	lists := schedulerContext.Load().GetPartitionMapClone()
 	clustersInfo := getClusterDAO(lists)
@@ -149,7 +167,7 @@ func validateQueue(queuePath string) error {
 }
 
 func validateConf(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	requestBytes, err := io.ReadAll(r.Body)
 	if err == nil {
 		_, err = configs.LoadSchedulerConfigFromByteArray(requestBytes)
@@ -166,11 +184,14 @@ func validateConf(w http.ResponseWriter, r *http.Request) {
 	}
 }
 
-func writeHeaders(w http.ResponseWriter) {
+func writeHeaders(w http.ResponseWriter, method string) {
 	w.Header().Set("Content-Type", "application/json; charset=UTF-8")
 	w.Header().Set("Access-Control-Allow-Origin", "*")
-	w.Header().Set("Access-Control-Allow-Credentials", "true")
-	w.Header().Set("Access-Control-Allow-Methods", "GET,POST,HEAD,OPTIONS")
+	methods := "GET, OPTIONS"
+	if method == http.MethodPost {
+		methods = "OPTIONS, POST"
+	}
+	w.Header().Set("Access-Control-Allow-Methods", methods)
 	w.Header().Set("Access-Control-Allow-Headers", "X-Requested-With,Content-Type,Accept,Origin")
 }
 
@@ -215,7 +236,7 @@ func getClusterUtilJSON(partition *scheduler.PartitionContext) []*dao.ClusterUti
 			}
 			utils = append(utils, utilization)
 		}
-	} else if !getResource {
+	} else {
 		utilization := &dao.ClusterUtilDAOInfo{
 			ResourceType: "N/A",
 			Total:        int64(-1),
@@ -254,6 +275,20 @@ func getAllocationDAO(alloc *objects.Allocation) *dao.AllocationDAOInfo {
 	return allocDAO
 }
 
+func getForeignAllocationDAO(alloc *objects.Allocation) *dao.ForeignAllocationDAOInfo {
+	allocTime := alloc.GetCreateTime().UnixNano()
+	allocDAO := &dao.ForeignAllocationDAOInfo{
+		AllocationKey:    alloc.GetAllocationKey(),
+		AllocationTags:   alloc.GetTagsClone(),
+		AllocationTime:   allocTime,
+		ResourcePerAlloc: alloc.GetAllocatedResource().DAOMap(),
+		Priority:         strconv.Itoa(int(alloc.GetPriority())),
+		NodeID:           alloc.GetNodeID(),
+		Preemptable:      alloc.IsPreemptable(),
+	}
+	return allocDAO
+}
+
 func getAllocationsDAO(allocations []*objects.Allocation) []*dao.AllocationDAOInfo {
 	allocsDAO := make([]*dao.AllocationDAOInfo, 0, len(allocations))
 	for _, alloc := range allocations {
@@ -262,6 +297,14 @@ func getAllocationsDAO(allocations []*objects.Allocation) []*dao.AllocationDAOIn
 	return allocsDAO
 }
 
+func getForeignAllocationsDAO(allocations []*objects.Allocation) []*dao.ForeignAllocationDAOInfo {
+	allocsDAO := make([]*dao.ForeignAllocationDAOInfo, 0, len(allocations))
+	for _, alloc := range allocations {
+		allocsDAO = append(allocsDAO, getForeignAllocationDAO(alloc))
+	}
+	return allocsDAO
+}
+
 func getPlaceholderDAO(ph *objects.PlaceholderData) *dao.PlaceholderDAOInfo {
 	phDAO := &dao.PlaceholderDAOInfo{
 		TaskGroupName: ph.TaskGroupName,
@@ -297,35 +340,40 @@ func getStatesDAO(entries []*objects.StateLogEntry) []*dao.StateDAOInfo {
 	return statesDAO
 }
 
-func getApplicationDAO(app *objects.Application, summary *objects.ApplicationSummary) *dao.ApplicationDAOInfo {
+func getApplicationDAO(app *objects.Application) *dao.ApplicationDAOInfo {
 	if app == nil {
 		return &dao.ApplicationDAOInfo{}
 	}
 
+	// The resource history is only correct in COMPLETING or COMPLETED app state.
+	resHistory := dao.ResourceHistory{
+		ResourceUsage:       app.GetTrackedDAOMap("usedResource"),
+		PreemptedResource:   app.GetTrackedDAOMap("preemptedResource"),
+		PlaceholderResource: app.GetTrackedDAOMap("placeholderResource"),
+	}
+
 	return &dao.ApplicationDAOInfo{
-		ApplicationID:       app.ApplicationID,
-		UsedResource:        app.GetAllocatedResource().DAOMap(),
-		MaxUsedResource:     app.GetMaxAllocatedResource().DAOMap(),
-		PendingResource:     app.GetPendingResource().DAOMap(),
-		Partition:           common.GetPartitionNameWithoutClusterID(app.Partition),
-		QueueName:           app.GetQueuePath(),
-		SubmissionTime:      app.SubmissionTime.UnixNano(),
-		FinishedTime:        common.ZeroTimeInUnixNano(app.FinishedTime()),
-		Requests:            getAllocationAsksDAO(app.GetAllRequests()),
-		Allocations:         getAllocationsDAO(app.GetAllAllocations()),
-		State:               app.CurrentState(),
-		User:                app.GetUser().User,
-		Groups:              app.GetUser().Groups,
-		RejectedMessage:     app.GetRejectedMessage(),
-		PlaceholderData:     getPlaceholdersDAO(app.GetAllPlaceholderData()),
-		StateLog:            getStatesDAO(app.GetStateLog()),
-		HasReserved:         app.HasReserved(),
-		Reservations:        app.GetReservations(),
-		MaxRequestPriority:  app.GetAskMaxPriority(),
-		StartTime:           app.StartTime().UnixMilli(),
-		ResourceUsage:       summary.ResourceUsage,
-		PreemptedResource:   summary.PreemptedResource,
-		PlaceholderResource: summary.PlaceholderResource,
+		ApplicationID:      app.ApplicationID,
+		UsedResource:       app.GetAllocatedResource().DAOMap(),
+		MaxUsedResource:    app.GetMaxAllocatedResource().DAOMap(),
+		PendingResource:    app.GetPendingResource().DAOMap(),
+		Partition:          common.GetPartitionNameWithoutClusterID(app.Partition),
+		QueueName:          app.GetQueuePath(),
+		SubmissionTime:     app.GetSubmissionTime().UnixNano(),
+		FinishedTime:       common.ZeroTimeInUnixNano(app.FinishedTime()),
+		Requests:           getAllocationAsksDAO(app.GetAllRequests()),
+		Allocations:        getAllocationsDAO(app.GetAllAllocations()),
+		State:              app.CurrentState(),
+		User:               app.GetUser().User,
+		Groups:             app.GetUser().Groups,
+		RejectedMessage:    app.GetRejectedMessage(),
+		PlaceholderData:    getPlaceholdersDAO(app.GetAllPlaceholderData()),
+		StateLog:           getStatesDAO(app.GetStateLog()),
+		HasReserved:        app.HasReserved(),
+		Reservations:       app.GetReservations(),
+		MaxRequestPriority: app.GetAskMaxPriority(),
+		StartTime:          app.StartTime().UnixMilli(),
+		ResourceHistory:    resHistory,
 	}
 }
 
@@ -375,19 +423,20 @@ func getAllocationAsksDAO(asks []*objects.Allocation) []*dao.AllocationAskDAOInf
 
 func getNodeDAO(node *objects.Node) *dao.NodeDAOInfo {
 	return &dao.NodeDAOInfo{
-		NodeID:       node.NodeID,
-		HostName:     node.Hostname,
-		RackName:     node.Rackname,
-		Attributes:   node.GetAttributes(),
-		Capacity:     node.GetCapacity().DAOMap(),
-		Occupied:     node.GetOccupiedResource().DAOMap(),
-		Allocated:    node.GetAllocatedResource().DAOMap(),
-		Available:    node.GetAvailableResource().DAOMap(),
-		Utilized:     node.GetUtilizedResource().DAOMap(),
-		Allocations:  getAllocationsDAO(node.GetAllAllocations()),
-		Schedulable:  node.IsSchedulable(),
-		IsReserved:   node.IsReserved(),
-		Reservations: node.GetReservationKeys(),
+		NodeID:             node.NodeID,
+		HostName:           node.Hostname,
+		RackName:           node.Rackname,
+		Attributes:         node.GetAttributes(),
+		Capacity:           node.GetCapacity().DAOMap(),
+		Occupied:           node.GetOccupiedResource().DAOMap(),
+		Allocated:          node.GetAllocatedResource().DAOMap(),
+		Available:          node.GetAvailableResource().DAOMap(),
+		Utilized:           node.GetUtilizedResource().DAOMap(),
+		Allocations:        getAllocationsDAO(node.GetYunikornAllocations()),
+		ForeignAllocations: getForeignAllocationsDAO(node.GetForeignAllocations()),
+		Schedulable:        node.IsSchedulable(),
+		IsReserved:         node.IsReserved(),
+		Reservations:       node.GetReservationKeys(),
 	}
 }
 
@@ -405,7 +454,7 @@ func getNodesDAO(entries []*objects.Node) []*dao.NodeDAOInfo {
 // Only check the default partition
 // Deprecated - To be removed in next major release. Replaced with getNodesUtilisations
 func getNodeUtilisation(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	partitionContext := schedulerContext.Load().GetPartitionWithoutClusterID(configs.DefaultPartition)
 	if partitionContext == nil {
 		buildJSONErrorResponse(w, PartitionDoesNotExists, http.StatusInternalServerError)
@@ -469,7 +518,7 @@ func getNodesUtilJSON(partition *scheduler.PartitionContext, name string) *dao.N
 }
 
 func getNodeUtilisations(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	var result []*dao.PartitionNodesUtilDAOInfo
 	for _, part := range schedulerContext.Load().GetPartitionMapClone() {
 		result = append(result, getPartitionNodesUtilJSON(part))
@@ -542,7 +591,7 @@ func getPartitionNodesUtilJSON(partition *scheduler.PartitionContext) *dao.Parti
 }
 
 func getApplicationHistory(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 
 	// There is nothing to return but we did not really encounter a problem
 	if imHistory == nil {
@@ -559,7 +608,7 @@ func getApplicationHistory(w http.ResponseWriter, r *http.Request) {
 }
 
 func getContainerHistory(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 
 	// There is nothing to return but we did not really encounter a problem
 	if imHistory == nil {
@@ -576,7 +625,7 @@ func getContainerHistory(w http.ResponseWriter, r *http.Request) {
 }
 
 func getClusterConfig(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 
 	var marshalledConf []byte
 	var err error
@@ -612,7 +661,7 @@ func getClusterConfigDAO() *dao.ConfigDAOInfo {
 }
 
 func checkHealthStatus(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 
 	// Fetch last healthCheck result
 	result := schedulerContext.Load().GetLastHealthCheckResult()
@@ -634,8 +683,8 @@ func checkHealthStatus(w http.ResponseWriter, r *http.Request) {
 	}
 }
 
-func getPartitions(w http.ResponseWriter, _ *http.Request) {
-	writeHeaders(w)
+func getPartitions(w http.ResponseWriter, r *http.Request) {
+	writeHeaders(w, r.Method)
 
 	lists := schedulerContext.Load().GetPartitionMapClone()
 	partitionsInfo := getPartitionInfoDAO(lists)
@@ -645,7 +694,7 @@ func getPartitions(w http.ResponseWriter, _ *http.Request) {
 }
 
 func getPartitionQueues(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -666,7 +715,7 @@ func getPartitionQueues(w http.ResponseWriter, r *http.Request) {
 }
 
 func getPartitionQueue(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -701,7 +750,7 @@ func getPartitionQueue(w http.ResponseWriter, r *http.Request) {
 }
 
 func getPartitionNodes(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -720,7 +769,7 @@ func getPartitionNodes(w http.ResponseWriter, r *http.Request) {
 }
 
 func getPartitionNode(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -745,7 +794,7 @@ func getPartitionNode(w http.ResponseWriter, r *http.Request) {
 }
 
 func getQueueApplications(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -776,8 +825,7 @@ func getQueueApplications(w http.ResponseWriter, r *http.Request) {
 
 	appsDao := make([]*dao.ApplicationDAOInfo, 0)
 	for _, app := range queue.GetCopyOfApps() {
-		summary := app.GetApplicationSummary(partitionContext.RmID)
-		appsDao = append(appsDao, getApplicationDAO(app, summary))
+		appsDao = append(appsDao, getApplicationDAO(app))
 	}
 
 	if err := json.NewEncoder(w).Encode(appsDao); err != nil {
@@ -786,7 +834,7 @@ func getQueueApplications(w http.ResponseWriter, r *http.Request) {
 }
 
 func getPartitionApplicationsByState(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -826,8 +874,7 @@ func getPartitionApplicationsByState(w http.ResponseWriter, r *http.Request) {
 	}
 	appsDao := make([]*dao.ApplicationDAOInfo, 0, len(appList))
 	for _, app := range appList {
-		summary := app.GetApplicationSummary(partitionContext.RmID)
-		appsDao = append(appsDao, getApplicationDAO(app, summary))
+		appsDao = append(appsDao, getApplicationDAO(app))
 	}
 	if err := json.NewEncoder(w).Encode(appsDao); err != nil {
 		buildJSONErrorResponse(w, err.Error(), http.StatusInternalServerError)
@@ -835,7 +882,7 @@ func getPartitionApplicationsByState(w http.ResponseWriter, r *http.Request) {
 }
 
 func getApplication(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -875,15 +922,14 @@ func getApplication(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	summary := app.GetApplicationSummary(partitionContext.RmID)
-	appDao := getApplicationDAO(app, summary)
+	appDao := getApplicationDAO(app)
 	if err := json.NewEncoder(w).Encode(appDao); err != nil {
 		buildJSONErrorResponse(w, err.Error(), http.StatusInternalServerError)
 	}
 }
 
 func getPartitionRules(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -902,7 +948,7 @@ func getPartitionRules(w http.ResponseWriter, r *http.Request) {
 }
 
 func getQueueApplicationsByState(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -946,8 +992,7 @@ func getQueueApplicationsByState(w http.ResponseWriter, r *http.Request) {
 	appsDao := make([]*dao.ApplicationDAOInfo, 0)
 	for _, app := range queue.GetCopyOfApps() {
 		if status == "" || strings.ToLower(app.CurrentState()) == status {
-			summary := app.GetApplicationSummary(partitionContext.RmID)
-			appsDao = append(appsDao, getApplicationDAO(app, summary))
+			appsDao = append(appsDao, getApplicationDAO(app))
 		}
 	}
 
@@ -965,6 +1010,7 @@ func getPartitionInfoDAO(lists map[string]*scheduler.PartitionContext) []*dao.Pa
 		partitionInfo.Name = common.GetPartitionNameWithoutClusterID(partitionContext.Name)
 		partitionInfo.State = partitionContext.GetCurrentState()
 		partitionInfo.LastStateTransitionTime = partitionContext.GetStateTime().UnixNano()
+		partitionInfo.PreemptionEnabled = partitionContext.IsPreemptionEnabled()
 
 		capacityInfo := dao.PartitionCapacity{}
 		capacity := partitionContext.GetTotalPartitionResource()
@@ -1055,8 +1101,7 @@ func getApplicationsDAO(lists map[string]*scheduler.PartitionContext) []*dao.App
 		appList = append(appList, partition.GetRejectedApplications()...)
 
 		for _, app := range appList {
-			summary := app.GetApplicationSummary(partition.RmID)
-			result = append(result, getApplicationDAO(app, summary))
+			result = append(result, getApplicationDAO(app))
 		}
 	}
 
@@ -1139,13 +1184,13 @@ func getMetrics(w http.ResponseWriter, r *http.Request) {
 	promhttp.Handler().ServeHTTP(w, r)
 }
 
-func getUsersResourceUsage(w http.ResponseWriter, _ *http.Request) {
-	writeHeaders(w)
+func getUsersResourceUsage(w http.ResponseWriter, r *http.Request) {
+	writeHeaders(w, r.Method)
 	userManager := ugm.GetUserManager()
-	usersResources := userManager.GetUsersResources()
-	result := make([]*dao.UserResourceUsageDAOInfo, len(usersResources))
-	for i, tracker := range usersResources {
-		result[i] = tracker.GetUserResourceUsageDAOInfo()
+	trackers := userManager.GetUserTrackers()
+	result := make([]*dao.UserResourceUsageDAOInfo, len(trackers))
+	for i, tracker := range trackers {
+		result[i] = tracker.GetResourceUsageDAOInfo()
 	}
 	if err := json.NewEncoder(w).Encode(result); err != nil {
 		buildJSONErrorResponse(w, err.Error(), http.StatusInternalServerError)
@@ -1153,7 +1198,7 @@ func getUsersResourceUsage(w http.ResponseWriter, _ *http.Request) {
 }
 
 func getUserResourceUsage(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -1174,19 +1219,19 @@ func getUserResourceUsage(w http.ResponseWriter, r *http.Request) {
 		buildJSONErrorResponse(w, UserDoesNotExists, http.StatusNotFound)
 		return
 	}
-	var result = userTracker.GetUserResourceUsageDAOInfo()
-	if err := json.NewEncoder(w).Encode(result); err != nil {
+	result := userTracker.GetResourceUsageDAOInfo()
+	if err = json.NewEncoder(w).Encode(result); err != nil {
 		buildJSONErrorResponse(w, err.Error(), http.StatusInternalServerError)
 	}
 }
 
 func getGroupsResourceUsage(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	userManager := ugm.GetUserManager()
-	groupsResources := userManager.GetGroupsResources()
-	result := make([]*dao.GroupResourceUsageDAOInfo, len(groupsResources))
-	for i, tracker := range groupsResources {
-		result[i] = tracker.GetGroupResourceUsageDAOInfo()
+	trackers := userManager.GetGroupTrackers()
+	result := make([]*dao.GroupResourceUsageDAOInfo, len(trackers))
+	for i, tracker := range trackers {
+		result[i] = tracker.GetResourceUsageDAOInfo()
 	}
 	if err := json.NewEncoder(w).Encode(result); err != nil {
 		buildJSONErrorResponse(w, err.Error(), http.StatusInternalServerError)
@@ -1194,7 +1239,7 @@ func getGroupsResourceUsage(w http.ResponseWriter, r *http.Request) {
 }
 
 func getGroupResourceUsage(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	vars := httprouter.ParamsFromContext(r.Context())
 	if vars == nil {
 		buildJSONErrorResponse(w, MissingParamsName, http.StatusBadRequest)
@@ -1215,14 +1260,14 @@ func getGroupResourceUsage(w http.ResponseWriter, r *http.Request) {
 		buildJSONErrorResponse(w, GroupDoesNotExists, http.StatusNotFound)
 		return
 	}
-	var result = groupTracker.GetGroupResourceUsageDAOInfo()
-	if err := json.NewEncoder(w).Encode(result); err != nil {
+	result := groupTracker.GetResourceUsageDAOInfo()
+	if err = json.NewEncoder(w).Encode(result); err != nil {
 		buildJSONErrorResponse(w, err.Error(), http.StatusInternalServerError)
 	}
 }
 
 func getEvents(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	eventSystem := events.GetEventSystem()
 	if !eventSystem.IsEventTrackingEnabled() {
 		buildJSONErrorResponse(w, "Event tracking is disabled", http.StatusInternalServerError)
@@ -1270,7 +1315,7 @@ func getEvents(w http.ResponseWriter, r *http.Request) {
 }
 
 func getStream(w http.ResponseWriter, r *http.Request) {
-	writeHeaders(w)
+	writeHeaders(w, r.Method)
 	eventSystem := events.GetEventSystem()
 	if !eventSystem.IsEventTrackingEnabled() {
 		buildJSONErrorResponse(w, "Event tracking is disabled", http.StatusInternalServerError)
