@@ -568,7 +568,9 @@ func TestMutate(t *testing.T) {
 	assert.Check(t, resp.Allowed, "response not allowed for unknown object type")
 	assert.Check(t, len(resp.Patch) > 0, "empty patch for deployment")
 	annotations := annotationsFromDeployment(t, resp.Patch)
-	assert.Equal(t, annotations[common.UserInfoAnnotation].(string), "{\"user\":\"testExtUser\"}")
+	annotationValue, ok := annotations[common.UserInfoAnnotation].(string)
+	assert.Assert(t, ok, "UserInfoAnnotation value is not a string")
+	assert.Equal(t, annotationValue, "{\"user\":\"testExtUser\"}")
 
 	// deployment - annotation is not set, bypassAuth is enabled
 	ac = prepareController(t, "", "", "^kube-system$,^bypass$", "", "^nolabel$", true, true)
@@ -838,7 +840,9 @@ func schedulerName(t *testing.T, patch []byte) string {
 	ops := parsePatch(t, patch)
 	for _, op := range ops {
 		if op.Path == "/spec/schedulerName" {
-			return op.Value.(string)
+			val, ok := op.Value.(string)
+			assert.Assert(t, ok, "scheduler name value is not a string")
+			return val
 		}
 	}
 	return ""
@@ -848,7 +852,9 @@ func labels(t *testing.T, patch []byte) map[string]interface{} {
 	ops := parsePatch(t, patch)
 	for _, op := range ops {
 		if op.Path == "/metadata/labels" {
-			return op.Value.(map[string]interface{})
+			val, ok := op.Value.(map[string]interface{})
+			assert.Assert(t, ok, "labels value is not a map")
+			return val
 		}
 	}
 	return make(map[string]interface{})
@@ -858,7 +864,9 @@ func annotationsFromDeployment(t *testing.T, patch []byte) map[string]interface{
 	ops := parsePatch(t, patch)
 	for _, op := range ops {
 		if op.Path == "/spec/template/metadata/annotations" {
-			return op.Value.(map[string]interface{})
+			val, ok := op.Value.(map[string]interface{})
+			assert.Assert(t, ok, "annotations value is not a map")
+			return val
 		}
 	}
 	return make(map[string]interface{})
