@@ -19,6 +19,7 @@
 package admission
 
 import (
+	"reflect"
 	"strings"
 	"testing"
 
@@ -62,14 +63,16 @@ func createTestingPodWithMeta() *v1.Pod {
 			Labels: map[string]string{
 				"random": "random",
 			},
+			Annotations: map[string]string{},
 		}
 
 	return pod
 }
 
-func createTestingPodWithAppId() *v1.Pod {
+func createTestingPodWithLabels(appId string, queue string) *v1.Pod {
 	pod := createTestingPodWithMeta()
-	pod.ObjectMeta.Labels["applicationId"] = "app-0001"
+	pod.ObjectMeta.Labels[constants.CanonicalLabelApplicationID] = appId
+	pod.ObjectMeta.Labels[constants.CanonicalLabelQueueName] = queue
 
 	return pod
 }
@@ -81,9 +84,10 @@ func createTestingPodWithGenerateName() *v1.Pod {
 	return pod
 }
 
-func createTestingPodWithQueue() *v1.Pod {
+func createTestingPodWithAnnotations(appId string, queue string) *v1.Pod {
 	pod := createTestingPodWithMeta()
-	pod.ObjectMeta.Labels["queue"] = "root.abc"
+	pod.ObjectMeta.Annotations[constants.AnnotationApplicationID] = appId
+	pod.ObjectMeta.Annotations[constants.AnnotationQueueName] = queue
 
 	return pod
 }
@@ -100,39 +104,42 @@ func createTestingPodNoNamespaceAndLabels() *v1.Pod {
 }
 
 func TestUpdatePodLabelForAdmissionController(t *testing.T) {
-	// verify when appId/queue are not given,
-	pod := createTestingPodWithMeta()
+	dummyAppId := "app-0001"
+	dummyQueueName := "root.abc"
 
+	// verify when appId/queue are not given,
+	// we generate new appId/queue labels
+	pod := createTestingPodWithMeta()
 	if result := updatePodLabel(pod, "default", false); result != nil {
 		assert.Equal(t, len(result), 3)
 		assert.Equal(t, result["random"], "random")
-		assert.Equal(t, result["disableStateAware"], "true")
-		assert.Equal(t, strings.HasPrefix(result["applicationId"], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.CanonicalLabelApplicationID], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.LabelApplicationID], constants.AutoGenAppPrefix), true)
 	} else {
 		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
 	}
 
-	// verify if applicationId is given in the labels,
-	// we won't modify it
-	pod = createTestingPodWithAppId()
-
+	// verify if appId/queue is given in the canonical labels
+	// we won't modify the value and will add it to non-canonical label for backward compatibility
+	pod = createTestingPodWithLabels(dummyAppId, dummyQueueName)
 	if result := updatePodLabel(pod, "default", false); result != nil {
-		assert.Equal(t, len(result), 2)
+		assert.Equal(t, len(result), 5)
 		assert.Equal(t, result["random"], "random")
-		assert.Equal(t, result["applicationId"], "app-0001")
+		assert.Equal(t, result[constants.CanonicalLabelApplicationID], dummyAppId)
+		assert.Equal(t, result[constants.LabelApplicationID], dummyAppId)
+		assert.Equal(t, result[constants.CanonicalLabelQueueName], dummyQueueName)
+		assert.Equal(t, result[constants.LabelQueueName], dummyQueueName)
 	} else {
 		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
 	}
 
-	// verify if queue is given in the labels,
-	// we won't modify it
-	pod = createTestingPodWithQueue()
+	// verify if applicationId and queue is given in the annotations,
+	// we won't generate new labels
+	pod = createTestingPodWithAnnotations(dummyAppId, dummyQueueName)
 	if result := updatePodLabel(pod, "default", false); result != nil {
-		assert.Equal(t, len(result), 4)
+		t.Log(result)
+		assert.Equal(t, len(result), 1)
 		assert.Equal(t, result["random"], "random")
-		assert.Equal(t, result["disableStateAware"], "true")
-		assert.Equal(t, result["queue"], "root.abc")
-		assert.Equal(t, strings.HasPrefix(result["applicationId"], constants.AutoGenAppPrefix), true)
 	} else {
 		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
 	}
@@ -143,8 +150,8 @@ func TestUpdatePodLabelForAdmissionController(t *testing.T) {
 
 	if result := updatePodLabel(pod, "default", false); result != nil {
 		assert.Equal(t, len(result), 2)
-		assert.Equal(t, result["disableStateAware"], "true")
-		assert.Equal(t, strings.HasPrefix(result["applicationId"], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.CanonicalLabelApplicationID], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.LabelApplicationID], constants.AutoGenAppPrefix), true)
 	} else {
 		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
 	}
@@ -153,8 +160,8 @@ func TestUpdatePodLabelForAdmissionController(t *testing.T) {
 	pod = createTestingPodWithGenerateName()
 	if result := updatePodLabel(pod, "default", false); result != nil {
 		assert.Equal(t, len(result), 2)
-		assert.Equal(t, result["disableStateAware"], "true")
-		assert.Equal(t, strings.HasPrefix(result["applicationId"], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.CanonicalLabelApplicationID], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.LabelApplicationID], constants.AutoGenAppPrefix), true)
 	} else {
 		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
 	}
@@ -162,9 +169,39 @@ func TestUpdatePodLabelForAdmissionController(t *testing.T) {
 	pod = createMinimalTestingPod()
 	if result := updatePodLabel(pod, "default", false); result != nil {
 		assert.Equal(t, len(result), 2)
-		assert.Equal(t, result["disableStateAware"], "true")
-		assert.Equal(t, strings.HasPrefix(result["applicationId"], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.CanonicalLabelApplicationID], constants.AutoGenAppPrefix), true)
+		assert.Equal(t, strings.HasPrefix(result[constants.LabelApplicationID], constants.AutoGenAppPrefix), true)
 	} else {
 		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
 	}
 }
+
+func TestDefaultQueueName(t *testing.T) {
+	defaultConf := createConfig()
+	pod := createTestingPodWithMeta()
+	if result := updatePodLabel(pod, defaultConf.GetNamespace(), defaultConf.GetGenerateUniqueAppIds()); result != nil {
+		assert.Equal(t, len(result), 3)
+		assert.Equal(t, result["random"], "random")
+		assert.Equal(t, result[constants.CanonicalLabelApplicationID], "yunikorn-default-autogen")
+		assert.Equal(t, result[constants.LabelApplicationID], "yunikorn-default-autogen")
+		assert.Equal(t, result[constants.CanonicalLabelQueueName], "")
+		assert.Equal(t, result[constants.LabelQueueName], "")
+	} else {
+		t.Fatal("UpdatePodLabelForAdmissionController is not as expected")
+	}
+}
+
+func TestConvert2Namespace(t *testing.T) {
+	namespace := &v1.Namespace{}
+	result := convert2Namespace(namespace)
+	assert.Check(t, result != nil)
+	assert.Check(t, reflect.DeepEqual(result, namespace))
+
+	obj := struct{}{}
+	result = convert2Namespace(obj)
+	assert.Check(t, result == nil)
+
+	pod := &v1.Pod{}
+	result = convert2Namespace(pod)
+	assert.Check(t, result == nil)
+}
