@@ -75,6 +75,7 @@ type Context struct {
 	lock           *locking.RWMutex               // lock - used not only for context data but also to ensure that multiple event types are not executed concurrently
 	txnID          atomic.Uint64                  // transaction ID counter
 	klogger        klog.Logger
+	podActivator   atomic.Value
 }
 
 // NewContext create a new context for the scheduler using a default (empty) configuration
@@ -111,6 +112,18 @@ func NewContextWithBootstrapConfigMaps(apis client.APIProvider, bootstrapConfigM
 	return ctx
 }
 
+// SetPodActivator is used by the plugin mode to add a callback function to reschedule a pod
+func (ctx *Context) SetPodActivator(podActivator func(logger klog.Logger, pod *v1.Pod)) {
+	ctx.podActivator.Store(podActivator)
+}
+
+// ActivatePod is used to tell Kubernetes to re-schedule a pod when using plugin mode
+func (ctx *Context) ActivatePod(pod *v1.Pod) {
+	if activator, ok := ctx.podActivator.Load().(func(logger klog.Logger, pod *v1.Pod)); ok && activator != nil {
+		activator(ctx.klogger, pod)
+	}
+}
+
 func (ctx *Context) AddSchedulingEventHandlers() error {
 	err := ctx.apiProvider.AddEventHandler(&client.ResourceEventHandlers{
 		Type:     client.ConfigMapInformerHandlers,
@@ -202,7 +215,7 @@ func (ctx *Context) updateNodeInternal(node *v1.Node, register bool) {
 			if applicationID == "" {
 				ctx.updateForeignPod(pod)
 			} else {
-				ctx.updateYuniKornPod(applicationID, pod)
+				ctx.updateYuniKornPod(applicationID, nil, pod)
 			}
 		}
 
@@ -217,10 +230,8 @@ func (ctx *Context) updateNodeInternal(node *v1.Node, register bool) {
 
 		if !common.Equals(prevCapacity, newCapacity) {
 			// update capacity
-			if capacity, occupied, ok := ctx.schedulerCache.UpdateCapacity(node.Name, newCapacity); ok {
-				if err := ctx.updateNodeResources(node, capacity, occupied); err != nil {
-					log.Log(log.ShimContext).Warn("Failed to update node capacity", zap.Error(err))
-				}
+			if err := ctx.updateNodeResources(node, newCapacity); err != nil {
+				log.Log(log.ShimContext).Warn("Failed to update node capacity", zap.Error(err))
 			} else {
 				log.Log(log.ShimContext).Warn("Failed to update cached node capacity", zap.String("nodeName", node.Name))
 			}
@@ -286,7 +297,7 @@ func (ctx *Context) AddPod(obj interface{}) {
 	ctx.UpdatePod(nil, obj)
 }
 
-func (ctx *Context) UpdatePod(_, newObj interface{}) {
+func (ctx *Context) UpdatePod(oldObj, newObj interface{}) {
 	ctx.lock.Lock()
 	defer ctx.lock.Unlock()
 	pod, err := utils.Convert2Pod(newObj)
@@ -294,15 +305,23 @@ func (ctx *Context) UpdatePod(_, newObj interface{}) {
 		log.Log(log.ShimContext).Error("failed to update pod", zap.Error(err))
 		return
 	}
+	var oldPod *v1.Pod
+	if oldObj != nil {
+		oldPod, err = utils.Convert2Pod(oldObj)
+		if err != nil {
+			log.Log(log.ShimContext).Error("failed to update pod", zap.Error(err))
+			return
+		}
+	}
 	applicationID := utils.GetApplicationIDFromPod(pod)
 	if applicationID == "" {
 		ctx.updateForeignPod(pod)
 	} else {
-		ctx.updateYuniKornPod(applicationID, pod)
+		ctx.updateYuniKornPod(applicationID, oldPod, pod)
 	}
 }
 
-func (ctx *Context) updateYuniKornPod(appID string, pod *v1.Pod) {
+func (ctx *Context) updateYuniKornPod(appID string, oldPod, pod *v1.Pod) {
 	taskID := string(pod.UID)
 	app := ctx.getApplication(appID)
 	if app != nil {
@@ -319,7 +338,19 @@ func (ctx *Context) updateYuniKornPod(appID string, pod *v1.Pod) {
 		return
 	}
 
-	if ctx.schedulerCache.UpdatePod(pod) {
+	hasGates := len(pod.Spec.SchedulingGates) > 0
+	if hasGates && oldPod == nil {
+		gates := make([]string, 0, len(pod.Spec.SchedulingGates))
+		for _, gate := range pod.Spec.SchedulingGates {
+			gates = append(gates, gate.Name)
+		}
+		events.GetRecorder().Eventf(pod.DeepCopy(), nil, v1.EventTypeNormal, "Scheduling", "Scheduling",
+			"waiting for scheduling gates: %s", strings.Join(gates, ","))
+		log.Log(log.ShimContext).Info("pod is waiting for scheduling gates", zap.String("name", pod.Name), zap.Strings("gates", gates))
+	}
+
+	// always call UpdatePod() first to make sure the pod instance is the latest in the cache
+	if ctx.schedulerCache.UpdatePod(pod) && !hasGates {
 		// pod was accepted; ensure the application and task objects have been created
 		ctx.ensureAppAndTaskCreated(pod, app)
 	}
@@ -365,23 +396,26 @@ func (ctx *Context) updateForeignPod(pod *v1.Pod) {
 		podStatusBefore = string(oldPod.Status.Phase)
 	}
 
-	// conditions for allocate:
-	//   1. pod was previously assigned
-	//   2. pod is now assigned
-	//   3. pod is not in terminated state
-	//   4. pod references a known node
-	if oldPod == nil && utils.IsAssignedPod(pod) && !utils.IsPodTerminated(pod) {
+	// conditions for allocate/update:
+	//   1. pod is now assigned
+	//   2. pod is not in terminated state
+	//   3. pod references a known node
+	if utils.IsAssignedPod(pod) && !utils.IsPodTerminated(pod) {
 		if ctx.schedulerCache.UpdatePod(pod) {
 			// pod was accepted by a real node
-			log.Log(log.ShimContext).Debug("pod is assigned to a node, trigger occupied resource update",
+			log.Log(log.ShimContext).Debug("pod is assigned to a node, trigger foreign resource update",
 				zap.String("namespace", pod.Namespace),
 				zap.String("podName", pod.Name),
 				zap.String("podStatusBefore", podStatusBefore),
 				zap.String("podStatusCurrent", string(pod.Status.Phase)))
-			ctx.updateNodeOccupiedResources(pod.Spec.NodeName, pod.Namespace, pod.Name, common.GetPodResource(pod), schedulercache.AddOccupiedResource)
+			allocReq := common.CreateAllocationForForeignPod(pod)
+			if err := ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateAllocation(allocReq); err != nil {
+				log.Log(log.ShimContext).Error("failed to add foreign allocation to the core",
+					zap.Error(err))
+			}
 		} else {
 			// pod is orphaned (references an unknown node)
-			log.Log(log.ShimContext).Info("skipping occupied resource update for assigned orphaned pod",
+			log.Log(log.ShimContext).Info("skipping updating allocation for assigned orphaned pod",
 				zap.String("namespace", pod.Namespace),
 				zap.String("podName", pod.Name),
 				zap.String("nodeName", pod.Spec.NodeName))
@@ -395,18 +429,22 @@ func (ctx *Context) updateForeignPod(pod *v1.Pod) {
 	//   3. pod references a known node
 	if oldPod != nil && utils.IsPodTerminated(pod) {
 		if !ctx.schedulerCache.IsPodOrphaned(string(pod.UID)) {
-			log.Log(log.ShimContext).Debug("pod terminated, trigger occupied resource update",
+			log.Log(log.ShimContext).Debug("pod terminated, trigger foreign resource update",
 				zap.String("namespace", pod.Namespace),
 				zap.String("podName", pod.Name),
 				zap.String("podStatusBefore", podStatusBefore),
 				zap.String("podStatusCurrent", string(pod.Status.Phase)))
 			// this means pod is terminated
-			// we need sub the occupied resource and re-sync with the scheduler-core
-			ctx.updateNodeOccupiedResources(pod.Spec.NodeName, pod.Namespace, pod.Name, common.GetPodResource(pod), schedulercache.SubOccupiedResource)
+			// remove from the scheduler cache and create release request to remove foreign allocation from the core
 			ctx.schedulerCache.RemovePod(pod)
+			releaseReq := common.CreateReleaseRequestForForeignPod(string(pod.UID), constants.DefaultPartition)
+			if err := ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateAllocation(releaseReq); err != nil {
+				log.Log(log.ShimContext).Error("failed to remove foreign allocation from the core",
+					zap.Error(err))
+			}
 		} else {
 			// pod is orphaned (references an unknown node)
-			log.Log(log.ShimContext).Info("skipping occupied resource update for terminated orphaned pod",
+			log.Log(log.ShimContext).Info("skipping foreign resource update for terminated orphaned pod",
 				zap.String("namespace", pod.Namespace),
 				zap.String("podName", pod.Name),
 				zap.String("nodeName", pod.Spec.NodeName))
@@ -453,51 +491,14 @@ func (ctx *Context) deleteYuniKornPod(pod *v1.Pod) {
 func (ctx *Context) deleteForeignPod(pod *v1.Pod) {
 	ctx.lock.Lock()
 	defer ctx.lock.Unlock()
-	oldPod := ctx.schedulerCache.GetPod(string(pod.UID))
-	if oldPod == nil {
-		// if pod is not in scheduler cache, no node updates are needed
-		log.Log(log.ShimContext).Debug("unknown foreign pod deleted, no resource updated needed",
-			zap.String("namespace", pod.Namespace),
-			zap.String("podName", pod.Name))
-		return
+	releaseReq := common.CreateReleaseRequestForForeignPod(string(pod.UID), constants.DefaultPartition)
+	if err := ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateAllocation(releaseReq); err != nil {
+		log.Log(log.ShimContext).Error("failed to remove foreign allocation from the core",
+			zap.Error(err))
 	}
 
-	// conditions for release:
-	//   1. pod is already assigned to a node
-	//   2. pod was not in a terminal state before
-	//   3. pod references a known node
-	if !utils.IsPodTerminated(oldPod) {
-		if !ctx.schedulerCache.IsPodOrphaned(string(oldPod.UID)) {
-			log.Log(log.ShimContext).Debug("foreign pod deleted, triggering occupied resource update",
-				zap.String("namespace", pod.Namespace),
-				zap.String("podName", pod.Name),
-				zap.String("podStatusBefore", string(oldPod.Status.Phase)),
-				zap.String("podStatusCurrent", string(pod.Status.Phase)))
-			// this means pod is terminated
-			// we need sub the occupied resource and re-sync with the scheduler-core
-			ctx.updateNodeOccupiedResources(pod.Spec.NodeName, pod.Namespace, pod.Name, common.GetPodResource(pod), schedulercache.SubOccupiedResource)
-		} else {
-			// pod is orphaned (references an unknown node)
-			log.Log(log.ShimContext).Info("skipping occupied resource update for removed orphaned pod",
-				zap.String("namespace", pod.Namespace),
-				zap.String("podName", pod.Name),
-				zap.String("nodeName", pod.Spec.NodeName))
-		}
-		ctx.schedulerCache.RemovePod(pod)
-	}
-}
-
-func (ctx *Context) updateNodeOccupiedResources(nodeName string, namespace string, podName string, resource *si.Resource, opt schedulercache.UpdateType) {
-	if common.IsZero(resource) {
-		return
-	}
-	if node, capacity, occupied, ok := ctx.schedulerCache.UpdateOccupiedResource(nodeName, namespace, podName, resource, opt); ok {
-		if err := ctx.updateNodeResources(node, capacity, occupied); err != nil {
-			log.Log(log.ShimContext).Warn("scheduler rejected update to node occupied resources", zap.Error(err))
-		}
-	} else {
-		log.Log(log.ShimContext).Warn("unable to update occupied resources for node", zap.String("nodeName", nodeName))
-	}
+	log.Log(log.ShimContext).Debug("removing pod from cache", zap.String("podName", pod.Name))
+	ctx.schedulerCache.RemovePod(pod)
 }
 
 // filter configMap for the scheduler
@@ -1530,7 +1531,6 @@ func (ctx *Context) registerNodes(nodes []*v1.Node) ([]*v1.Node, error) {
 				constants.DefaultNodeAttributeRackNameKey: constants.DefaultRackName,
 			},
 			SchedulableResource: common.GetNodeResource(&nodeStatus),
-			OccupiedResource:    common.NewResourceBuilder().Build(),
 		})
 		pendingNodes[node.Name] = node
 	}
@@ -1612,8 +1612,8 @@ func (ctx *Context) decommissionNode(node *v1.Node) error {
 	return ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateNode(request)
 }
 
-func (ctx *Context) updateNodeResources(node *v1.Node, capacity *si.Resource, occupied *si.Resource) error {
-	request := common.CreateUpdateRequestForUpdatedNode(node.Name, capacity, occupied)
+func (ctx *Context) updateNodeResources(node *v1.Node, capacity *si.Resource) error {
+	request := common.CreateUpdateRequestForUpdatedNode(node.Name, capacity)
 	return ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateNode(request)
 }
 
@@ -1654,14 +1654,14 @@ func (ctx *Context) finalizeNodes(existingNodes []*v1.Node) error {
 	}
 
 	// convert the node list into a map
-	nodeMap := make(map[string]*v1.Node)
+	nodeMap := make(map[string]bool, len(nodes))
 	for _, node := range nodes {
-		nodeMap[node.Name] = node
+		nodeMap[node.Name] = true
 	}
 
 	// find any existing nodes that no longer exist
 	for _, node := range existingNodes {
-		if _, ok := nodeMap[node.Name]; !ok {
+		if !nodeMap[node.Name] {
 			// node no longer exists, delete it
 			log.Log(log.ShimContext).Info("Removing node which went away during initialization",
 				zap.String("name", node.Name))
@@ -1710,13 +1710,13 @@ func (ctx *Context) finalizePods(existingPods []*v1.Pod) error {
 	}
 
 	// convert the pod list into a map
-	podMap := make(map[types.UID]*v1.Pod)
+	podMap := make(map[types.UID]bool, len(pods))
 	for _, pod := range pods {
 		// if the pod is terminated finalising should remove it if it was running in register
 		if utils.IsPodTerminated(pod) {
 			continue
 		}
-		podMap[pod.UID] = pod
+		podMap[pod.UID] = true
 	}
 
 	// find any existing pods that no longer exist
@@ -1725,7 +1725,7 @@ func (ctx *Context) finalizePods(existingPods []*v1.Pod) error {
 		if pod == nil {
 			continue
 		}
-		if _, ok := podMap[pod.UID]; !ok {
+		if !podMap[pod.UID] {
 			// pod no longer exists, delete it
 			log.Log(log.ShimContext).Info("Removing pod which went away during initialization",
 				zap.String("namespace", pod.Namespace),
