@@ -22,6 +22,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"strings"
+	"sync/atomic"
 	"testing"
 	"time"
 
@@ -35,14 +36,11 @@ import (
 	k8sEvents "k8s.io/client-go/tools/events"
 	"k8s.io/kubernetes/pkg/scheduler/framework/plugins/volumebinding"
 
-	schedulercache "github.com/apache/yunikorn-k8shim/pkg/cache/external"
 	"github.com/apache/yunikorn-k8shim/pkg/client"
-	"github.com/apache/yunikorn-k8shim/pkg/common"
 	"github.com/apache/yunikorn-k8shim/pkg/common/constants"
 	"github.com/apache/yunikorn-k8shim/pkg/common/events"
 	"github.com/apache/yunikorn-k8shim/pkg/common/test"
 	"github.com/apache/yunikorn-k8shim/pkg/common/utils"
-	"github.com/apache/yunikorn-k8shim/pkg/conf"
 	"github.com/apache/yunikorn-k8shim/pkg/dispatcher"
 	"github.com/apache/yunikorn-k8shim/pkg/log"
 	siCommon "github.com/apache/yunikorn-scheduler-interface/lib/go/common"
@@ -75,11 +73,13 @@ const (
 	taskUID4    = "task00004"
 	taskUnknown = "non_existing_taskID"
 
-	podName1     = "pod1"
-	podName2     = "pod2"
-	podName3     = "pod3"
-	podName4     = "pod4"
-	podNamespace = "yk"
+	podName1       = "pod1"
+	podName2       = "pod2"
+	podName3       = "pod3"
+	podName4       = "pod4"
+	podForeignName = "foreign-1"
+	podForeignUID  = "UUID-foreign-1"
+	podNamespace   = "yk"
 
 	nodeName1    = "node1"
 	nodeName2    = "node2"
@@ -103,7 +103,6 @@ func initContextForTest() *Context {
 }
 
 func initContextAndAPIProviderForTest() (*Context, *client.MockedAPIProvider) {
-	conf.GetSchedulerConf().SetTestMode(true)
 	apis := client.NewMockedAPIProvider(false)
 	context := NewContext(apis)
 	return context, apis
@@ -182,8 +181,8 @@ func TestUpdateNodes(t *testing.T) {
 	})
 
 	oldNodeResource := make(map[v1.ResourceName]resource.Quantity)
-	oldNodeResource[v1.ResourceName("memory")] = *resource.NewQuantity(1024*1000*1000, resource.DecimalSI)
-	oldNodeResource[v1.ResourceName("cpu")] = *resource.NewQuantity(2, resource.DecimalSI)
+	oldNodeResource["memory"] = *resource.NewQuantity(1024*1000*1000, resource.DecimalSI)
+	oldNodeResource["cpu"] = *resource.NewQuantity(2, resource.DecimalSI)
 	oldNode := v1.Node{
 		ObjectMeta: apis.ObjectMeta{
 			Name:      Host1,
@@ -196,8 +195,8 @@ func TestUpdateNodes(t *testing.T) {
 	}
 
 	newNodeResource := make(map[v1.ResourceName]resource.Quantity)
-	newNodeResource[v1.ResourceName("memory")] = *resource.NewQuantity(2048*1000*1000, resource.DecimalSI)
-	newNodeResource[v1.ResourceName("cpu")] = *resource.NewQuantity(4, resource.DecimalSI)
+	newNodeResource["memory"] = *resource.NewQuantity(2048*1000*1000, resource.DecimalSI)
+	newNodeResource["cpu"] = *resource.NewQuantity(4, resource.DecimalSI)
 	newNode := v1.Node{
 		ObjectMeta: apis.ObjectMeta{
 			Name:      Host1,
@@ -211,12 +210,6 @@ func TestUpdateNodes(t *testing.T) {
 
 	ctx.addNode(&oldNode)
 	ctx.updateNode(&oldNode, &newNode)
-
-	_, capacity, _, ok := ctx.schedulerCache.UpdateOccupiedResource(
-		Host1, "n/a", "n/a", nil, schedulercache.AddOccupiedResource)
-	assert.Assert(t, ok, "unable to retrieve node capacity")
-	assert.Equal(t, int64(2048*1000*1000), capacity.Resources[siCommon.Memory].Value)
-	assert.Equal(t, int64(4000), capacity.Resources[siCommon.CPU].Value)
 }
 
 func TestDeleteNodes(t *testing.T) {
@@ -393,7 +386,7 @@ func TestAddPod(t *testing.T) {
 	assert.Check(t, pod == nil, "terminated pod was added")
 }
 
-func TestUpdatePod(t *testing.T) {
+func TestUpdatePod(t *testing.T) { //nolint:funlen
 	context := initContextForTest()
 
 	pod1 := &v1.Pod{
@@ -452,6 +445,9 @@ func TestUpdatePod(t *testing.T) {
 	context.UpdatePod(nil, nil)
 	context.UpdatePod(nil, pod1)
 	context.UpdatePod(pod1, nil)
+	context.UpdatePod(&v1.Node{}, pod2)
+	podFromCache := context.schedulerCache.GetPod(uid1)
+	assert.Equal(t, "new", podFromCache.Annotations["test.state"])
 
 	// ensure a terminated pod is removed
 	context.UpdatePod(pod1, pod3)
@@ -468,6 +464,71 @@ func TestUpdatePod(t *testing.T) {
 	if assert.Check(t, found != nil, "pod not found after update") {
 		assert.Check(t, found.GetAnnotations()["test.state"] == "updated", "pod state not updated")
 	}
+
+	// scheduling gated pod
+	recorder := k8sEvents.NewFakeRecorder(1024)
+	events.SetRecorder(recorder)
+	defer events.SetRecorder(events.NewMockedRecorder())
+	pod4 := &v1.Pod{
+		TypeMeta: apis.TypeMeta{
+			Kind:       "Pod",
+			APIVersion: "v1",
+		},
+		ObjectMeta: apis.ObjectMeta{
+			Name: appID2,
+			UID:  uid2,
+			Annotations: map[string]string{
+				constants.AnnotationApplicationID: appID2,
+			},
+		},
+		Spec: v1.PodSpec{
+			SchedulerName: "yunikorn",
+			SchedulingGates: []v1.PodSchedulingGate{
+				{Name: "gate1"},
+				{Name: "gate2"},
+			},
+		},
+		Status: v1.PodStatus{
+			Phase: v1.PodPending,
+		},
+	}
+	context.UpdatePod(nil, pod4)
+	// check that the event has been published
+	select {
+	case event := <-recorder.Events:
+		assert.Assert(t, strings.Contains(event, "waiting for scheduling gates: gate1,gate2"), "unexpected k8s event received for gated pod: %s", event)
+	default:
+		t.Error("no k8s event received for gated pod")
+	}
+	assert.Assert(t, context.schedulerCache.GetPod(uid2) != nil, "pod was not found in scheduler cache")
+	assert.Assert(t, context.getApplication(appID2) == nil, "application was created")
+	pod5 := pod4.DeepCopy()
+	pod5.Spec.SchedulingGates = []v1.PodSchedulingGate{{Name: "gate1"}} // remove a single gate
+	context.UpdatePod(pod4, pod5)
+	// no events expected
+	select {
+	case event := <-recorder.Events:
+		t.Errorf("no k8s event expected, got: %s", event)
+	default:
+	}
+	pod5Cache := context.schedulerCache.GetPod(uid2)
+	assert.Assert(t, pod5Cache != nil, "pod was removed from the scheduler cache")
+	assert.Assert(t, context.getApplication(appID2) == nil, "application was created unexpectedly")
+	assert.Equal(t, 1, len(pod5Cache.Spec.SchedulingGates), "pod was not updated properly in the cache")
+	pod6 := pod5.DeepCopy()
+	pod6.Spec.SchedulingGates = nil // remove remaining gate
+	context.UpdatePod(pod5, pod6)
+	// no events expected
+	select {
+	case event := <-recorder.Events:
+		t.Errorf("no k8s event expected, got: %s", event)
+	default:
+	}
+	pod6Cache := context.schedulerCache.GetPod(uid2)
+	assert.Assert(t, pod6Cache != nil, "pod was removed from the scheduler cache")
+	assert.Equal(t, 0, len(pod6Cache.Spec.SchedulingGates), "pod was not updated properly in the cache")
+	assert.Assert(t, context.getApplication(appID2) != nil, "application was not created")
+	assert.Assert(t, context.getTask(appID2, uid2) != nil, "task was not created")
 }
 
 func TestDeletePod(t *testing.T) {
@@ -529,39 +590,11 @@ func TestAddUpdatePodForeign(t *testing.T) {
 	defer dispatcher.UnregisterAllEventHandlers()
 	defer dispatcher.Stop()
 
-	executed := false
-	expectAdd := false
-	expectRemove := false
-	tc := ""
-
-	validatorFunc := func(request *si.NodeRequest) error {
-		assert.Equal(t, len(request.Nodes), 1, "%s: wrong node count", tc)
-		updatedNode := request.Nodes[0]
-		assert.Equal(t, updatedNode.NodeID, Host1, "%s: wrong nodeID", tc)
-		switch updatedNode.Action {
-		case si.NodeInfo_CREATE_DRAIN:
-			return nil
-		case si.NodeInfo_DRAIN_TO_SCHEDULABLE:
-			return nil
-		case si.NodeInfo_UPDATE:
-			executed = true
-		default:
-			assert.Equal(t, false, "Unexpected action: %d", updatedNode.Action)
-			return nil
-		}
-		assert.Equal(t, updatedNode.SchedulableResource.Resources[siCommon.Memory].Value, int64(10000*1000*1000), "%s: wrong schedulable memory", tc)
-		assert.Equal(t, updatedNode.SchedulableResource.Resources[siCommon.CPU].Value, int64(10000), "%s: wrong schedulable cpu", tc)
-		if expectAdd {
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.Memory].Value, int64(1000*1000*1000), "%s: wrong occupied memory (add)", tc)
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.CPU].Value, int64(500), "%s: wrong occupied cpu (add)", tc)
-		}
-		if expectRemove {
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.Memory].Value, int64(0), "%s: wrong occupied memory (remove)", tc)
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.CPU].Value, int64(0), "%s: wrong occupied cpu (remove)", tc)
-		}
+	var allocRequest *si.AllocationRequest
+	apiProvider.MockSchedulerAPIUpdateAllocationFn(func(request *si.AllocationRequest) error {
+		allocRequest = request
 		return nil
-	}
-
+	})
 	apiProvider.MockSchedulerAPIUpdateNodeFn(func(request *si.NodeRequest) error {
 		for _, node := range request.Nodes {
 			if node.Action == si.NodeInfo_CREATE_DRAIN {
@@ -571,10 +604,10 @@ func TestAddUpdatePodForeign(t *testing.T) {
 				})
 			}
 		}
-		return validatorFunc(request)
+		return nil
 	})
 
-	host1 := nodeForTest(Host1, "10G", "10")
+	host1 := nodeForTest(Host1, "10G", "10") // add existing foreign pod
 	context.updateNode(nil, host1)
 
 	// pod is not assigned to any node
@@ -582,22 +615,18 @@ func TestAddUpdatePodForeign(t *testing.T) {
 	pod1.Status.Phase = v1.PodPending
 	pod1.Spec.NodeName = ""
 
-	// validate add
-	tc = "add-pod1"
-	executed = false
-	expectAdd = false
-	expectRemove = false
+	// validate add (pending, no node assigned)
+	allocRequest = nil
 	context.AddPod(pod1)
-	assert.Assert(t, !executed, "unexpected update")
+	assert.Assert(t, allocRequest == nil, "unexpected update")
 	pod := context.schedulerCache.GetPod(string(pod1.UID))
 	assert.Assert(t, pod == nil, "unassigned pod found in cache")
 
-	// validate update
-	tc = "update-pod1"
-	executed = false
-	expectRemove = false
+	// validate update (no change)
+	allocRequest = nil
 	context.UpdatePod(nil, pod1)
-	assert.Assert(t, !executed, "unexpected update")
+	assert.Assert(t, allocRequest == nil, "unexpected update")
+	pod = context.schedulerCache.GetPod(string(pod1.UID))
 	assert.Assert(t, pod == nil, "unassigned pod found in cache")
 
 	// pod is assigned to a node but still in pending state, should update
@@ -606,155 +635,93 @@ func TestAddUpdatePodForeign(t *testing.T) {
 	pod2.Spec.NodeName = Host1
 
 	// validate add
-	tc = "add-pod2"
-	executed = false
-	expectAdd = true
-	expectRemove = false
 	context.AddPod(pod2)
-	assert.Assert(t, executed, "updated expected")
+	assert.Assert(t, allocRequest != nil, "update expected")
+	assertAddForeignPod(t, podName2, Host1, allocRequest)
 	pod = context.schedulerCache.GetPod(string(pod2.UID))
 	assert.Assert(t, pod != nil, "pod not found in cache")
 
-	// validate update
-	tc = "update-pod2"
-	executed = false
-	expectAdd = false
-	expectRemove = false
+	// validate update (no change)
+	allocRequest = nil
 	context.UpdatePod(nil, pod2)
-	assert.Assert(t, !executed, "unexpected update")
+	assert.Assert(t, allocRequest != nil, "update expected")
 	pod = context.schedulerCache.GetPod(string(pod2.UID))
 	assert.Assert(t, pod != nil, "pod not found in cache")
 
 	// validate update when not already in cache
-	tc = "update-pod2-nocache-pre"
-	executed = false
-	expectAdd = false
-	expectRemove = true
+	allocRequest = nil
 	context.DeletePod(pod2)
-	assert.Assert(t, executed, "expected update")
-	tc = "update-pod2-nocache"
-	executed = false
-	expectAdd = true
-	expectRemove = false
+	assertReleaseForeignPod(t, podName2, allocRequest)
+
+	allocRequest = nil
 	context.UpdatePod(nil, pod2)
-	assert.Assert(t, executed, "expected update")
+	assert.Assert(t, allocRequest != nil, "expected update")
 	pod = context.schedulerCache.GetPod(string(pod2.UID))
 	assert.Assert(t, pod != nil, "pod not found in cache")
+	assertAddForeignPod(t, podName2, Host1, allocRequest)
 
 	// pod is failed, should trigger update if already in cache
 	pod3 := pod2.DeepCopy()
 	pod3.Status.Phase = v1.PodFailed
 
 	// validate add
-	tc = "add-pod3"
-	executed = false
-	expectAdd = false
-	expectRemove = true
+	allocRequest = nil
 	context.AddPod(pod3)
-	assert.Assert(t, executed, "expected update")
+	assert.Assert(t, allocRequest != nil, "expected update")
 	pod = context.schedulerCache.GetPod(string(pod3.UID))
 	assert.Assert(t, pod == nil, "failed pod found in cache")
+	assert.Assert(t, allocRequest.Releases != nil) // expecting a release due to pod status
+	assertReleaseForeignPod(t, podName2, allocRequest)
+}
 
-	// validate update when not already in cache
-	tc = "update-pod3-pre"
-	executed = false
-	expectAdd = true
-	expectRemove = false
-	context.AddPod(pod2)
-	tc = "update-pod3"
-	executed = false
-	expectAdd = false
-	expectRemove = true
-	context.UpdatePod(nil, pod3)
-	assert.Assert(t, executed, "expected update")
-	pod = context.schedulerCache.GetPod(string(pod3.UID))
-	assert.Assert(t, pod == nil, "failed pod found in cache")
+func assertAddForeignPod(t *testing.T, podName, host string, allocRequest *si.AllocationRequest) {
+	t.Helper()
+	assert.Equal(t, 1, len(allocRequest.Allocations))
+	tags := allocRequest.Allocations[0].AllocationTags
+	assert.Equal(t, 4, len(tags))
+	assert.Equal(t, siCommon.AllocTypeDefault, tags[siCommon.Foreign])
+	assert.Equal(t, tags["kubernetes.io/meta/namespace"], "testNamespace")
+	assert.Equal(t, tags["kubernetes.io/meta/podName"], podName)
+	assert.Equal(t, podName, allocRequest.Allocations[0].AllocationKey)
+	assert.Equal(t, host, allocRequest.Allocations[0].NodeID)
+}
+
+func assertReleaseForeignPod(t *testing.T, podName string, allocRequest *si.AllocationRequest) {
+	t.Helper()
+	assert.Assert(t, allocRequest.Releases != nil)
+	assert.Equal(t, 1, len(allocRequest.Releases.AllocationsToRelease))
+	assert.Equal(t, podName, allocRequest.Releases.AllocationsToRelease[0].AllocationKey)
+	assert.Equal(t, constants.DefaultPartition, allocRequest.Releases.AllocationsToRelease[0].PartitionName)
+	assert.Equal(t, "", allocRequest.Releases.AllocationsToRelease[0].ApplicationID)
+	assert.Equal(t, si.TerminationType_STOPPED_BY_RM, allocRequest.Releases.AllocationsToRelease[0].TerminationType)
 }
 
 func TestDeletePodForeign(t *testing.T) {
 	context, apiProvider := initContextAndAPIProviderForTest()
-	dispatcher.Start()
-	defer dispatcher.UnregisterAllEventHandlers()
-	defer dispatcher.Stop()
 
-	executed := false
-	expectAdd := false
-	expectRemove := false
-	tc := ""
-
-	validatorFunc := func(request *si.NodeRequest) error {
-		executed = true
-		assert.Equal(t, len(request.Nodes), 1, "%s: wrong node count", tc)
-		updatedNode := request.Nodes[0]
-		switch updatedNode.Action {
-		case si.NodeInfo_CREATE_DRAIN:
-			return nil
-		case si.NodeInfo_DRAIN_TO_SCHEDULABLE:
-			return nil
-		case si.NodeInfo_UPDATE:
-			executed = true
-		default:
-			assert.Equal(t, false, "Unexpected action: %d", updatedNode.Action)
-			return nil
-		}
-		assert.Equal(t, updatedNode.NodeID, Host1, "%s: wrong nodeID", tc)
-		assert.Equal(t, updatedNode.Action, si.NodeInfo_UPDATE, "%s: wrong action", tc)
-		assert.Equal(t, updatedNode.SchedulableResource.Resources[siCommon.Memory].Value, int64(10000*1000*1000), "%s: wrong schedulable memory", tc)
-		assert.Equal(t, updatedNode.SchedulableResource.Resources[siCommon.CPU].Value, int64(10000), "%s: wrong schedulable cpu", tc)
-		if expectAdd {
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.Memory].Value, int64(1000*1000*1000), "%s: wrong occupied memory (add)", tc)
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.CPU].Value, int64(500), "%s: wrong occupied cpu (add)", tc)
-		}
-		if expectRemove {
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.Memory].Value, int64(0), "%s: wrong occupied memory (remove)", tc)
-			assert.Equal(t, updatedNode.OccupiedResource.Resources[siCommon.CPU].Value, int64(0), "%s: wrong occupied cpu (remove)", tc)
-		}
+	var allocRequest *si.AllocationRequest
+	apiProvider.MockSchedulerAPIUpdateAllocationFn(func(request *si.AllocationRequest) error {
+		allocRequest = request
 		return nil
-	}
-
-	apiProvider.MockSchedulerAPIUpdateNodeFn(func(request *si.NodeRequest) error {
-		for _, node := range request.Nodes {
-			if node.Action == si.NodeInfo_CREATE_DRAIN {
-				dispatcher.Dispatch(CachedSchedulerNodeEvent{
-					NodeID: node.NodeID,
-					Event:  NodeAccepted,
-				})
-			}
-		}
-		return validatorFunc(request)
 	})
 
-	host1 := nodeForTest(Host1, "10G", "10")
-	context.updateNode(nil, host1)
-
-	// add existing pod
+	// add existing foreign pod
 	pod1 := foreignPod(podName1, "1G", "500m")
 	pod1.Status.Phase = v1.PodRunning
 	pod1.Spec.NodeName = Host1
-
-	// validate deletion of existing assigned pod
-	tc = "delete-pod1-pre"
-	executed = false
-	expectAdd = true
-	expectRemove = false
 	context.AddPod(pod1)
-	tc = "delete-pod1"
-	executed = false
-	expectAdd = false
-	expectRemove = true
+	allocRequest = nil
 	context.DeletePod(pod1)
-	assert.Assert(t, executed, "update not executed")
-	pod := context.schedulerCache.GetPod(string(pod1.UID))
-	assert.Assert(t, pod == nil, "deleted pod found in cache")
 
-	// validate delete when not already found
-	tc = "delete-pod1-again"
-	executed = false
-	expectAdd = false
-	expectRemove = false
-	context.DeletePod(pod1)
-	assert.Assert(t, !executed, "unexpected update")
-	pod = context.schedulerCache.GetPod(string(pod1.UID))
+	assert.Assert(t, allocRequest != nil, "update not executed")
+	assert.Equal(t, 0, len(allocRequest.Allocations))
+	assert.Assert(t, allocRequest.Releases != nil)
+	assert.Equal(t, 1, len(allocRequest.Releases.AllocationsToRelease))
+	assert.Equal(t, podName1, allocRequest.Releases.AllocationsToRelease[0].AllocationKey)
+	assert.Equal(t, constants.DefaultPartition, allocRequest.Releases.AllocationsToRelease[0].PartitionName)
+	assert.Equal(t, "", allocRequest.Releases.AllocationsToRelease[0].ApplicationID)
+	assert.Equal(t, si.TerminationType_STOPPED_BY_RM, allocRequest.Releases.AllocationsToRelease[0].TerminationType)
+	pod := context.schedulerCache.GetPod(string(pod1.UID))
 	assert.Assert(t, pod == nil, "deleted pod found in cache")
 }
 
@@ -1160,11 +1127,9 @@ func TestGetTask(t *testing.T) {
 }
 
 func TestNodeEventFailsPublishingWithoutNode(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
-	recorder, ok := events.GetRecorder().(*k8sEvents.FakeRecorder)
-	if !ok {
-		t.Fatal("the EventRecorder is expected to be of type FakeRecorder")
-	}
+	recorder := k8sEvents.NewFakeRecorder(1024)
+	events.SetRecorder(recorder)
+	defer events.SetRecorder(events.NewMockedRecorder())
 	context := initContextForTest()
 
 	eventRecords := make([]*si.EventRecord, 0)
@@ -1189,11 +1154,9 @@ func TestNodeEventFailsPublishingWithoutNode(t *testing.T) {
 }
 
 func TestNodeEventPublishedCorrectly(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
-	recorder, ok := events.GetRecorder().(*k8sEvents.FakeRecorder)
-	if !ok {
-		t.Fatal("the EventRecorder is expected to be of type FakeRecorder")
-	}
+	recorder := k8sEvents.NewFakeRecorder(1024)
+	events.SetRecorder(recorder)
+	defer events.SetRecorder(events.NewMockedRecorder())
 
 	context, apiProvider := initContextAndAPIProviderForTest()
 	dispatcher.Start()
@@ -1250,11 +1213,9 @@ func TestNodeEventPublishedCorrectly(t *testing.T) {
 }
 
 func TestFilteredEventsNotPublished(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
-	recorder, ok := events.GetRecorder().(*k8sEvents.FakeRecorder)
-	if !ok {
-		t.Fatal("the EventRecorder is expected to be of type FakeRecorder")
-	}
+	recorder := k8sEvents.NewFakeRecorder(1024)
+	events.SetRecorder(recorder)
+	defer events.SetRecorder(events.NewMockedRecorder())
 
 	context, apiProvider := initContextAndAPIProviderForTest()
 	dispatcher.Start()
@@ -1335,11 +1296,10 @@ func TestFilteredEventsNotPublished(t *testing.T) {
 }
 
 func TestPublishEventsWithNotExistingAsk(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
-	recorder, ok := events.GetRecorder().(*k8sEvents.FakeRecorder)
-	if !ok {
-		t.Fatal("the EventRecorder is expected to be of type FakeRecorder")
-	}
+	recorder := k8sEvents.NewFakeRecorder(1024)
+	events.SetRecorder(recorder)
+	defer events.SetRecorder(events.NewMockedRecorder())
+
 	context := initContextForTest()
 	context.AddApplication(&AddApplicationRequest{
 		Metadata: ApplicationMetadata{
@@ -1376,11 +1336,10 @@ func TestPublishEventsWithNotExistingAsk(t *testing.T) {
 }
 
 func TestPublishEventsCorrectly(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
-	recorder, ok := events.GetRecorder().(*k8sEvents.FakeRecorder)
-	if !ok {
-		t.Fatal("the EventRecorder is expected to be of type FakeRecorder")
-	}
+	recorder := k8sEvents.NewFakeRecorder(1024)
+	events.SetRecorder(recorder)
+	defer events.SetRecorder(events.NewMockedRecorder())
+
 	context := initContextForTest()
 
 	// create fake application and task
@@ -2000,6 +1959,10 @@ func TestInitializeState(t *testing.T) {
 		},
 	}}
 	podLister.AddPod(orphaned)
+	// add an orphan foreign pod
+	orphanForeign := newPodHelper(podForeignName, "default", podForeignUID, nodeName2, "", v1.PodRunning)
+	orphanForeign.Spec.SchedulerName = ""
+	podLister.AddPod(orphanForeign)
 
 	err := context.InitializeState()
 	assert.NilError(t, err, "InitializeState failed")
@@ -2011,20 +1974,14 @@ func TestInitializeState(t *testing.T) {
 	assert.Equal(t, *pc.PreemptionPolicy, policy, "wrong preemption policy")
 	assert.Equal(t, pc.Annotations[constants.AnnotationAllowPreemption], constants.True, "wrong allow-preemption value")
 
-	// verify occupied / capacity on node
-	capacity, occupied, ok := context.schedulerCache.SnapshotResources(nodeName1)
-	assert.Assert(t, ok, "Unable to retrieve node resources")
-	expectedCapacity := common.ParseResource("4", "10G")
-	assert.Equal(t, expectedCapacity.Resources["vcore"].Value, capacity.Resources["vcore"].Value, "wrong capacity vcore")
-	assert.Equal(t, expectedCapacity.Resources["memory"].Value, capacity.Resources["memory"].Value, "wrong capacity memory")
-	expectedOccupied := common.ParseResource("1500m", "2G")
-	assert.Equal(t, expectedOccupied.Resources["vcore"].Value, occupied.Resources["vcore"].Value, "wrong occupied vcore")
-	assert.Equal(t, expectedOccupied.Resources["memory"].Value, occupied.Resources["memory"].Value, "wrong occupied memory")
-
 	// check that pod orphan status is correct
 	assert.Check(t, !context.schedulerCache.IsPodOrphaned(podName1), "pod1 should not be orphaned")
 	assert.Check(t, !context.schedulerCache.IsPodOrphaned(podName2), "pod2 should not be orphaned")
 	assert.Check(t, context.schedulerCache.IsPodOrphaned(podName3), "pod3 should be orphaned")
+	assert.Check(t, context.schedulerCache.IsPodOrphaned(podForeignUID), "foreign pod should be orphaned")
+	assert.Check(t, context.schedulerCache.GetPod("foreignRunning") != nil, "foreign running pod is not in the cache")
+	assert.Check(t, context.schedulerCache.GetPod("foreignPending") == nil, "foreign pending pod should not be in the cache")
+	assert.Check(t, !context.schedulerCache.IsPodOrphaned("foreignRunning"), "foreign running pod should not be orphaned")
 
 	// pod1 is pending
 	task1 := context.getTask(appID1, podName1)
@@ -2041,6 +1998,145 @@ func TestInitializeState(t *testing.T) {
 	assert.Assert(t, task3 == nil, "pod3 was found")
 }
 
+func TestPodAdoption(t *testing.T) {
+	ctx, apiProvider := initContextAndAPIProviderForTest()
+	dispatcher.Start()
+	defer dispatcher.UnregisterAllEventHandlers()
+	defer dispatcher.Stop()
+	apiProvider.MockSchedulerAPIUpdateNodeFn(func(request *si.NodeRequest) error {
+		for _, node := range request.Nodes {
+			dispatcher.Dispatch(CachedSchedulerNodeEvent{
+				NodeID: node.NodeID,
+				Event:  NodeAccepted,
+			})
+		}
+		return nil
+	})
+
+	// add pods w/o node & check orphan status
+	pod1 := newPodHelper(podName1, namespace, pod1UID, Host1, appID, v1.PodRunning)
+	pod2 := newPodHelper(podForeignName, namespace, podForeignUID, Host1, "", v1.PodRunning)
+	pod2.Spec.SchedulerName = ""
+	ctx.AddPod(pod1)
+	ctx.AddPod(pod2)
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(pod1UID), "Yunikorn pod is not orphan")
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(podForeignUID), "foreign pod is not orphan")
+
+	// add node
+	node := v1.Node{
+		ObjectMeta: apis.ObjectMeta{
+			Name:      Host1,
+			Namespace: "default",
+			UID:       uid1,
+		},
+	}
+	ctx.addNode(&node)
+
+	// check that node has adopted the pods
+	assert.Assert(t, !ctx.schedulerCache.IsPodOrphaned(pod1UID), "Yunikorn pod has not been adopted")
+	assert.Assert(t, !ctx.schedulerCache.IsPodOrphaned(podForeignUID), "foreign pod has not been adopted")
+}
+
+func TestOrphanPodUpdate(t *testing.T) {
+	ctx, apiProvider := initContextAndAPIProviderForTest()
+	dispatcher.Start()
+	defer dispatcher.UnregisterAllEventHandlers()
+	defer dispatcher.Stop()
+	var update atomic.Bool
+	apiProvider.MockSchedulerAPIUpdateAllocationFn(func(request *si.AllocationRequest) error {
+		update.Store(true)
+		return nil
+	})
+
+	// add pods w/o node & check orphan status
+	pod1 := newPodHelper(podName1, namespace, pod1UID, Host1, appID, v1.PodPending)
+	pod2 := newPodHelper(podForeignName, namespace, podForeignUID, Host1, "", v1.PodPending)
+	pod2.Spec.SchedulerName = ""
+	ctx.AddPod(pod1)
+	ctx.AddPod(pod2)
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(pod1UID), "Yunikorn pod is not orphan")
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(podForeignUID), "foreign pod is not orphan")
+	assert.Assert(t, ctx.getApplication(appID) == nil)
+
+	// update orphan pods
+	pod1Upd := pod1.DeepCopy()
+	pod1Upd.Status.Phase = v1.PodRunning
+	pod2Upd := pod2.DeepCopy()
+	pod2Upd.Status.Phase = v1.PodRunning
+
+	ctx.UpdatePod(pod1, pod1Upd)
+	assert.Assert(t, ctx.getApplication(appID) == nil)
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(pod1UID), "Yunikorn pod is not orphan after update")
+	assert.Equal(t, v1.PodRunning, ctx.schedulerCache.GetPod(pod1UID).Status.Phase, "pod has not been updated in the cache")
+	assert.Assert(t, !update.Load(), "allocation update has been triggered for Yunikorn orphan pod")
+
+	ctx.UpdatePod(pod2, pod2Upd)
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(podForeignUID), "foreign pod is not orphan after update")
+	assert.Equal(t, v1.PodRunning, ctx.schedulerCache.GetPod(podForeignUID).Status.Phase, "foreign pod has not been updated in the cache")
+	assert.Assert(t, !update.Load(), "allocation update has been triggered for foreign orphan pod")
+}
+
+func TestOrphanPodDelete(t *testing.T) {
+	ctx, apiProvider := initContextAndAPIProviderForTest()
+	dispatcher.Start()
+	defer dispatcher.UnregisterAllEventHandlers()
+	defer dispatcher.Stop()
+	var taskEventSent atomic.Bool
+	dispatcher.RegisterEventHandler("TestTaskHandler", dispatcher.EventTypeTask, func(obj interface{}) {
+		taskEventSent.Store(true)
+	})
+	var request *si.AllocationRequest
+	apiProvider.MockSchedulerAPIUpdateAllocationFn(func(r *si.AllocationRequest) error {
+		request = r
+		return nil
+	})
+	apiProvider.MockSchedulerAPIUpdateNodeFn(func(request *si.NodeRequest) error {
+		for _, node := range request.Nodes {
+			dispatcher.Dispatch(CachedSchedulerNodeEvent{
+				NodeID: node.NodeID,
+				Event:  NodeAccepted,
+			})
+		}
+		return nil
+	})
+
+	// add pods w/o node & check orphan status
+	pod1 := newPodHelper(podName1, namespace, pod1UID, Host1, appID, v1.PodPending)
+	pod2 := newPodHelper(podForeignName, namespace, podForeignUID, Host1, "", v1.PodPending)
+	pod2.Spec.SchedulerName = ""
+	ctx.AddPod(pod1)
+	ctx.AddPod(pod2)
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(pod1UID), "Yunikorn pod is not orphan")
+	assert.Assert(t, ctx.schedulerCache.IsPodOrphaned(podForeignUID), "foreign pod is not orphan")
+	assert.Assert(t, ctx.getApplication(appID) == nil)
+
+	// add a node with pod - this creates the application object
+	node := v1.Node{
+		ObjectMeta: apis.ObjectMeta{
+			Name:      Host2,
+			Namespace: "default",
+			UID:       uid1,
+		},
+	}
+	ctx.addNode(&node)
+	pod3 := newPodHelper(podName2, namespace, pod2UID, Host2, appID, v1.PodPending)
+	ctx.AddPod(pod3)
+	assert.Assert(t, !ctx.schedulerCache.IsPodOrphaned(pod2UID), "Yunikorn pod is orphan")
+	assert.Assert(t, ctx.getApplication(appID) != nil)
+
+	// delete orphan YK pod
+	ctx.DeletePod(pod1)
+	err := utils.WaitForCondition(taskEventSent.Load, 100*time.Millisecond, time.Second)
+	assert.NilError(t, err)
+
+	// delete foreign pod
+	ctx.DeletePod(pod2)
+	assert.Assert(t, request != nil)
+	assert.Assert(t, request.Releases != nil)
+	assert.Equal(t, 1, len(request.Releases.AllocationsToRelease))
+	assert.Equal(t, podForeignUID, request.Releases.AllocationsToRelease[0].AllocationKey)
+}
+
 func TestTaskRemoveOnCompletion(t *testing.T) {
 	context := initContextForTest()
 	dispatcher.Start()
@@ -2361,8 +2457,9 @@ func foreignPod(podName, memory, cpu string) *v1.Pod {
 			APIVersion: "v1",
 		},
 		ObjectMeta: apis.ObjectMeta{
-			Name: podName,
-			UID:  types.UID(podName),
+			Name:      podName,
+			UID:       types.UID(podName),
+			Namespace: "testNamespace",
 		},
 		Spec: v1.PodSpec{
 			Containers: containers,
