@@ -32,18 +32,9 @@ import (
 	"k8s.io/kubernetes/pkg/scheduler/framework"
 
 	"github.com/apache/yunikorn-k8shim/pkg/client"
-	"github.com/apache/yunikorn-k8shim/pkg/common"
 	"github.com/apache/yunikorn-k8shim/pkg/common/utils"
 	"github.com/apache/yunikorn-k8shim/pkg/locking"
 	"github.com/apache/yunikorn-k8shim/pkg/log"
-	"github.com/apache/yunikorn-scheduler-interface/lib/go/si"
-)
-
-type UpdateType int
-
-const (
-	AddOccupiedResource UpdateType = iota
-	SubOccupiedResource
 )
 
 // SchedulerCache maintains some critical information about nodes and pods used for scheduling.
@@ -59,8 +50,6 @@ const (
 // is called in the plugin to signify completion of the allocation, it is removed.
 type SchedulerCache struct {
 	nodesMap              map[string]*framework.NodeInfo // node name to NodeInfo map
-	nodeCapacity          map[string]*si.Resource        // node name to node resource capacity
-	nodeOccupied          map[string]*si.Resource        // node name to node occupied resources
 	podsMap               map[string]*v1.Pod
 	pcMap                 map[string]*schedulingv1.PriorityClass
 	assignedPods          map[string]string      // map of pods to the node they are currently assigned to
@@ -90,8 +79,6 @@ type taskBloomFilter struct {
 func NewSchedulerCache(clients *client.Clients) *SchedulerCache {
 	cache := &SchedulerCache{
 		nodesMap:              make(map[string]*framework.NodeInfo),
-		nodeCapacity:          make(map[string]*si.Resource),
-		nodeOccupied:          make(map[string]*si.Resource),
 		podsMap:               make(map[string]*v1.Pod),
 		pcMap:                 make(map[string]*schedulingv1.PriorityClass),
 		assignedPods:          make(map[string]string),
@@ -197,8 +184,6 @@ func (cache *SchedulerCache) updateNode(node *v1.Node) (*v1.Node, []*v1.Pod) {
 		log.Log(log.ShimCacheExternal).Debug("Adding node to cache", zap.String("nodeName", node.Name))
 		nodeInfo = framework.NewNodeInfo()
 		cache.nodesMap[node.Name] = nodeInfo
-		cache.nodeCapacity[node.Name] = common.GetNodeResource(&node.Status)
-		cache.nodeOccupied[node.Name] = common.NewResourceBuilder().Build()
 		cache.nodesInfo = nil
 		nodeInfo.SetNode(node)
 
@@ -253,8 +238,6 @@ func (cache *SchedulerCache) removeNode(node *v1.Node) (*v1.Node, []*v1.Pod) {
 
 	log.Log(log.ShimCacheExternal).Debug("Removing node from cache", zap.String("nodeName", node.Name))
 	delete(cache.nodesMap, node.Name)
-	delete(cache.nodeOccupied, node.Name)
-	delete(cache.nodeCapacity, node.Name)
 	cache.nodesInfo = nil
 	cache.nodesInfoPodsWithAffinity = nil
 	cache.nodesInfoPodsWithReqAntiAffinity = nil
@@ -263,72 +246,6 @@ func (cache *SchedulerCache) removeNode(node *v1.Node) (*v1.Node, []*v1.Pod) {
 	return result, orphans
 }
 
-func (cache *SchedulerCache) SnapshotResources(nodeName string) (capacity *si.Resource, occupied *si.Resource, ok bool) {
-	cache.lock.RLock()
-	defer cache.lock.RUnlock()
-
-	occupied, ok1 := cache.nodeOccupied[nodeName]
-	capacity, ok2 := cache.nodeCapacity[nodeName]
-	if !ok1 || !ok2 {
-		log.Log(log.ShimCacheExternal).Warn("Unable to snapshot resources for node", zap.String("nodeName", nodeName))
-		return nil, nil, false
-	}
-	return capacity, occupied, true
-}
-
-func (cache *SchedulerCache) UpdateCapacity(nodeName string, resource *si.Resource) (capacity *si.Resource, occupied *si.Resource, ok bool) {
-	cache.lock.Lock()
-	defer cache.lock.Unlock()
-
-	occupied, ok1 := cache.nodeOccupied[nodeName]
-	_, ok2 := cache.nodeCapacity[nodeName]
-	if !ok1 || !ok2 {
-		log.Log(log.ShimCacheExternal).Warn("Unable to update capacity for node", zap.String("nodeName", nodeName))
-		return nil, nil, false
-	}
-	cache.nodeCapacity[nodeName] = resource
-	return resource, occupied, true
-}
-
-func (cache *SchedulerCache) UpdateOccupiedResource(nodeName string, namespace string, podName string, resource *si.Resource, opt UpdateType) (node *v1.Node, capacity *si.Resource, occupied *si.Resource, ok bool) {
-	cache.lock.Lock()
-	defer cache.lock.Unlock()
-
-	nodeInfo, ok1 := cache.nodesMap[nodeName]
-	occupied, ok2 := cache.nodeOccupied[nodeName]
-	capacity, ok3 := cache.nodeCapacity[nodeName]
-	if !ok1 || !ok2 || !ok3 {
-		log.Log(log.ShimCacheExternal).Warn("Unable to update occupied resources for node",
-			zap.String("nodeName", nodeName),
-			zap.String("namespace", namespace),
-			zap.String("podName", podName))
-		return nil, nil, nil, false
-	}
-	node = nodeInfo.Node()
-
-	switch opt {
-	case AddOccupiedResource:
-		log.Log(log.ShimCacheExternal).Info("Adding occupied resources to node",
-			zap.String("nodeID", nodeName),
-			zap.String("namespace", namespace),
-			zap.String("podName", podName),
-			zap.Stringer("occupied", resource))
-		occupied = common.Add(occupied, resource)
-		cache.nodeOccupied[nodeName] = occupied
-	case SubOccupiedResource:
-		log.Log(log.ShimCacheExternal).Info("Subtracting occupied resources from node",
-			zap.String("nodeID", nodeName),
-			zap.String("namespace", namespace),
-			zap.String("podName", podName),
-			zap.Stringer("occupied", resource))
-		occupied = common.Sub(occupied, resource)
-		cache.nodeOccupied[nodeName] = occupied
-	default:
-		// noop
-	}
-	return node, capacity, occupied, true
-}
-
 func (cache *SchedulerCache) GetPriorityClass(name string) *schedulingv1.PriorityClass {
 	cache.lock.RLock()
 	defer cache.lock.RUnlock()
@@ -733,7 +650,7 @@ func (cache *SchedulerCache) GetNodeInfo(nodeName string) (*v1.Node, error) {
 
 // Implement scheduler/algorithm/predicates/predicates.go#StorageClassInfo interface
 func (cache *SchedulerCache) GetStorageClassInfo(className string) (*storageV1.StorageClass, error) {
-	return cache.clients.StorageInformer.Lister().Get(className)
+	return cache.clients.StorageClassInformer.Lister().Get(className)
 }
 
 // Implement scheduler/algorithm/predicates/predicates.go#PersistentVolumeClaimInfo interface
