@@ -19,7 +19,6 @@
 package cache
 
 import (
-	"strconv"
 	"strings"
 
 	v1 "k8s.io/api/core/v1"
@@ -32,7 +31,7 @@ import (
 	"github.com/apache/yunikorn-k8shim/pkg/common/utils"
 	"github.com/apache/yunikorn-k8shim/pkg/conf"
 	"github.com/apache/yunikorn-k8shim/pkg/log"
-	siCommon "github.com/apache/yunikorn-scheduler-interface/lib/go/common"
+	"github.com/apache/yunikorn-scheduler-interface/lib/go/common"
 )
 
 func getTaskMetadata(pod *v1.Pod) (TaskMetadata, bool) {
@@ -78,8 +77,19 @@ func getAppMetadata(pod *v1.Pod) (ApplicationMetadata, bool) {
 	} else {
 		tags[constants.AppTagNamespace] = pod.Namespace
 	}
-	if isStateAwareDisabled(pod) {
-		tags[siCommon.AppTagStateAwareDisable] = "true"
+
+	// Make sure we set the force create flag to true if the pod has been scheduled already.
+	// When we create and link the metadata to an application the application does not exist yet.
+	// The force flag prevents rejections during initialisation of already allocated pods in a changed
+	// queue configuration.
+	// It will also pick up static (mirror) and DaemonSet pods. In certain circumstances this could cause
+	// pods to be allowed into the recovery queue while they should not. If this becomes an issue we can
+	// add a filter here.
+	// NOTE: this could fail to set the flag if the oldest pod for the application is not scheduled and
+	// later pods are.
+	tags[common.AppTagCreateForce] = constants.False
+	if utils.IsAssignedPod(pod) {
+		tags[common.AppTagCreateForce] = constants.True
 	}
 
 	// attach imagePullSecrets if present
@@ -104,7 +114,7 @@ func getAppMetadata(pod *v1.Pod) (ApplicationMetadata, bool) {
 				zap.String("namespace", pod.Namespace),
 				zap.String("name", pod.Name),
 				zap.Error(err))
-			events.GetRecorder().Eventf(pod, nil, v1.EventTypeWarning, "TaskGroupsError", "TaskGroupsError",
+			events.GetRecorder().Eventf(pod, nil, v1.EventTypeWarning, "GangScheduling", "TaskGroupsError",
 				"unable to get taskGroups for pod, reason: %s", err.Error())
 		}
 		tags[constants.AnnotationTaskGroups] = pod.Annotations[constants.AnnotationTaskGroups]
@@ -151,20 +161,3 @@ func getOwnerReference(pod *v1.Pod) []metav1.OwnerReference {
 	}
 	return []metav1.OwnerReference{ref}
 }
-
-func isStateAwareDisabled(pod *v1.Pod) bool {
-	value := utils.GetPodLabelValue(pod, constants.LabelDisableStateAware)
-	if value == "" {
-		return false
-	}
-	result, err := strconv.ParseBool(value)
-	if err != nil {
-		log.Log(log.ShimCacheApplication).Debug("unable to parse label for pod",
-			zap.String("namespace", pod.Namespace),
-			zap.String("name", pod.Name),
-			zap.String("label", constants.LabelDisableStateAware),
-			zap.Error(err))
-		return false
-	}
-	return result
-}
