@@ -21,7 +21,7 @@ package cache
 import (
 	"context"
 	"fmt"
-	"strconv"
+	"strings"
 	"time"
 
 	"github.com/looplab/fsm"
@@ -428,19 +428,8 @@ func (task *Task) postTaskBound() {
 	if utils.IsPluginMode() {
 		// When the pod is actively scheduled by YuniKorn, it can be  moved to the default-scheduler's
 		// UnschedulablePods structure. If the pod does not change, the pod will stay in the UnschedulablePods
-		// structure for podMaxInUnschedulablePodsDuration (default 5 minutes). Here we update the pod
-		// explicitly to move it back to the active queue.
-		// See: pkg/scheduler/internal/queue/scheduling_queue.go:isPodUpdated() for what is considered updated.
-		podCopy := task.pod.DeepCopy()
-		if _, err := task.UpdateTaskPod(podCopy, func(pod *v1.Pod) {
-			// Ensure that the default scheduler detects the pod as having changed
-			if pod.Annotations == nil {
-				pod.Annotations = make(map[string]string)
-			}
-			pod.Annotations[constants.DomainYuniKorn+"scheduled-at"] = strconv.FormatInt(time.Now().UnixNano(), 10)
-		}); err != nil {
-			log.Log(log.ShimCacheTask).Warn("failed to update pod status", zap.Error(err))
-		}
+		// structure for podMaxInUnschedulablePodsDuration (default 5 minutes). Here we explicitly activate the pod.
+		task.context.ActivatePod(task.pod)
 	}
 
 	if task.placeholder {
@@ -494,6 +483,8 @@ func (task *Task) beforeTaskCompleted() {
 
 // releaseAllocation sends the release request for the Allocation to the core.
 func (task *Task) releaseAllocation() {
+	terminationType := common.GetTerminationTypeFromString(task.terminationType)
+
 	// scheduler api might be nil in some tests
 	if task.context.apiProvider.GetAPIs().SchedulerAPI != nil {
 		log.Log(log.ShimCacheTask).Debug("prepare to send release request",
@@ -502,7 +493,7 @@ func (task *Task) releaseAllocation() {
 			zap.String("taskAlias", task.alias),
 			zap.String("allocationKey", task.allocationKey),
 			zap.String("task", task.GetTaskState()),
-			zap.String("terminationType", task.terminationType))
+			zap.String("terminationType", string(terminationType)))
 
 		// send an AllocationReleaseRequest
 		var releaseRequest *si.AllocationRequest
@@ -526,7 +517,7 @@ func (task *Task) releaseAllocation() {
 			task.applicationID,
 			task.taskID,
 			task.application.partition,
-			task.terminationType,
+			terminationType,
 		)
 
 		if releaseRequest.Releases != nil {
@@ -543,30 +534,40 @@ func (task *Task) releaseAllocation() {
 // this reduces the scheduling overhead by blocking such
 // request away from the core scheduler.
 func (task *Task) sanityCheckBeforeScheduling() error {
-	// After version 1.7.0, we should reject the task whose pod is unbound and has conflicting metadata.
-	if !utils.PodAlreadyBound(task.pod) {
-		if err := utils.CheckAppIdInPod(task.pod); err != nil {
-			log.Log(log.ShimCacheTask).Warn("Pod has inconsistent application metadata and may be rejected in a future YuniKorn release",
-				zap.String("appID", task.applicationID),
-				zap.String("podName", task.pod.Name),
-				zap.String("error", err.Error()))
-
-			events.GetRecorder().Eventf(task.pod.DeepCopy(),
-				nil, v1.EventTypeWarning, "Scheduling", "Scheduling", fmt.Sprintf("Pod has inconsistent application metadata and may be rejected in a future YuniKorn release: %s", err.Error()))
-		}
-		if err := utils.CheckQueueNameInPod(task.pod); err != nil {
-			log.Log(log.ShimCacheTask).Warn("Pod has inconsistent queue metadata and may be rejected in a future YuniKorn release",
-				zap.String("appID", task.applicationID),
-				zap.String("podName", task.pod.Name),
-				zap.String("error", err.Error()))
-
-			events.GetRecorder().Eventf(task.pod.DeepCopy(),
-				nil, v1.EventTypeWarning, "Scheduling", "Scheduling", fmt.Sprintf("Pod has inconsistent queue metadata and may be rejected in a future YuniKorn release: %s", err.Error()))
-		}
-	}
 	return task.checkPodPVCs()
 }
 
+// throw a warning if the pod has inconsistent metadata
+func (task *Task) checkPodMetadataBeforeScheduling() {
+	appID := utils.GetApplicationIDFromPod(task.pod)
+	ignoredAppIDLabels, ignoredAppIDAnnotation := utils.GetIgnoredLabelAnnotationInPod(task.pod, appID, constants.AppIdLabelKeys, constants.AppIdAnnotationKeys)
+	if len(ignoredAppIDLabels) > 0 || len(ignoredAppIDAnnotation) > 0 {
+		task.logIgnoredPodMetadata("app-id", appID, ignoredAppIDLabels, ignoredAppIDAnnotation)
+	}
+
+	queueName := utils.GetQueueNameFromPod(task.pod)
+	ignoredQueueLabels, ignoredQueueAnnotation := utils.GetIgnoredLabelAnnotationInPod(task.pod, queueName, constants.QueueLabelKeys, constants.QueueAnnotationKeys)
+	if len(ignoredQueueLabels) > 0 || len(ignoredQueueAnnotation) > 0 {
+		task.logIgnoredPodMetadata("queue", queueName, ignoredQueueLabels, ignoredQueueAnnotation)
+	}
+}
+
+func (task *Task) logIgnoredPodMetadata(metadataType string, fianlValue string, ignoredLabel map[string]string, ignoredAnnotation map[string]string) {
+	ignoredItems := make([]string, 0)
+	for key, value := range ignoredLabel {
+		ignoredItems = append(ignoredItems, fmt.Sprintf("(Label) %s: %s", key, value))
+	}
+	for key, value := range ignoredAnnotation {
+		ignoredItems = append(ignoredItems, fmt.Sprintf("(Annotation) %s: %s", key, value))
+	}
+	logMessage := fmt.Sprintf("Found multiple '%s' value in pod. { podName: %s, fianlValue: %s, ignored: [%s] }",
+		metadataType, task.pod.Name, fianlValue, strings.Join(ignoredItems, ", "))
+
+	log.Log(log.ShimCacheTask).Warn(logMessage)
+	events.GetRecorder().Eventf(task.pod.DeepCopy(),
+		nil, v1.EventTypeWarning, "Scheduling", "Scheduling", logMessage)
+}
+
 func (task *Task) checkPodPVCs() error {
 	task.lock.RLock()
 	// Check PVCs used by the pod
