@@ -27,6 +27,7 @@ import (
 	"os"
 	"os/signal"
 	"syscall"
+	"time"
 
 	"go.uber.org/zap"
 
@@ -62,9 +63,21 @@ func main() {
 	kubeClient := client.NewKubeClient(amConf.GetKubeConfig())
 
 	informers := admission.NewInformers(kubeClient, amConf.GetNamespace())
-	amConf.RegisterHandlers(informers.ConfigMap)
-	pcCache := admission.NewPriorityClassCache(informers.PriorityClass)
-	nsCache := admission.NewNamespaceCache(informers.Namespace)
+
+	if hadlerErr := amConf.RegisterHandlers(informers.ConfigMap); hadlerErr != nil {
+		log.Log(log.Admission).Fatal("Failed to register handlers", zap.Error(hadlerErr))
+		return
+	}
+	pcCache, pcErr := admission.NewPriorityClassCache(informers.PriorityClass)
+	if pcErr != nil {
+		log.Log(log.Admission).Fatal("Failed to create new priority class cache", zap.Error(pcErr))
+		return
+	}
+	nsCache, nsErr := admission.NewNamespaceCache(informers.Namespace)
+	if nsErr != nil {
+		log.Log(log.Admission).Fatal("Failed to create namespace cache", zap.Error(nsErr))
+		return
+	}
 	informers.Start()
 
 	wm, err := admission.NewWebhookManager(amConf)
@@ -148,7 +161,8 @@ func (wh *WebHook) Startup(certs *tls.Certificate) {
 			CipherSuites: wh.getCipherSuites(),       // limit cipher suite to secure ones
 			Certificates: []tls.Certificate{*certs},
 		},
-		Handler: mux,
+		Handler:           mux,
+		ReadHeaderTimeout: 10 * time.Second,
 	}
 
 	go func() {
