@@ -29,10 +29,12 @@ import (
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apiserver/pkg/util/feature"
 	"k8s.io/client-go/informers"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/klog/v2"
 	v1helper "k8s.io/kubernetes/pkg/apis/core/v1/helper"
+	"k8s.io/kubernetes/pkg/features"
 	"k8s.io/kubernetes/pkg/scheduler/framework"
 	"k8s.io/kubernetes/pkg/scheduler/framework/plugins/interpodaffinity"
 	"k8s.io/kubernetes/pkg/scheduler/framework/plugins/nodeaffinity"
@@ -45,7 +47,6 @@ import (
 	"k8s.io/kubernetes/pkg/util/taints"
 
 	"github.com/apache/yunikorn-k8shim/pkg/client"
-	"github.com/apache/yunikorn-k8shim/pkg/conf"
 	"github.com/apache/yunikorn-k8shim/pkg/log"
 	"github.com/apache/yunikorn-k8shim/pkg/plugin/support"
 )
@@ -56,7 +57,6 @@ var (
 )
 
 func TestPreemptionPredicatesEmpty(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
 	lister := lister()
@@ -74,7 +74,6 @@ func TestPreemptionPredicatesEmpty(t *testing.T) {
 }
 
 func TestPreemptionPredicates(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
 	lister := lister()
@@ -127,7 +126,6 @@ func TestPreemptionPredicates(t *testing.T) {
 }
 
 func TestEventsToRegister(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
 	lister := lister()
@@ -142,19 +140,18 @@ func TestEventsToRegister(t *testing.T) {
 	}
 	events := predicateManager.EventsToRegister(queueingHintFn)
 	assert.Equal(t, events[0].Event.Resource, framework.Node, "wrong resource (0)")
-	assert.Equal(t, events[0].Event.ActionType, framework.All, "wrong action type (0)")
+	assert.Equal(t, events[0].Event.ActionType, framework.Add|framework.Delete|framework.UpdateNodeLabel|framework.UpdateNodeTaint, "wrong action type (0)")
 	fn0, err := events[0].QueueingHintFn(klog.NewKlogr(), nil, "", "")
 	assert.NilError(t, err)
 	assert.Equal(t, int(fn0), -1, "wrong fn (0)")
 	assert.Equal(t, events[1].Event.Resource, framework.Pod, "wrong resource (1)")
-	assert.Equal(t, events[1].Event.ActionType, framework.Add|framework.Delete|framework.UpdatePodLabel, "wrong action type (1)")
+	assert.Equal(t, events[1].Event.ActionType, framework.Add|framework.Delete|framework.UpdatePodLabel|framework.UpdatePodTolerations, "wrong action type (1)")
 	fn1, err := events[1].QueueingHintFn(klog.NewKlogr(), nil, "", "")
 	assert.NilError(t, err)
 	assert.Equal(t, int(fn1), -1, "wrong fn (1)")
 }
 
 func TestPodFitsHost(t *testing.T) {
-	conf.GetSchedulerConf().SetTestMode(true)
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
 	lister := lister()
@@ -1112,6 +1109,12 @@ func newPodWithPort(hostPorts ...int) *v1.Pod {
 	}
 }
 
+func TestEnableOptionalKubernetesFeatureGates(t *testing.T) {
+	EnableOptionalKubernetesFeatureGates()
+	assert.Assert(t, feature.DefaultFeatureGate.Enabled(features.PodLevelResources), "pod level resources not enabled")
+	assert.Assert(t, feature.DefaultFeatureGate.Enabled(features.InPlacePodVerticalScaling), "in-place pod vertical scaling not enabled")
+}
+
 func TestRunGeneralPredicates(t *testing.T) {
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
