@@ -269,6 +269,7 @@ func (sp *YuniKornSchedulerPlugin) PostBind(_ context.Context, _ *framework.Cycl
 // NewSchedulerPlugin initializes a new plugin and returns it
 func NewSchedulerPlugin(_ context.Context, _ runtime.Object, handle framework.Handle) (framework.Plugin, error) {
 	log.Log(log.ShimSchedulerPlugin).Info(conf.GetBuildInfoString())
+	log.Log(log.ShimSchedulerPlugin).Warn("The plugin mode has been deprecated and will be removed in a future release. Consider migrating to YuniKorn standalone mode.")
 
 	configMaps, err := client.LoadBootstrapConfigMaps()
 	if err != nil {
@@ -293,8 +294,12 @@ func NewSchedulerPlugin(_ context.Context, _ runtime.Object, handle framework.Ha
 		log.Log(log.ShimSchedulerPlugin).Fatal("Unable to start scheduler", zap.Error(err))
 	}
 
+	context := ss.GetContext()
+	context.SetPodActivator(func(logger klog.Logger, pod *v1.Pod) {
+		handle.Activate(logger, map[string]*v1.Pod{pod.Name: pod})
+	})
 	p := &YuniKornSchedulerPlugin{
-		context: ss.GetContext(),
+		context: context,
 	}
 	events.SetRecorder(handle.EventRecorder())
 	return p, nil
