@@ -21,7 +21,6 @@ package spark_jobs_scheduling
 import (
 	"context"
 	"fmt"
-	"net/url"
 	"os"
 	"os/exec"
 	"sort"
@@ -29,7 +28,6 @@ import (
 
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
-	"k8s.io/client-go/rest"
 
 	"github.com/apache/yunikorn-core/pkg/webservice/dao"
 	tests "github.com/apache/yunikorn-k8shim/test/e2e"
@@ -46,16 +44,17 @@ var _ = Describe("", func() {
 	var exErr error
 	var sparkNS = "spark-" + common.RandSeq(10)
 	var svcAcc = "svc-acc-" + common.RandSeq(10)
-	var config *rest.Config
-	var masterURL string
 	var roleName = "spark-jobs-role-" + common.RandSeq(5)
 	var clusterEditRole = "edit"
-	var sparkImage = os.Getenv("SPARK_PYTHON_IMAGE")
+	var sparkImage = os.Getenv("SPARK_IMAGE")
+	var sparkPyImage = os.Getenv("SPARK_PYTHON_IMAGE")
 	var sparkExecutorCount = 3
 
 	BeforeEach(func() {
 		By(fmt.Sprintf("Spark image is: %s", sparkImage))
 		Ω(sparkImage).NotTo(BeEmpty())
+		By(fmt.Sprintf("Spark_py image is: %s", sparkPyImage))
+		Ω(sparkPyImage).NotTo(BeEmpty())
 		kClient = k8s.KubeCtl{}
 		Ω(kClient.SetClient()).To(BeNil())
 		Ω(exErr).NotTo(HaveOccurred())
@@ -71,21 +70,6 @@ var _ = Describe("", func() {
 		By(fmt.Sprintf("Creating cluster role binding: %s for spark jobs", roleName))
 		_, err = kClient.CreateClusterRoleBinding(roleName, clusterEditRole, sparkNS, svcAcc)
 		Ω(err).NotTo(HaveOccurred())
-
-		config, err = kClient.GetKubeConfig()
-		Ω(err).NotTo(HaveOccurred())
-
-		u, err := url.Parse(config.Host)
-		Ω(err).NotTo(HaveOccurred())
-		port := u.Port()
-		if port == "" {
-			port = "443"
-			if u.Scheme == "http" {
-				port = "80"
-			}
-		}
-		masterURL = u.Scheme + "://" + u.Hostname() + ":" + port
-		By(fmt.Sprintf("MasterURL info is %s ", masterURL))
 	})
 
 	It("Test_With_Spark_Jobs", func() {
@@ -93,8 +77,8 @@ var _ = Describe("", func() {
 		err := exec.Command(
 			"bash",
 			"../testdata/spark_jobs.sh",
-			masterURL,
 			sparkImage,
+			sparkPyImage,
 			sparkNS,
 			svcAcc,
 			string(rune(sparkExecutorCount))).Run()
@@ -110,12 +94,15 @@ var _ = Describe("", func() {
 		err = restClient.WaitforQueueToAppear(configmanager.DefaultPartition, sparkQueueName, 120)
 		Ω(err).NotTo(HaveOccurred())
 
-		By(fmt.Sprintf("Get apps from specific queue: %s", sparkNS))
+		By(fmt.Sprintf("Get apps from specific queue: %s", sparkQueueName))
 		var appsFromQueue []*dao.ApplicationDAOInfo
 		// Poll for apps to appear in the queue
 		err = wait.PollUntilContextTimeout(context.TODO(), time.Millisecond*100, time.Duration(120)*time.Second, false, func(context.Context) (done bool, err error) {
-			appsFromQueue, err = restClient.GetApps(configmanager.DefaultPartition, configmanager.RootQueue+"."+sparkNS)
-			if len(appsFromQueue) == 3 {
+			appsFromQueue, err = restClient.GetApps(configmanager.DefaultPartition, sparkQueueName)
+			if err != nil {
+				return false, err
+			}
+			if len(appsFromQueue) == 4 {
 				return true, nil
 			}
 			return false, err
@@ -138,7 +125,7 @@ var _ = Describe("", func() {
 		By(fmt.Sprintf("Apps submitted are: %s", appIds))
 
 		// Verify that all the spark jobs are scheduled and are in running state.
-		for _, id := range appIds {
+		for _, id := range appIds[1:] {
 			By(fmt.Sprintf("Verify driver pod for application %s has been created.", id))
 			err = kClient.WaitForPodBySelector(sparkNS, fmt.Sprintf("spark-app-selector=%s, spark-role=driver", id), 180*time.Second)
 			Ω(err).ShouldNot(HaveOccurred())
