@@ -81,10 +81,59 @@ export class CommonUtil {
     return `${toValue.toLocaleString(undefined, { maximumFractionDigits: 2 })}${unit}`;
   }
 
+  static absoluteUsedMemoryColumnFormatter(value: string | undefined): string {
+    if (!value) {
+      return '';
+    }
+    if (value === 'n/a') {
+      return '<strong>Memory:</strong> n/a';
+    }
+    //Memory: 4%, CPU: 2%
+    const memoryRegex = /Memory: ([0-9]|[1-9][0-9]|100)%/;
+    const match = value.match(memoryRegex);
+  
+    if(match){
+      return CommonUtil.queueResourceColumnFormatter(match[0]);
+    } else {
+      return '<strong>Memory:</strong> n/a (wrong memory format)';
+    }
+  }
+
+  static absoluteUsedCPUColumnFormatter(value: string | undefined): string {
+    if (!value) {
+      return '';
+    }
+    if (value === 'n/a') {
+      return '<strong>CPU:</strong> n/a';
+    }
+    //Memory: 4%, CPU: 2%
+    const cpuRegex = /CPU: ([0-9]|[1-9][0-9]|100)%/;
+    const match = value.match(cpuRegex);
+  
+    if(match){
+      return CommonUtil.queueResourceColumnFormatter(match[0]);
+    } else {
+      return '<strong>CPU:</strong> n/a (wrong cpu format)';
+    }
+  }
+
   static resourceColumnFormatter(value: string): string {
     return value.split(', ').join('<br/>');
   }
 
+  static queueResourceColumnFormatter(value: string | undefined): string {
+    if (!value) {
+      return '';
+    }
+    return value.split(', ').map(part => {
+      const [key, val] = part.split(': ');
+      if (key === 'n/a') {
+        return key;
+      }
+      return `<strong>${key}:</strong> ${val}`;
+    }).join('<br/>');
+  }
+
   static formatPercent(value: number | string): string {
     const toValue = +value;
     return `${toValue.toFixed(0)}%`;
