@@ -17,4 +17,4 @@
  */
 
 // zone JS is required by default for Angular itself.
-import 'zone.js/dist/zone';
+import 'zone.js';
